/*! noble-hashes - MIT License (c) 2021 Paul Miller (paulmillr.com) */
export declare type TypedArray = Int8Array | Uint8ClampedArray | Uint8Array | Uint16Array | Int16Array | Uint32Array | Int32Array;
export declare const u8: (arr: TypedArray) => Uint8Array;
export declare const u32: (arr: TypedArray) => Uint32Array;
export declare const createView: (arr: TypedArray) => DataView;
export declare const rotr: (word: number, shift: number) => number;
export declare const isLE: boolean;
export declare function bytesToHex(uint8a: Uint8Array): string;
export declare function hexToBytes(hex: string): Uint8Array;
export declare const nextTick: () => Promise<unknown>;
export declare function asyncLoop(iters: number, tick: number, cb: (i: number) => void): Promise<void>;
export declare function utf8ToBytes(str: string): Uint8Array;
export declare type Input = Uint8Array | string;
export declare function toBytes(data: Input): Uint8Array;
export declare function concatBytes(...arrays: Uint8Array[]): Uint8Array;
export declare function assertNumber(n: number): void;
export declare function assertBool(b: boolean): void;
export declare function assertBytes(bytes: Uint8Array, ...lengths: number[]): void;
export declare function assertHash(hash: CHash): void;
export declare abstract class Hash<T extends Hash<T>> {
    abstract blockLen: number;
    abstract outputLen: number;
    abstract update(buf: Input): this;
    abstract digestInto(buf: Uint8Array): void;
    abstract digest(): Uint8Array;
    abstract destroy(): void;
    abstract _cloneInto(to?: T): T;
    clone(): T;
}
export declare type HashXOF<T extends Hash<T>> = Hash<T> & {
    xof(bytes: number): Uint8Array;
    xofInto(buf: Uint8Array): Uint8Array;
};
declare type EmptyObj = {};
export declare function checkOpts<T1 extends EmptyObj, T2 extends EmptyObj>(def: T1, _opts?: T2): T1 & T2;
export declare type CHash = ReturnType<typeof wrapConstructor>;
export declare function wrapConstructor<T extends Hash<T>>(hashConstructor: () => Hash<T>): {
    (message: Input): Uint8Array;
    outputLen: number;
    blockLen: number;
    create(): Hash<T>;
    init: () => Hash<T>;
};
export declare function wrapConstructorWithOpts<H extends Hash<H>, T extends Object>(hashCons: (opts?: T) => Hash<H>): {
    (msg: Input, opts?: T | undefined): Uint8Array;
    outputLen: number;
    blockLen: number;
    create(opts: T): Hash<H>;
    init: (opts: T) => Hash<H>;
};
export declare function randomBytes(bytesLength?: number): Uint8Array;
export {};
