import type { ApiTypes } from '@polkadot/api-base/types';
declare module '@polkadot/api-base/types/errors' {
    interface AugmentedErrors<ApiType extends ApiTypes> {
        auctions: {
            /**
             * The para is already leased out for part of this range.
             **/
            AlreadyLeasedOut: AugmentedError<ApiType>;
            /**
             * Auction has already ended.
             **/
            AuctionEnded: AugmentedError<ApiType>;
            /**
             * This auction is already in progress.
             **/
            AuctionInProgress: AugmentedError<ApiType>;
            /**
             * The lease period is in the past.
             **/
            LeasePeriodInPast: AugmentedError<ApiType>;
            /**
             * Not an auction.
             **/
            NotAuction: AugmentedError<ApiType>;
            /**
             * Not a current auction.
             **/
            NotCurrentAuction: AugmentedError<ApiType>;
            /**
             * Para is not registered
             **/
            ParaNotRegistered: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        authorship: {
            /**
             * The uncle is genesis.
             **/
            GenesisUncle: AugmentedError<ApiType>;
            /**
             * The uncle parent not in the chain.
             **/
            InvalidUncleParent: AugmentedError<ApiType>;
            /**
             * The uncle isn't recent enough to be included.
             **/
            OldUncle: AugmentedError<ApiType>;
            /**
             * The uncle is too high in chain.
             **/
            TooHighUncle: AugmentedError<ApiType>;
            /**
             * Too many uncles.
             **/
            TooManyUncles: AugmentedError<ApiType>;
            /**
             * The uncle is already included.
             **/
            UncleAlreadyIncluded: AugmentedError<ApiType>;
            /**
             * Uncles already set in the block.
             **/
            UnclesAlreadySet: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        babe: {
            /**
             * A given equivocation report is valid but already previously reported.
             **/
            DuplicateOffenceReport: AugmentedError<ApiType>;
            /**
             * An equivocation proof provided as part of an equivocation report is invalid.
             **/
            InvalidEquivocationProof: AugmentedError<ApiType>;
            /**
             * A key ownership proof provided as part of an equivocation report is invalid.
             **/
            InvalidKeyOwnershipProof: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        bagsList: {
            /**
             * Id not found in list.
             **/
            IdNotFound: AugmentedError<ApiType>;
            /**
             * An Id does not have a greater vote weight than another Id.
             **/
            NotHeavier: AugmentedError<ApiType>;
            /**
             * Attempted to place node in front of a node in another bag.
             **/
            NotInSameBag: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        balances: {
            /**
             * Beneficiary account must pre-exist
             **/
            DeadAccount: AugmentedError<ApiType>;
            /**
             * Value too low to create account due to existential deposit
             **/
            ExistentialDeposit: AugmentedError<ApiType>;
            /**
             * A vesting schedule already exists for this account
             **/
            ExistingVestingSchedule: AugmentedError<ApiType>;
            /**
             * Balance too low to send value
             **/
            InsufficientBalance: AugmentedError<ApiType>;
            /**
             * Transfer/payment would kill account
             **/
            KeepAlive: AugmentedError<ApiType>;
            /**
             * Account liquidity restrictions prevent withdrawal
             **/
            LiquidityRestrictions: AugmentedError<ApiType>;
            /**
             * Number of named reserves exceed MaxReserves
             **/
            TooManyReserves: AugmentedError<ApiType>;
            /**
             * Vesting balance too high to send value
             **/
            VestingBalance: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        bounties: {
            /**
             * The bounty cannot be closed because it has active child-bounties.
             **/
            HasActiveChildBounty: AugmentedError<ApiType>;
            /**
             * Proposer's balance is too low.
             **/
            InsufficientProposersBalance: AugmentedError<ApiType>;
            /**
             * Invalid bounty fee.
             **/
            InvalidFee: AugmentedError<ApiType>;
            /**
             * No proposal or bounty at that index.
             **/
            InvalidIndex: AugmentedError<ApiType>;
            /**
             * Invalid bounty value.
             **/
            InvalidValue: AugmentedError<ApiType>;
            /**
             * A bounty payout is pending.
             * To cancel the bounty, you must unassign and slash the curator.
             **/
            PendingPayout: AugmentedError<ApiType>;
            /**
             * The bounties cannot be claimed/closed because it's still in the countdown period.
             **/
            Premature: AugmentedError<ApiType>;
            /**
             * The reason given is just too big.
             **/
            ReasonTooBig: AugmentedError<ApiType>;
            /**
             * Require bounty curator.
             **/
            RequireCurator: AugmentedError<ApiType>;
            /**
             * The bounty status is unexpected.
             **/
            UnexpectedStatus: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        claims: {
            /**
             * Invalid Ethereum signature.
             **/
            InvalidEthereumSignature: AugmentedError<ApiType>;
            /**
             * A needed statement was not included.
             **/
            InvalidStatement: AugmentedError<ApiType>;
            /**
             * There's not enough in the pot to pay out some unvested amount. Generally implies a logic
             * error.
             **/
            PotUnderflow: AugmentedError<ApiType>;
            /**
             * Account ID sending transaction has no claim.
             **/
            SenderHasNoClaim: AugmentedError<ApiType>;
            /**
             * Ethereum address has no claim.
             **/
            SignerHasNoClaim: AugmentedError<ApiType>;
            /**
             * The account already has a vested balance.
             **/
            VestedBalanceExists: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        configuration: {
            /**
             * The new value for a configuration parameter is invalid.
             **/
            InvalidNewValue: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        council: {
            /**
             * Members are already initialized!
             **/
            AlreadyInitialized: AugmentedError<ApiType>;
            /**
             * Duplicate proposals not allowed
             **/
            DuplicateProposal: AugmentedError<ApiType>;
            /**
             * Duplicate vote ignored
             **/
            DuplicateVote: AugmentedError<ApiType>;
            /**
             * Account is not a member
             **/
            NotMember: AugmentedError<ApiType>;
            /**
             * Proposal must exist
             **/
            ProposalMissing: AugmentedError<ApiType>;
            /**
             * The close call was made too early, before the end of the voting.
             **/
            TooEarly: AugmentedError<ApiType>;
            /**
             * There can only be a maximum of `MaxProposals` active proposals.
             **/
            TooManyProposals: AugmentedError<ApiType>;
            /**
             * Mismatched index
             **/
            WrongIndex: AugmentedError<ApiType>;
            /**
             * The given length bound for the proposal was too low.
             **/
            WrongProposalLength: AugmentedError<ApiType>;
            /**
             * The given weight bound for the proposal was too low.
             **/
            WrongProposalWeight: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        crowdloan: {
            /**
             * The fund is already in `NewRaise`
             **/
            AlreadyInNewRaise: AugmentedError<ApiType>;
            /**
             * This parachain's bid or lease is still active and withdraw cannot yet begin.
             **/
            BidOrLeaseActive: AugmentedError<ApiType>;
            /**
             * The campaign ends before the current block number. The end must be in the future.
             **/
            CannotEndInPast: AugmentedError<ApiType>;
            /**
             * Contributions exceed maximum amount.
             **/
            CapExceeded: AugmentedError<ApiType>;
            /**
             * The contribution period has already ended.
             **/
            ContributionPeriodOver: AugmentedError<ApiType>;
            /**
             * The contribution was below the minimum, `MinContribution`.
             **/
            ContributionTooSmall: AugmentedError<ApiType>;
            /**
             * The end date for this crowdloan is not sensible.
             **/
            EndTooFarInFuture: AugmentedError<ApiType>;
            /**
             * The current lease period is more than the first lease period.
             **/
            FirstPeriodInPast: AugmentedError<ApiType>;
            /**
             * The first lease period needs to at least be less than 3 `max_value`.
             **/
            FirstPeriodTooFarInFuture: AugmentedError<ApiType>;
            /**
             * The crowdloan has not yet ended.
             **/
            FundNotEnded: AugmentedError<ApiType>;
            /**
             * The origin of this call is invalid.
             **/
            InvalidOrigin: AugmentedError<ApiType>;
            /**
             * Invalid fund index.
             **/
            InvalidParaId: AugmentedError<ApiType>;
            /**
             * Invalid signature.
             **/
            InvalidSignature: AugmentedError<ApiType>;
            /**
             * Last lease period must be greater than first lease period.
             **/
            LastPeriodBeforeFirstPeriod: AugmentedError<ApiType>;
            /**
             * The last lease period cannot be more than 3 periods after the first period.
             **/
            LastPeriodTooFarInFuture: AugmentedError<ApiType>;
            /**
             * This parachain lease is still active and retirement cannot yet begin.
             **/
            LeaseActive: AugmentedError<ApiType>;
            /**
             * The provided memo is too large.
             **/
            MemoTooLarge: AugmentedError<ApiType>;
            /**
             * There are no contributions stored in this crowdloan.
             **/
            NoContributions: AugmentedError<ApiType>;
            /**
             * A lease period has not started yet, due to an offset in the starting block.
             **/
            NoLeasePeriod: AugmentedError<ApiType>;
            /**
             * This crowdloan does not correspond to a parachain.
             **/
            NotParachain: AugmentedError<ApiType>;
            /**
             * The crowdloan is not ready to dissolve. Potentially still has a slot or in retirement period.
             **/
            NotReadyToDissolve: AugmentedError<ApiType>;
            /**
             * There was an overflow.
             **/
            Overflow: AugmentedError<ApiType>;
            /**
             * No contributions allowed during the VRF delay
             **/
            VrfDelayInProgress: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        democracy: {
            /**
             * Cannot cancel the same proposal twice
             **/
            AlreadyCanceled: AugmentedError<ApiType>;
            /**
             * The account is already delegating.
             **/
            AlreadyDelegating: AugmentedError<ApiType>;
            /**
             * Identity may not veto a proposal twice
             **/
            AlreadyVetoed: AugmentedError<ApiType>;
            /**
             * Preimage already noted
             **/
            DuplicatePreimage: AugmentedError<ApiType>;
            /**
             * Proposal already made
             **/
            DuplicateProposal: AugmentedError<ApiType>;
            /**
             * Imminent
             **/
            Imminent: AugmentedError<ApiType>;
            /**
             * The instant referendum origin is currently disallowed.
             **/
            InstantNotAllowed: AugmentedError<ApiType>;
            /**
             * Too high a balance was provided that the account cannot afford.
             **/
            InsufficientFunds: AugmentedError<ApiType>;
            /**
             * Invalid hash
             **/
            InvalidHash: AugmentedError<ApiType>;
            /**
             * Maximum number of votes reached.
             **/
            MaxVotesReached: AugmentedError<ApiType>;
            /**
             * No proposals waiting
             **/
            NoneWaiting: AugmentedError<ApiType>;
            /**
             * Delegation to oneself makes no sense.
             **/
            Nonsense: AugmentedError<ApiType>;
            /**
             * The actor has no permission to conduct the action.
             **/
            NoPermission: AugmentedError<ApiType>;
            /**
             * No external proposal
             **/
            NoProposal: AugmentedError<ApiType>;
            /**
             * The account is not currently delegating.
             **/
            NotDelegating: AugmentedError<ApiType>;
            /**
             * Not imminent
             **/
            NotImminent: AugmentedError<ApiType>;
            /**
             * Next external proposal not simple majority
             **/
            NotSimpleMajority: AugmentedError<ApiType>;
            /**
             * The given account did not vote on the referendum.
             **/
            NotVoter: AugmentedError<ApiType>;
            /**
             * Invalid preimage
             **/
            PreimageInvalid: AugmentedError<ApiType>;
            /**
             * Preimage not found
             **/
            PreimageMissing: AugmentedError<ApiType>;
            /**
             * Proposal still blacklisted
             **/
            ProposalBlacklisted: AugmentedError<ApiType>;
            /**
             * Proposal does not exist
             **/
            ProposalMissing: AugmentedError<ApiType>;
            /**
             * Vote given for invalid referendum
             **/
            ReferendumInvalid: AugmentedError<ApiType>;
            /**
             * Too early
             **/
            TooEarly: AugmentedError<ApiType>;
            /**
             * Maximum number of proposals reached.
             **/
            TooManyProposals: AugmentedError<ApiType>;
            /**
             * Value too low
             **/
            ValueLow: AugmentedError<ApiType>;
            /**
             * The account currently has votes attached to it and the operation cannot succeed until
             * these are removed, either through `unvote` or `reap_vote`.
             **/
            VotesExist: AugmentedError<ApiType>;
            /**
             * Invalid upper bound.
             **/
            WrongUpperBound: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        electionProviderMultiPhase: {
            /**
             * The call is not allowed at this point.
             **/
            CallNotAllowed: AugmentedError<ApiType>;
            /**
             * `Self::insert_submission` returned an invalid index.
             **/
            InvalidSubmissionIndex: AugmentedError<ApiType>;
            /**
             * Snapshot metadata should exist but didn't.
             **/
            MissingSnapshotMetadata: AugmentedError<ApiType>;
            /**
             * OCW submitted solution for wrong round
             **/
            OcwCallWrongEra: AugmentedError<ApiType>;
            /**
             * Submission was too early.
             **/
            PreDispatchEarlySubmission: AugmentedError<ApiType>;
            /**
             * Submission was too weak, score-wise.
             **/
            PreDispatchWeakSubmission: AugmentedError<ApiType>;
            /**
             * Wrong number of winners presented.
             **/
            PreDispatchWrongWinnerCount: AugmentedError<ApiType>;
            /**
             * The origin failed to pay the deposit.
             **/
            SignedCannotPayDeposit: AugmentedError<ApiType>;
            /**
             * Witness data to dispatchable is invalid.
             **/
            SignedInvalidWitness: AugmentedError<ApiType>;
            /**
             * The queue was full, and the solution was not better than any of the existing ones.
             **/
            SignedQueueFull: AugmentedError<ApiType>;
            /**
             * The signed submission consumes too much weight
             **/
            SignedTooMuchWeight: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        grandpa: {
            /**
             * Attempt to signal GRANDPA change with one already pending.
             **/
            ChangePending: AugmentedError<ApiType>;
            /**
             * A given equivocation report is valid but already previously reported.
             **/
            DuplicateOffenceReport: AugmentedError<ApiType>;
            /**
             * An equivocation proof provided as part of an equivocation report is invalid.
             **/
            InvalidEquivocationProof: AugmentedError<ApiType>;
            /**
             * A key ownership proof provided as part of an equivocation report is invalid.
             **/
            InvalidKeyOwnershipProof: AugmentedError<ApiType>;
            /**
             * Attempt to signal GRANDPA pause when the authority set isn't live
             * (either paused or already pending pause).
             **/
            PauseFailed: AugmentedError<ApiType>;
            /**
             * Attempt to signal GRANDPA resume when the authority set isn't paused
             * (either live or already pending resume).
             **/
            ResumeFailed: AugmentedError<ApiType>;
            /**
             * Cannot signal forced change so soon after last.
             **/
            TooSoon: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        hrmp: {
            /**
             * The channel is already confirmed.
             **/
            AcceptHrmpChannelAlreadyConfirmed: AugmentedError<ApiType>;
            /**
             * The channel from the sender to the origin doesn't exist.
             **/
            AcceptHrmpChannelDoesntExist: AugmentedError<ApiType>;
            /**
             * The recipient already has the maximum number of allowed inbound channels.
             **/
            AcceptHrmpChannelLimitExceeded: AugmentedError<ApiType>;
            /**
             * Canceling is requested by neither the sender nor recipient of the open channel request.
             **/
            CancelHrmpOpenChannelUnauthorized: AugmentedError<ApiType>;
            /**
             * The channel close request is already requested.
             **/
            CloseHrmpChannelAlreadyUnderway: AugmentedError<ApiType>;
            /**
             * The channel to be closed doesn't exist.
             **/
            CloseHrmpChannelDoesntExist: AugmentedError<ApiType>;
            /**
             * The origin tries to close a channel where it is neither the sender nor the recipient.
             **/
            CloseHrmpChannelUnauthorized: AugmentedError<ApiType>;
            /**
             * Cannot cancel an HRMP open channel request because it is already confirmed.
             **/
            OpenHrmpChannelAlreadyConfirmed: AugmentedError<ApiType>;
            /**
             * The channel already exists
             **/
            OpenHrmpChannelAlreadyExists: AugmentedError<ApiType>;
            /**
             * There is already a request to open the same channel.
             **/
            OpenHrmpChannelAlreadyRequested: AugmentedError<ApiType>;
            /**
             * The requested capacity exceeds the global limit.
             **/
            OpenHrmpChannelCapacityExceedsLimit: AugmentedError<ApiType>;
            /**
             * The open request doesn't exist.
             **/
            OpenHrmpChannelDoesntExist: AugmentedError<ApiType>;
            /**
             * The recipient is not a valid para.
             **/
            OpenHrmpChannelInvalidRecipient: AugmentedError<ApiType>;
            /**
             * The sender already has the maximum number of allowed outbound channels.
             **/
            OpenHrmpChannelLimitExceeded: AugmentedError<ApiType>;
            /**
             * The open request requested the message size that exceeds the global limit.
             **/
            OpenHrmpChannelMessageSizeExceedsLimit: AugmentedError<ApiType>;
            /**
             * The sender tried to open a channel to themselves.
             **/
            OpenHrmpChannelToSelf: AugmentedError<ApiType>;
            /**
             * The requested capacity is zero.
             **/
            OpenHrmpChannelZeroCapacity: AugmentedError<ApiType>;
            /**
             * The requested maximum message size is 0.
             **/
            OpenHrmpChannelZeroMessageSize: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        identity: {
            /**
             * Account ID is already named.
             **/
            AlreadyClaimed: AugmentedError<ApiType>;
            /**
             * Empty index.
             **/
            EmptyIndex: AugmentedError<ApiType>;
            /**
             * Fee is changed.
             **/
            FeeChanged: AugmentedError<ApiType>;
            /**
             * The index is invalid.
             **/
            InvalidIndex: AugmentedError<ApiType>;
            /**
             * Invalid judgement.
             **/
            InvalidJudgement: AugmentedError<ApiType>;
            /**
             * The target is invalid.
             **/
            InvalidTarget: AugmentedError<ApiType>;
            /**
             * Judgement given.
             **/
            JudgementGiven: AugmentedError<ApiType>;
            /**
             * No identity found.
             **/
            NoIdentity: AugmentedError<ApiType>;
            /**
             * Account isn't found.
             **/
            NotFound: AugmentedError<ApiType>;
            /**
             * Account isn't named.
             **/
            NotNamed: AugmentedError<ApiType>;
            /**
             * Sub-account isn't owned by sender.
             **/
            NotOwned: AugmentedError<ApiType>;
            /**
             * Sender is not a sub-account.
             **/
            NotSub: AugmentedError<ApiType>;
            /**
             * Sticky judgement.
             **/
            StickyJudgement: AugmentedError<ApiType>;
            /**
             * Too many additional fields.
             **/
            TooManyFields: AugmentedError<ApiType>;
            /**
             * Maximum amount of registrars reached. Cannot add any more.
             **/
            TooManyRegistrars: AugmentedError<ApiType>;
            /**
             * Too many subs-accounts.
             **/
            TooManySubAccounts: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        imOnline: {
            /**
             * Duplicated heartbeat.
             **/
            DuplicatedHeartbeat: AugmentedError<ApiType>;
            /**
             * Non existent public key.
             **/
            InvalidKey: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        indices: {
            /**
             * The index was not available.
             **/
            InUse: AugmentedError<ApiType>;
            /**
             * The index was not already assigned.
             **/
            NotAssigned: AugmentedError<ApiType>;
            /**
             * The index is assigned to another account.
             **/
            NotOwner: AugmentedError<ApiType>;
            /**
             * The source and destination accounts are identical.
             **/
            NotTransfer: AugmentedError<ApiType>;
            /**
             * The index is permanent and may not be freed/changed.
             **/
            Permanent: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        multisig: {
            /**
             * Call is already approved by this signatory.
             **/
            AlreadyApproved: AugmentedError<ApiType>;
            /**
             * The data to be stored is already stored.
             **/
            AlreadyStored: AugmentedError<ApiType>;
            /**
             * The maximum weight information provided was too low.
             **/
            MaxWeightTooLow: AugmentedError<ApiType>;
            /**
             * Threshold must be 2 or greater.
             **/
            MinimumThreshold: AugmentedError<ApiType>;
            /**
             * Call doesn't need any (more) approvals.
             **/
            NoApprovalsNeeded: AugmentedError<ApiType>;
            /**
             * Multisig operation not found when attempting to cancel.
             **/
            NotFound: AugmentedError<ApiType>;
            /**
             * No timepoint was given, yet the multisig operation is already underway.
             **/
            NoTimepoint: AugmentedError<ApiType>;
            /**
             * Only the account that originally created the multisig is able to cancel it.
             **/
            NotOwner: AugmentedError<ApiType>;
            /**
             * The sender was contained in the other signatories; it shouldn't be.
             **/
            SenderInSignatories: AugmentedError<ApiType>;
            /**
             * The signatories were provided out of order; they should be ordered.
             **/
            SignatoriesOutOfOrder: AugmentedError<ApiType>;
            /**
             * There are too few signatories in the list.
             **/
            TooFewSignatories: AugmentedError<ApiType>;
            /**
             * There are too many signatories in the list.
             **/
            TooManySignatories: AugmentedError<ApiType>;
            /**
             * A timepoint was given, yet no multisig operation is underway.
             **/
            UnexpectedTimepoint: AugmentedError<ApiType>;
            /**
             * A different timepoint was given to the multisig operation that is underway.
             **/
            WrongTimepoint: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        paraInclusion: {
            /**
             * Multiple bitfields submitted by same validator or validators out of order by index.
             **/
            BitfieldDuplicateOrUnordered: AugmentedError<ApiType>;
            /**
             * A bitfield that references a freed core,
             * either intentionally or as part of a concluded
             * invalid dispute.
             **/
            BitfieldReferencesFreedCore: AugmentedError<ApiType>;
            /**
             * Candidate not in parent context.
             **/
            CandidateNotInParentContext: AugmentedError<ApiType>;
            /**
             * Candidate scheduled despite pending candidate already existing for the para.
             **/
            CandidateScheduledBeforeParaFree: AugmentedError<ApiType>;
            /**
             * Head data exceeds the configured maximum.
             **/
            HeadDataTooLarge: AugmentedError<ApiType>;
            /**
             * The candidate didn't follow the rules of HRMP watermark advancement.
             **/
            HrmpWatermarkMishandling: AugmentedError<ApiType>;
            /**
             * The downward message queue is not processed correctly.
             **/
            IncorrectDownwardMessageHandling: AugmentedError<ApiType>;
            /**
             * Insufficient (non-majority) backing.
             **/
            InsufficientBacking: AugmentedError<ApiType>;
            /**
             * Invalid (bad signature, unknown validator, etc.) backing.
             **/
            InvalidBacking: AugmentedError<ApiType>;
            /**
             * Invalid signature
             **/
            InvalidBitfieldSignature: AugmentedError<ApiType>;
            /**
             * Invalid group index in core assignment.
             **/
            InvalidGroupIndex: AugmentedError<ApiType>;
            /**
             * The HRMP messages sent by the candidate is not valid.
             **/
            InvalidOutboundHrmp: AugmentedError<ApiType>;
            /**
             * At least one upward message sent does not pass the acceptance criteria.
             **/
            InvalidUpwardMessages: AugmentedError<ApiType>;
            /**
             * The validation code hash of the candidate is not valid.
             **/
            InvalidValidationCodeHash: AugmentedError<ApiType>;
            /**
             * Output code is too large
             **/
            NewCodeTooLarge: AugmentedError<ApiType>;
            /**
             * Collator did not sign PoV.
             **/
            NotCollatorSigned: AugmentedError<ApiType>;
            /**
             * The `para_head` hash in the candidate descriptor doesn't match the hash of the actual para head in the
             * commitments.
             **/
            ParaHeadMismatch: AugmentedError<ApiType>;
            /**
             * Code upgrade prematurely.
             **/
            PrematureCodeUpgrade: AugmentedError<ApiType>;
            /**
             * Scheduled cores out of order.
             **/
            ScheduledOutOfOrder: AugmentedError<ApiType>;
            /**
             * Candidate submitted but para not scheduled.
             **/
            UnscheduledCandidate: AugmentedError<ApiType>;
            /**
             * The validation data hash does not match expected.
             **/
            ValidationDataHashMismatch: AugmentedError<ApiType>;
            /**
             * Validator index out of bounds.
             **/
            ValidatorIndexOutOfBounds: AugmentedError<ApiType>;
            /**
             * Availability bitfield has unexpected size.
             **/
            WrongBitfieldSize: AugmentedError<ApiType>;
            /**
             * Candidate included with the wrong collator.
             **/
            WrongCollator: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        paraInherent: {
            /**
             * Disputed candidate that was concluded invalid.
             **/
            CandidateConcludedInvalid: AugmentedError<ApiType>;
            /**
             * The data given to the inherent will result in an overweight block.
             **/
            InherentOverweight: AugmentedError<ApiType>;
            /**
             * The hash of the submitted parent header doesn't correspond to the saved block hash of
             * the parent.
             **/
            InvalidParentHeader: AugmentedError<ApiType>;
            /**
             * Inclusion inherent called more than once per block.
             **/
            TooManyInclusionInherents: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        paras: {
            /**
             * Para cannot be downgraded to a parathread.
             **/
            CannotDowngrade: AugmentedError<ApiType>;
            /**
             * Para cannot be offboarded at this time.
             **/
            CannotOffboard: AugmentedError<ApiType>;
            /**
             * Para cannot be onboarded because it is already tracked by our system.
             **/
            CannotOnboard: AugmentedError<ApiType>;
            /**
             * Para cannot be upgraded to a parachain.
             **/
            CannotUpgrade: AugmentedError<ApiType>;
            /**
             * Para is not registered in our system.
             **/
            NotRegistered: AugmentedError<ApiType>;
            /**
             * The PVF pre-checking statement cannot be included since the PVF pre-checking mechanism
             * is disabled.
             **/
            PvfCheckDisabled: AugmentedError<ApiType>;
            /**
             * The given validator already has cast a vote.
             **/
            PvfCheckDoubleVote: AugmentedError<ApiType>;
            /**
             * The signature for the PVF pre-checking is invalid.
             **/
            PvfCheckInvalidSignature: AugmentedError<ApiType>;
            /**
             * The statement for PVF pre-checking is for a future session.
             **/
            PvfCheckStatementFuture: AugmentedError<ApiType>;
            /**
             * The statement for PVF pre-checking is stale.
             **/
            PvfCheckStatementStale: AugmentedError<ApiType>;
            /**
             * The given PVF does not exist at the moment of process a vote.
             **/
            PvfCheckSubjectInvalid: AugmentedError<ApiType>;
            /**
             * Claimed validator index is out of bounds.
             **/
            PvfCheckValidatorIndexOutOfBounds: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        phragmenElection: {
            /**
             * Duplicated candidate submission.
             **/
            DuplicatedCandidate: AugmentedError<ApiType>;
            /**
             * Candidate does not have enough funds.
             **/
            InsufficientCandidateFunds: AugmentedError<ApiType>;
            /**
             * The renouncing origin presented a wrong `Renouncing` parameter.
             **/
            InvalidRenouncing: AugmentedError<ApiType>;
            /**
             * Prediction regarding replacement after member removal is wrong.
             **/
            InvalidReplacement: AugmentedError<ApiType>;
            /**
             * The provided count of number of votes is incorrect.
             **/
            InvalidVoteCount: AugmentedError<ApiType>;
            /**
             * The provided count of number of candidates is incorrect.
             **/
            InvalidWitnessData: AugmentedError<ApiType>;
            /**
             * Cannot vote with stake less than minimum balance.
             **/
            LowBalance: AugmentedError<ApiType>;
            /**
             * Cannot vote more than maximum allowed.
             **/
            MaximumVotesExceeded: AugmentedError<ApiType>;
            /**
             * Member cannot re-submit candidacy.
             **/
            MemberSubmit: AugmentedError<ApiType>;
            /**
             * Must be a voter.
             **/
            MustBeVoter: AugmentedError<ApiType>;
            /**
             * Not a member.
             **/
            NotMember: AugmentedError<ApiType>;
            /**
             * Must vote for at least one candidate.
             **/
            NoVotes: AugmentedError<ApiType>;
            /**
             * Cannot report self.
             **/
            ReportSelf: AugmentedError<ApiType>;
            /**
             * Runner cannot re-submit candidacy.
             **/
            RunnerUpSubmit: AugmentedError<ApiType>;
            /**
             * Cannot vote more than candidates.
             **/
            TooManyVotes: AugmentedError<ApiType>;
            /**
             * Voter can not pay voting bond.
             **/
            UnableToPayBond: AugmentedError<ApiType>;
            /**
             * Cannot vote when no candidates or members exist.
             **/
            UnableToVote: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        preimage: {
            /**
             * Preimage has already been noted on-chain.
             **/
            AlreadyNoted: AugmentedError<ApiType>;
            /**
             * The user is not authorized to perform this action.
             **/
            NotAuthorized: AugmentedError<ApiType>;
            /**
             * The preimage cannot be removed since it has not yet been noted.
             **/
            NotNoted: AugmentedError<ApiType>;
            /**
             * The preimage request cannot be removed since no outstanding requests exist.
             **/
            NotRequested: AugmentedError<ApiType>;
            /**
             * A preimage may not be removed when there are outstanding requests.
             **/
            Requested: AugmentedError<ApiType>;
            /**
             * Preimage is too large to store on-chain.
             **/
            TooLarge: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        proxy: {
            /**
             * Account is already a proxy.
             **/
            Duplicate: AugmentedError<ApiType>;
            /**
             * Call may not be made by proxy because it may escalate its privileges.
             **/
            NoPermission: AugmentedError<ApiType>;
            /**
             * Cannot add self as proxy.
             **/
            NoSelfProxy: AugmentedError<ApiType>;
            /**
             * Proxy registration not found.
             **/
            NotFound: AugmentedError<ApiType>;
            /**
             * Sender is not a proxy of the account to be proxied.
             **/
            NotProxy: AugmentedError<ApiType>;
            /**
             * There are too many proxies registered or too many announcements pending.
             **/
            TooMany: AugmentedError<ApiType>;
            /**
             * Announcement, if made at all, was made too recently.
             **/
            Unannounced: AugmentedError<ApiType>;
            /**
             * A call which is incompatible with the proxy type's filter was attempted.
             **/
            Unproxyable: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        registrar: {
            /**
             * The ID is already registered.
             **/
            AlreadyRegistered: AugmentedError<ApiType>;
            /**
             * Cannot deregister para
             **/
            CannotDeregister: AugmentedError<ApiType>;
            /**
             * Cannot schedule downgrade of parachain to parathread
             **/
            CannotDowngrade: AugmentedError<ApiType>;
            /**
             * Cannot schedule upgrade of parathread to parachain
             **/
            CannotUpgrade: AugmentedError<ApiType>;
            /**
             * Invalid para code size.
             **/
            CodeTooLarge: AugmentedError<ApiType>;
            /**
             * Registering parachain with empty code is not allowed.
             **/
            EmptyCode: AugmentedError<ApiType>;
            /**
             * Invalid para head data size.
             **/
            HeadDataTooLarge: AugmentedError<ApiType>;
            /**
             * The caller is not the owner of this Id.
             **/
            NotOwner: AugmentedError<ApiType>;
            /**
             * Para is not a Parachain.
             **/
            NotParachain: AugmentedError<ApiType>;
            /**
             * Para is not a Parathread.
             **/
            NotParathread: AugmentedError<ApiType>;
            /**
             * The ID is not registered.
             **/
            NotRegistered: AugmentedError<ApiType>;
            /**
             * The ID given for registration has not been reserved.
             **/
            NotReserved: AugmentedError<ApiType>;
            /**
             * Para is locked from manipulation by the manager. Must use parachain or relay chain governance.
             **/
            ParaLocked: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        scheduler: {
            /**
             * Failed to schedule a call
             **/
            FailedToSchedule: AugmentedError<ApiType>;
            /**
             * Cannot find the scheduled call.
             **/
            NotFound: AugmentedError<ApiType>;
            /**
             * Reschedule failed because it does not change scheduled time.
             **/
            RescheduleNoChange: AugmentedError<ApiType>;
            /**
             * Given target block number is in the past.
             **/
            TargetBlockNumberInPast: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        session: {
            /**
             * Registered duplicate key.
             **/
            DuplicatedKey: AugmentedError<ApiType>;
            /**
             * Invalid ownership proof.
             **/
            InvalidProof: AugmentedError<ApiType>;
            /**
             * Key setting account is not live, so it's impossible to associate keys.
             **/
            NoAccount: AugmentedError<ApiType>;
            /**
             * No associated validator ID for account.
             **/
            NoAssociatedValidatorId: AugmentedError<ApiType>;
            /**
             * No keys are associated with this account.
             **/
            NoKeys: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        slots: {
            /**
             * There was an error with the lease.
             **/
            LeaseError: AugmentedError<ApiType>;
            /**
             * The parachain ID is not onboarding.
             **/
            ParaNotOnboarding: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        staking: {
            /**
             * Stash is already bonded.
             **/
            AlreadyBonded: AugmentedError<ApiType>;
            /**
             * Rewards for this era have already been claimed for this validator.
             **/
            AlreadyClaimed: AugmentedError<ApiType>;
            /**
             * Controller is already paired.
             **/
            AlreadyPaired: AugmentedError<ApiType>;
            /**
             * Internal state has become somehow corrupted and the operation cannot continue.
             **/
            BadState: AugmentedError<ApiType>;
            /**
             * A nomination target was supplied that was blocked or otherwise not a validator.
             **/
            BadTarget: AugmentedError<ApiType>;
            /**
             * The user has enough bond and thus cannot be chilled forcefully by an external person.
             **/
            CannotChillOther: AugmentedError<ApiType>;
            /**
             * Commission is too low. Must be at least `MinCommission`.
             **/
            CommissionTooLow: AugmentedError<ApiType>;
            /**
             * Duplicate index.
             **/
            DuplicateIndex: AugmentedError<ApiType>;
            /**
             * Targets cannot be empty.
             **/
            EmptyTargets: AugmentedError<ApiType>;
            /**
             * Attempting to target a stash that still has funds.
             **/
            FundedTarget: AugmentedError<ApiType>;
            /**
             * Incorrect previous history depth input provided.
             **/
            IncorrectHistoryDepth: AugmentedError<ApiType>;
            /**
             * Incorrect number of slashing spans provided.
             **/
            IncorrectSlashingSpans: AugmentedError<ApiType>;
            /**
             * Cannot have a validator or nominator role, with value less than the minimum defined by
             * governance (see `MinValidatorBond` and `MinNominatorBond`). If unbonding is the
             * intention, `chill` first to remove one's role as validator/nominator.
             **/
            InsufficientBond: AugmentedError<ApiType>;
            /**
             * Invalid era to reward.
             **/
            InvalidEraToReward: AugmentedError<ApiType>;
            /**
             * Invalid number of nominations.
             **/
            InvalidNumberOfNominations: AugmentedError<ApiType>;
            /**
             * Slash record index out of bounds.
             **/
            InvalidSlashIndex: AugmentedError<ApiType>;
            /**
             * Can not schedule more unlock chunks.
             **/
            NoMoreChunks: AugmentedError<ApiType>;
            /**
             * Not a controller account.
             **/
            NotController: AugmentedError<ApiType>;
            /**
             * Items are not sorted and unique.
             **/
            NotSortedAndUnique: AugmentedError<ApiType>;
            /**
             * Not a stash account.
             **/
            NotStash: AugmentedError<ApiType>;
            /**
             * Can not rebond without unlocking chunks.
             **/
            NoUnlockChunk: AugmentedError<ApiType>;
            /**
             * There are too many nominators in the system. Governance needs to adjust the staking
             * settings to keep things safe for the runtime.
             **/
            TooManyNominators: AugmentedError<ApiType>;
            /**
             * Too many nomination targets supplied.
             **/
            TooManyTargets: AugmentedError<ApiType>;
            /**
             * There are too many validators in the system. Governance needs to adjust the staking
             * settings to keep things safe for the runtime.
             **/
            TooManyValidators: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        system: {
            /**
             * The origin filter prevent the call to be dispatched.
             **/
            CallFiltered: AugmentedError<ApiType>;
            /**
             * Failed to extract the runtime version from the new runtime.
             *
             * Either calling `Core_version` or decoding `RuntimeVersion` failed.
             **/
            FailedToExtractRuntimeVersion: AugmentedError<ApiType>;
            /**
             * The name of specification does not match between the current runtime
             * and the new runtime.
             **/
            InvalidSpecName: AugmentedError<ApiType>;
            /**
             * Suicide called when the account has non-default composite data.
             **/
            NonDefaultComposite: AugmentedError<ApiType>;
            /**
             * There is a non-zero reference count preventing the account from being purged.
             **/
            NonZeroRefCount: AugmentedError<ApiType>;
            /**
             * The specification version is not allowed to decrease between the current runtime
             * and the new runtime.
             **/
            SpecVersionNeedsToIncrease: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        technicalCommittee: {
            /**
             * Members are already initialized!
             **/
            AlreadyInitialized: AugmentedError<ApiType>;
            /**
             * Duplicate proposals not allowed
             **/
            DuplicateProposal: AugmentedError<ApiType>;
            /**
             * Duplicate vote ignored
             **/
            DuplicateVote: AugmentedError<ApiType>;
            /**
             * Account is not a member
             **/
            NotMember: AugmentedError<ApiType>;
            /**
             * Proposal must exist
             **/
            ProposalMissing: AugmentedError<ApiType>;
            /**
             * The close call was made too early, before the end of the voting.
             **/
            TooEarly: AugmentedError<ApiType>;
            /**
             * There can only be a maximum of `MaxProposals` active proposals.
             **/
            TooManyProposals: AugmentedError<ApiType>;
            /**
             * Mismatched index
             **/
            WrongIndex: AugmentedError<ApiType>;
            /**
             * The given length bound for the proposal was too low.
             **/
            WrongProposalLength: AugmentedError<ApiType>;
            /**
             * The given weight bound for the proposal was too low.
             **/
            WrongProposalWeight: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        technicalMembership: {
            /**
             * Already a member.
             **/
            AlreadyMember: AugmentedError<ApiType>;
            /**
             * Not a member.
             **/
            NotMember: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        tips: {
            /**
             * The tip was already found/started.
             **/
            AlreadyKnown: AugmentedError<ApiType>;
            /**
             * The account attempting to retract the tip is not the finder of the tip.
             **/
            NotFinder: AugmentedError<ApiType>;
            /**
             * The tip cannot be claimed/closed because it's still in the countdown period.
             **/
            Premature: AugmentedError<ApiType>;
            /**
             * The reason given is just too big.
             **/
            ReasonTooBig: AugmentedError<ApiType>;
            /**
             * The tip cannot be claimed/closed because there are not enough tippers yet.
             **/
            StillOpen: AugmentedError<ApiType>;
            /**
             * The tip hash is unknown.
             **/
            UnknownTip: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        treasury: {
            /**
             * Proposer's balance is too low.
             **/
            InsufficientProposersBalance: AugmentedError<ApiType>;
            /**
             * No proposal or bounty at that index.
             **/
            InvalidIndex: AugmentedError<ApiType>;
            /**
             * Too many approvals in the queue.
             **/
            TooManyApprovals: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        ump: {
            /**
             * The message index given is unknown.
             **/
            UnknownMessageIndex: AugmentedError<ApiType>;
            /**
             * The amount of weight given is possibly not enough for executing the message.
             **/
            WeightOverLimit: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        utility: {
            /**
             * Too many calls batched.
             **/
            TooManyCalls: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        vesting: {
            /**
             * Amount being transferred is too low to create a vesting schedule.
             **/
            AmountLow: AugmentedError<ApiType>;
            /**
             * The account already has `MaxVestingSchedules` count of schedules and thus
             * cannot add another one. Consider merging existing schedules in order to add another.
             **/
            AtMaxVestingSchedules: AugmentedError<ApiType>;
            /**
             * Failed to create a new schedule because some parameter was invalid.
             **/
            InvalidScheduleParams: AugmentedError<ApiType>;
            /**
             * The account given is not vesting.
             **/
            NotVesting: AugmentedError<ApiType>;
            /**
             * An index was out of bounds of the vesting schedules.
             **/
            ScheduleIndexOutOfBounds: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
        xcmPallet: {
            /**
             * The location is invalid since it already has a subscription from us.
             **/
            AlreadySubscribed: AugmentedError<ApiType>;
            /**
             * The given location could not be used (e.g. because it cannot be expressed in the
             * desired version of XCM).
             **/
            BadLocation: AugmentedError<ApiType>;
            /**
             * The version of the `Versioned` value used is not able to be interpreted.
             **/
            BadVersion: AugmentedError<ApiType>;
            /**
             * Could not re-anchor the assets to declare the fees for the destination chain.
             **/
            CannotReanchor: AugmentedError<ApiType>;
            /**
             * The destination `MultiLocation` provided cannot be inverted.
             **/
            DestinationNotInvertible: AugmentedError<ApiType>;
            /**
             * The assets to be sent are empty.
             **/
            Empty: AugmentedError<ApiType>;
            /**
             * The message execution fails the filter.
             **/
            Filtered: AugmentedError<ApiType>;
            /**
             * Origin is invalid for sending.
             **/
            InvalidOrigin: AugmentedError<ApiType>;
            /**
             * The referenced subscription could not be found.
             **/
            NoSubscription: AugmentedError<ApiType>;
            /**
             * There was some other issue (i.e. not to do with routing) in sending the message. Perhaps
             * a lack of space for buffering the message.
             **/
            SendFailure: AugmentedError<ApiType>;
            /**
             * Too many assets have been attempted for transfer.
             **/
            TooManyAssets: AugmentedError<ApiType>;
            /**
             * The desired destination was unreachable, generally because there is a no way of routing
             * to it.
             **/
            Unreachable: AugmentedError<ApiType>;
            /**
             * The message's weight could not be determined.
             **/
            UnweighableMessage: AugmentedError<ApiType>;
            /**
             * Generic error
             **/
            [key: string]: AugmentedError<ApiType>;
        };
    }
}
