declare module '@polkadot/types/lookup' {
    import type { Data } from '@polkadot/types';
    import type { BTreeMap, Bytes, Compact, Enum, Null, Option, Result, Set, Struct, Text, U8aFixed, Vec, WrapperKeepOpaque, bool, u128, u16, u32, u64, u8 } from '@polkadot/types-codec';
    import type { ITuple } from '@polkadot/types-codec/types';
    import type { Vote } from '@polkadot/types/interfaces/elections';
    import type { AccountId32, Call, H256, MultiAddress, PerU16, Perbill, Percent, Perquintill } from '@polkadot/types/interfaces/runtime';
    import type { Event } from '@polkadot/types/interfaces/system';
    /** @name FrameSystemAccountInfo (3) */
    interface FrameSystemAccountInfo extends Struct {
        readonly nonce: u32;
        readonly consumers: u32;
        readonly providers: u32;
        readonly sufficients: u32;
        readonly data: PalletBalancesAccountData;
    }
    /** @name PalletBalancesAccountData (5) */
    interface PalletBalancesAccountData extends Struct {
        readonly free: u128;
        readonly reserved: u128;
        readonly miscFrozen: u128;
        readonly feeFrozen: u128;
    }
    /** @name FrameSupportWeightsPerDispatchClassU64 (7) */
    interface FrameSupportWeightsPerDispatchClassU64 extends Struct {
        readonly normal: u64;
        readonly operational: u64;
        readonly mandatory: u64;
    }
    /** @name SpRuntimeDigest (11) */
    interface SpRuntimeDigest extends Struct {
        readonly logs: Vec<SpRuntimeDigestDigestItem>;
    }
    /** @name SpRuntimeDigestDigestItem (13) */
    interface SpRuntimeDigestDigestItem extends Enum {
        readonly isOther: boolean;
        readonly asOther: Bytes;
        readonly isConsensus: boolean;
        readonly asConsensus: ITuple<[U8aFixed, Bytes]>;
        readonly isSeal: boolean;
        readonly asSeal: ITuple<[U8aFixed, Bytes]>;
        readonly isPreRuntime: boolean;
        readonly asPreRuntime: ITuple<[U8aFixed, Bytes]>;
        readonly isRuntimeEnvironmentUpdated: boolean;
        readonly type: 'Other' | 'Consensus' | 'Seal' | 'PreRuntime' | 'RuntimeEnvironmentUpdated';
    }
    /** @name FrameSystemEventRecord (16) */
    interface FrameSystemEventRecord extends Struct {
        readonly phase: FrameSystemPhase;
        readonly event: Event;
        readonly topics: Vec<H256>;
    }
    /** @name FrameSystemEvent (18) */
    interface FrameSystemEvent extends Enum {
        readonly isExtrinsicSuccess: boolean;
        readonly asExtrinsicSuccess: {
            readonly dispatchInfo: FrameSupportWeightsDispatchInfo;
        } & Struct;
        readonly isExtrinsicFailed: boolean;
        readonly asExtrinsicFailed: {
            readonly dispatchError: SpRuntimeDispatchError;
            readonly dispatchInfo: FrameSupportWeightsDispatchInfo;
        } & Struct;
        readonly isCodeUpdated: boolean;
        readonly isNewAccount: boolean;
        readonly asNewAccount: {
            readonly account: AccountId32;
        } & Struct;
        readonly isKilledAccount: boolean;
        readonly asKilledAccount: {
            readonly account: AccountId32;
        } & Struct;
        readonly isRemarked: boolean;
        readonly asRemarked: {
            readonly sender: AccountId32;
            readonly hash_: H256;
        } & Struct;
        readonly type: 'ExtrinsicSuccess' | 'ExtrinsicFailed' | 'CodeUpdated' | 'NewAccount' | 'KilledAccount' | 'Remarked';
    }
    /** @name FrameSupportWeightsDispatchInfo (19) */
    interface FrameSupportWeightsDispatchInfo extends Struct {
        readonly weight: u64;
        readonly class: FrameSupportWeightsDispatchClass;
        readonly paysFee: FrameSupportWeightsPays;
    }
    /** @name FrameSupportWeightsDispatchClass (20) */
    interface FrameSupportWeightsDispatchClass extends Enum {
        readonly isNormal: boolean;
        readonly isOperational: boolean;
        readonly isMandatory: boolean;
        readonly type: 'Normal' | 'Operational' | 'Mandatory';
    }
    /** @name FrameSupportWeightsPays (21) */
    interface FrameSupportWeightsPays extends Enum {
        readonly isYes: boolean;
        readonly isNo: boolean;
        readonly type: 'Yes' | 'No';
    }
    /** @name SpRuntimeDispatchError (22) */
    interface SpRuntimeDispatchError extends Enum {
        readonly isOther: boolean;
        readonly isCannotLookup: boolean;
        readonly isBadOrigin: boolean;
        readonly isModule: boolean;
        readonly asModule: {
            readonly index: u8;
            readonly error: u8;
        } & Struct;
        readonly isConsumerRemaining: boolean;
        readonly isNoProviders: boolean;
        readonly isTooManyConsumers: boolean;
        readonly isToken: boolean;
        readonly asToken: SpRuntimeTokenError;
        readonly isArithmetic: boolean;
        readonly asArithmetic: SpRuntimeArithmeticError;
        readonly type: 'Other' | 'CannotLookup' | 'BadOrigin' | 'Module' | 'ConsumerRemaining' | 'NoProviders' | 'TooManyConsumers' | 'Token' | 'Arithmetic';
    }
    /** @name SpRuntimeTokenError (23) */
    interface SpRuntimeTokenError extends Enum {
        readonly isNoFunds: boolean;
        readonly isWouldDie: boolean;
        readonly isBelowMinimum: boolean;
        readonly isCannotCreate: boolean;
        readonly isUnknownAsset: boolean;
        readonly isFrozen: boolean;
        readonly isUnsupported: boolean;
        readonly type: 'NoFunds' | 'WouldDie' | 'BelowMinimum' | 'CannotCreate' | 'UnknownAsset' | 'Frozen' | 'Unsupported';
    }
    /** @name SpRuntimeArithmeticError (24) */
    interface SpRuntimeArithmeticError extends Enum {
        readonly isUnderflow: boolean;
        readonly isOverflow: boolean;
        readonly isDivisionByZero: boolean;
        readonly type: 'Underflow' | 'Overflow' | 'DivisionByZero';
    }
    /** @name PalletUtilityEvent (25) */
    interface PalletUtilityEvent extends Enum {
        readonly isBatchInterrupted: boolean;
        readonly asBatchInterrupted: {
            readonly index: u32;
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly isBatchCompleted: boolean;
        readonly isItemCompleted: boolean;
        readonly isDispatchedAs: boolean;
        readonly asDispatchedAs: {
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly type: 'BatchInterrupted' | 'BatchCompleted' | 'ItemCompleted' | 'DispatchedAs';
    }
    /** @name PalletIndicesEvent (28) */
    interface PalletIndicesEvent extends Enum {
        readonly isIndexAssigned: boolean;
        readonly asIndexAssigned: {
            readonly who: AccountId32;
            readonly index: u32;
        } & Struct;
        readonly isIndexFreed: boolean;
        readonly asIndexFreed: {
            readonly index: u32;
        } & Struct;
        readonly isIndexFrozen: boolean;
        readonly asIndexFrozen: {
            readonly index: u32;
            readonly who: AccountId32;
        } & Struct;
        readonly type: 'IndexAssigned' | 'IndexFreed' | 'IndexFrozen';
    }
    /** @name PalletBalancesEvent (29) */
    interface PalletBalancesEvent extends Enum {
        readonly isEndowed: boolean;
        readonly asEndowed: {
            readonly account: AccountId32;
            readonly freeBalance: u128;
        } & Struct;
        readonly isDustLost: boolean;
        readonly asDustLost: {
            readonly account: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly from: AccountId32;
            readonly to: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isBalanceSet: boolean;
        readonly asBalanceSet: {
            readonly who: AccountId32;
            readonly free: u128;
            readonly reserved: u128;
        } & Struct;
        readonly isReserved: boolean;
        readonly asReserved: {
            readonly who: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isUnreserved: boolean;
        readonly asUnreserved: {
            readonly who: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isReserveRepatriated: boolean;
        readonly asReserveRepatriated: {
            readonly from: AccountId32;
            readonly to: AccountId32;
            readonly amount: u128;
            readonly destinationStatus: FrameSupportTokensMiscBalanceStatus;
        } & Struct;
        readonly isDeposit: boolean;
        readonly asDeposit: {
            readonly who: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isWithdraw: boolean;
        readonly asWithdraw: {
            readonly who: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isSlashed: boolean;
        readonly asSlashed: {
            readonly who: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly type: 'Endowed' | 'DustLost' | 'Transfer' | 'BalanceSet' | 'Reserved' | 'Unreserved' | 'ReserveRepatriated' | 'Deposit' | 'Withdraw' | 'Slashed';
    }
    /** @name FrameSupportTokensMiscBalanceStatus (30) */
    interface FrameSupportTokensMiscBalanceStatus extends Enum {
        readonly isFree: boolean;
        readonly isReserved: boolean;
        readonly type: 'Free' | 'Reserved';
    }
    /** @name PalletElectionProviderMultiPhaseEvent (31) */
    interface PalletElectionProviderMultiPhaseEvent extends Enum {
        readonly isSolutionStored: boolean;
        readonly asSolutionStored: {
            readonly electionCompute: PalletElectionProviderMultiPhaseElectionCompute;
            readonly prevEjected: bool;
        } & Struct;
        readonly isElectionFinalized: boolean;
        readonly asElectionFinalized: {
            readonly electionCompute: Option<PalletElectionProviderMultiPhaseElectionCompute>;
        } & Struct;
        readonly isRewarded: boolean;
        readonly asRewarded: {
            readonly account: AccountId32;
            readonly value: u128;
        } & Struct;
        readonly isSlashed: boolean;
        readonly asSlashed: {
            readonly account: AccountId32;
            readonly value: u128;
        } & Struct;
        readonly isSignedPhaseStarted: boolean;
        readonly asSignedPhaseStarted: {
            readonly round: u32;
        } & Struct;
        readonly isUnsignedPhaseStarted: boolean;
        readonly asUnsignedPhaseStarted: {
            readonly round: u32;
        } & Struct;
        readonly type: 'SolutionStored' | 'ElectionFinalized' | 'Rewarded' | 'Slashed' | 'SignedPhaseStarted' | 'UnsignedPhaseStarted';
    }
    /** @name PalletElectionProviderMultiPhaseElectionCompute (32) */
    interface PalletElectionProviderMultiPhaseElectionCompute extends Enum {
        readonly isOnChain: boolean;
        readonly isSigned: boolean;
        readonly isUnsigned: boolean;
        readonly isFallback: boolean;
        readonly isEmergency: boolean;
        readonly type: 'OnChain' | 'Signed' | 'Unsigned' | 'Fallback' | 'Emergency';
    }
    /** @name PalletStakingPalletEvent (35) */
    interface PalletStakingPalletEvent extends Enum {
        readonly isEraPaid: boolean;
        readonly asEraPaid: ITuple<[u32, u128, u128]>;
        readonly isRewarded: boolean;
        readonly asRewarded: ITuple<[AccountId32, u128]>;
        readonly isSlashed: boolean;
        readonly asSlashed: ITuple<[AccountId32, u128]>;
        readonly isOldSlashingReportDiscarded: boolean;
        readonly asOldSlashingReportDiscarded: u32;
        readonly isStakersElected: boolean;
        readonly isBonded: boolean;
        readonly asBonded: ITuple<[AccountId32, u128]>;
        readonly isUnbonded: boolean;
        readonly asUnbonded: ITuple<[AccountId32, u128]>;
        readonly isWithdrawn: boolean;
        readonly asWithdrawn: ITuple<[AccountId32, u128]>;
        readonly isKicked: boolean;
        readonly asKicked: ITuple<[AccountId32, AccountId32]>;
        readonly isStakingElectionFailed: boolean;
        readonly isChilled: boolean;
        readonly asChilled: AccountId32;
        readonly isPayoutStarted: boolean;
        readonly asPayoutStarted: ITuple<[u32, AccountId32]>;
        readonly type: 'EraPaid' | 'Rewarded' | 'Slashed' | 'OldSlashingReportDiscarded' | 'StakersElected' | 'Bonded' | 'Unbonded' | 'Withdrawn' | 'Kicked' | 'StakingElectionFailed' | 'Chilled' | 'PayoutStarted';
    }
    /** @name PalletSessionEvent (36) */
    interface PalletSessionEvent extends Enum {
        readonly isNewSession: boolean;
        readonly asNewSession: {
            readonly sessionIndex: u32;
        } & Struct;
        readonly type: 'NewSession';
    }
    /** @name PalletDemocracyEvent (37) */
    interface PalletDemocracyEvent extends Enum {
        readonly isProposed: boolean;
        readonly asProposed: {
            readonly proposalIndex: u32;
            readonly deposit: u128;
        } & Struct;
        readonly isTabled: boolean;
        readonly asTabled: {
            readonly proposalIndex: u32;
            readonly deposit: u128;
            readonly depositors: Vec<AccountId32>;
        } & Struct;
        readonly isExternalTabled: boolean;
        readonly isStarted: boolean;
        readonly asStarted: {
            readonly refIndex: u32;
            readonly threshold: PalletDemocracyVoteThreshold;
        } & Struct;
        readonly isPassed: boolean;
        readonly asPassed: {
            readonly refIndex: u32;
        } & Struct;
        readonly isNotPassed: boolean;
        readonly asNotPassed: {
            readonly refIndex: u32;
        } & Struct;
        readonly isCancelled: boolean;
        readonly asCancelled: {
            readonly refIndex: u32;
        } & Struct;
        readonly isExecuted: boolean;
        readonly asExecuted: {
            readonly refIndex: u32;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isDelegated: boolean;
        readonly asDelegated: {
            readonly who: AccountId32;
            readonly target: AccountId32;
        } & Struct;
        readonly isUndelegated: boolean;
        readonly asUndelegated: {
            readonly account: AccountId32;
        } & Struct;
        readonly isVetoed: boolean;
        readonly asVetoed: {
            readonly who: AccountId32;
            readonly proposalHash: H256;
            readonly until: u32;
        } & Struct;
        readonly isPreimageNoted: boolean;
        readonly asPreimageNoted: {
            readonly proposalHash: H256;
            readonly who: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly isPreimageUsed: boolean;
        readonly asPreimageUsed: {
            readonly proposalHash: H256;
            readonly provider: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly isPreimageInvalid: boolean;
        readonly asPreimageInvalid: {
            readonly proposalHash: H256;
            readonly refIndex: u32;
        } & Struct;
        readonly isPreimageMissing: boolean;
        readonly asPreimageMissing: {
            readonly proposalHash: H256;
            readonly refIndex: u32;
        } & Struct;
        readonly isPreimageReaped: boolean;
        readonly asPreimageReaped: {
            readonly proposalHash: H256;
            readonly provider: AccountId32;
            readonly deposit: u128;
            readonly reaper: AccountId32;
        } & Struct;
        readonly isBlacklisted: boolean;
        readonly asBlacklisted: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isVoted: boolean;
        readonly asVoted: {
            readonly voter: AccountId32;
            readonly refIndex: u32;
            readonly vote: PalletDemocracyVoteAccountVote;
        } & Struct;
        readonly isSeconded: boolean;
        readonly asSeconded: {
            readonly seconder: AccountId32;
            readonly propIndex: u32;
        } & Struct;
        readonly type: 'Proposed' | 'Tabled' | 'ExternalTabled' | 'Started' | 'Passed' | 'NotPassed' | 'Cancelled' | 'Executed' | 'Delegated' | 'Undelegated' | 'Vetoed' | 'PreimageNoted' | 'PreimageUsed' | 'PreimageInvalid' | 'PreimageMissing' | 'PreimageReaped' | 'Blacklisted' | 'Voted' | 'Seconded';
    }
    /** @name PalletDemocracyVoteThreshold (39) */
    interface PalletDemocracyVoteThreshold extends Enum {
        readonly isSuperMajorityApprove: boolean;
        readonly isSuperMajorityAgainst: boolean;
        readonly isSimpleMajority: boolean;
        readonly type: 'SuperMajorityApprove' | 'SuperMajorityAgainst' | 'SimpleMajority';
    }
    /** @name PalletDemocracyVoteAccountVote (40) */
    interface PalletDemocracyVoteAccountVote extends Enum {
        readonly isStandard: boolean;
        readonly asStandard: {
            readonly vote: Vote;
            readonly balance: u128;
        } & Struct;
        readonly isSplit: boolean;
        readonly asSplit: {
            readonly aye: u128;
            readonly nay: u128;
        } & Struct;
        readonly type: 'Standard' | 'Split';
    }
    /** @name PalletCollectiveEvent (42) */
    interface PalletCollectiveEvent extends Enum {
        readonly isProposed: boolean;
        readonly asProposed: {
            readonly account: AccountId32;
            readonly proposalIndex: u32;
            readonly proposalHash: H256;
            readonly threshold: u32;
        } & Struct;
        readonly isVoted: boolean;
        readonly asVoted: {
            readonly account: AccountId32;
            readonly proposalHash: H256;
            readonly voted: bool;
            readonly yes: u32;
            readonly no: u32;
        } & Struct;
        readonly isApproved: boolean;
        readonly asApproved: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isDisapproved: boolean;
        readonly asDisapproved: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isExecuted: boolean;
        readonly asExecuted: {
            readonly proposalHash: H256;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isMemberExecuted: boolean;
        readonly asMemberExecuted: {
            readonly proposalHash: H256;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isClosed: boolean;
        readonly asClosed: {
            readonly proposalHash: H256;
            readonly yes: u32;
            readonly no: u32;
        } & Struct;
        readonly type: 'Proposed' | 'Voted' | 'Approved' | 'Disapproved' | 'Executed' | 'MemberExecuted' | 'Closed';
    }
    /** @name PalletElectionsPhragmenEvent (44) */
    interface PalletElectionsPhragmenEvent extends Enum {
        readonly isNewTerm: boolean;
        readonly asNewTerm: {
            readonly newMembers: Vec<ITuple<[AccountId32, u128]>>;
        } & Struct;
        readonly isEmptyTerm: boolean;
        readonly isElectionError: boolean;
        readonly isMemberKicked: boolean;
        readonly asMemberKicked: {
            readonly member: AccountId32;
        } & Struct;
        readonly isRenounced: boolean;
        readonly asRenounced: {
            readonly candidate: AccountId32;
        } & Struct;
        readonly isCandidateSlashed: boolean;
        readonly asCandidateSlashed: {
            readonly candidate: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isSeatHolderSlashed: boolean;
        readonly asSeatHolderSlashed: {
            readonly seatHolder: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly type: 'NewTerm' | 'EmptyTerm' | 'ElectionError' | 'MemberKicked' | 'Renounced' | 'CandidateSlashed' | 'SeatHolderSlashed';
    }
    /** @name PalletMembershipEvent (47) */
    interface PalletMembershipEvent extends Enum {
        readonly isMemberAdded: boolean;
        readonly isMemberRemoved: boolean;
        readonly isMembersSwapped: boolean;
        readonly isMembersReset: boolean;
        readonly isKeyChanged: boolean;
        readonly isDummy: boolean;
        readonly type: 'MemberAdded' | 'MemberRemoved' | 'MembersSwapped' | 'MembersReset' | 'KeyChanged' | 'Dummy';
    }
    /** @name PalletGrandpaEvent (48) */
    interface PalletGrandpaEvent extends Enum {
        readonly isNewAuthorities: boolean;
        readonly asNewAuthorities: {
            readonly authoritySet: Vec<ITuple<[SpFinalityGrandpaAppPublic, u64]>>;
        } & Struct;
        readonly isPaused: boolean;
        readonly isResumed: boolean;
        readonly type: 'NewAuthorities' | 'Paused' | 'Resumed';
    }
    /** @name SpFinalityGrandpaAppPublic (51) */
    interface SpFinalityGrandpaAppPublic extends SpCoreEd25519Public {
    }
    /** @name SpCoreEd25519Public (52) */
    interface SpCoreEd25519Public extends U8aFixed {
    }
    /** @name PalletTreasuryEvent (53) */
    interface PalletTreasuryEvent extends Enum {
        readonly isProposed: boolean;
        readonly asProposed: {
            readonly proposalIndex: u32;
        } & Struct;
        readonly isSpending: boolean;
        readonly asSpending: {
            readonly budgetRemaining: u128;
        } & Struct;
        readonly isAwarded: boolean;
        readonly asAwarded: {
            readonly proposalIndex: u32;
            readonly award: u128;
            readonly account: AccountId32;
        } & Struct;
        readonly isRejected: boolean;
        readonly asRejected: {
            readonly proposalIndex: u32;
            readonly slashed: u128;
        } & Struct;
        readonly isBurnt: boolean;
        readonly asBurnt: {
            readonly burntFunds: u128;
        } & Struct;
        readonly isRollover: boolean;
        readonly asRollover: {
            readonly rolloverBalance: u128;
        } & Struct;
        readonly isDeposit: boolean;
        readonly asDeposit: {
            readonly value: u128;
        } & Struct;
        readonly type: 'Proposed' | 'Spending' | 'Awarded' | 'Rejected' | 'Burnt' | 'Rollover' | 'Deposit';
    }
    /** @name PalletContractsEvent (54) */
    interface PalletContractsEvent extends Enum {
        readonly isInstantiated: boolean;
        readonly asInstantiated: {
            readonly deployer: AccountId32;
            readonly contract: AccountId32;
        } & Struct;
        readonly isTerminated: boolean;
        readonly asTerminated: {
            readonly contract: AccountId32;
            readonly beneficiary: AccountId32;
        } & Struct;
        readonly isCodeStored: boolean;
        readonly asCodeStored: {
            readonly codeHash: H256;
        } & Struct;
        readonly isContractEmitted: boolean;
        readonly asContractEmitted: {
            readonly contract: AccountId32;
            readonly data: Bytes;
        } & Struct;
        readonly isCodeRemoved: boolean;
        readonly asCodeRemoved: {
            readonly codeHash: H256;
        } & Struct;
        readonly type: 'Instantiated' | 'Terminated' | 'CodeStored' | 'ContractEmitted' | 'CodeRemoved';
    }
    /** @name PalletSudoEvent (55) */
    interface PalletSudoEvent extends Enum {
        readonly isSudid: boolean;
        readonly asSudid: {
            readonly sudoResult: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isKeyChanged: boolean;
        readonly asKeyChanged: {
            readonly oldSudoer: Option<AccountId32>;
        } & Struct;
        readonly isSudoAsDone: boolean;
        readonly asSudoAsDone: {
            readonly sudoResult: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly type: 'Sudid' | 'KeyChanged' | 'SudoAsDone';
    }
    /** @name PalletImOnlineEvent (57) */
    interface PalletImOnlineEvent extends Enum {
        readonly isHeartbeatReceived: boolean;
        readonly asHeartbeatReceived: {
            readonly authorityId: PalletImOnlineSr25519AppSr25519Public;
        } & Struct;
        readonly isAllGood: boolean;
        readonly isSomeOffline: boolean;
        readonly asSomeOffline: {
            readonly offline: Vec<ITuple<[AccountId32, PalletStakingExposure]>>;
        } & Struct;
        readonly type: 'HeartbeatReceived' | 'AllGood' | 'SomeOffline';
    }
    /** @name PalletImOnlineSr25519AppSr25519Public (58) */
    interface PalletImOnlineSr25519AppSr25519Public extends SpCoreSr25519Public {
    }
    /** @name SpCoreSr25519Public (59) */
    interface SpCoreSr25519Public extends U8aFixed {
    }
    /** @name PalletStakingExposure (62) */
    interface PalletStakingExposure extends Struct {
        readonly total: Compact<u128>;
        readonly own: Compact<u128>;
        readonly others: Vec<PalletStakingIndividualExposure>;
    }
    /** @name PalletStakingIndividualExposure (65) */
    interface PalletStakingIndividualExposure extends Struct {
        readonly who: AccountId32;
        readonly value: Compact<u128>;
    }
    /** @name PalletOffencesEvent (66) */
    interface PalletOffencesEvent extends Enum {
        readonly isOffence: boolean;
        readonly asOffence: {
            readonly kind: U8aFixed;
            readonly timeslot: Bytes;
        } & Struct;
        readonly type: 'Offence';
    }
    /** @name PalletIdentityEvent (68) */
    interface PalletIdentityEvent extends Enum {
        readonly isIdentitySet: boolean;
        readonly asIdentitySet: {
            readonly who: AccountId32;
        } & Struct;
        readonly isIdentityCleared: boolean;
        readonly asIdentityCleared: {
            readonly who: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly isIdentityKilled: boolean;
        readonly asIdentityKilled: {
            readonly who: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly isJudgementRequested: boolean;
        readonly asJudgementRequested: {
            readonly who: AccountId32;
            readonly registrarIndex: u32;
        } & Struct;
        readonly isJudgementUnrequested: boolean;
        readonly asJudgementUnrequested: {
            readonly who: AccountId32;
            readonly registrarIndex: u32;
        } & Struct;
        readonly isJudgementGiven: boolean;
        readonly asJudgementGiven: {
            readonly target: AccountId32;
            readonly registrarIndex: u32;
        } & Struct;
        readonly isRegistrarAdded: boolean;
        readonly asRegistrarAdded: {
            readonly registrarIndex: u32;
        } & Struct;
        readonly isSubIdentityAdded: boolean;
        readonly asSubIdentityAdded: {
            readonly sub: AccountId32;
            readonly main: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly isSubIdentityRemoved: boolean;
        readonly asSubIdentityRemoved: {
            readonly sub: AccountId32;
            readonly main: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly isSubIdentityRevoked: boolean;
        readonly asSubIdentityRevoked: {
            readonly sub: AccountId32;
            readonly main: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly type: 'IdentitySet' | 'IdentityCleared' | 'IdentityKilled' | 'JudgementRequested' | 'JudgementUnrequested' | 'JudgementGiven' | 'RegistrarAdded' | 'SubIdentityAdded' | 'SubIdentityRemoved' | 'SubIdentityRevoked';
    }
    /** @name PalletSocietyEvent (69) */
    interface PalletSocietyEvent extends Enum {
        readonly isFounded: boolean;
        readonly asFounded: {
            readonly founder: AccountId32;
        } & Struct;
        readonly isBid: boolean;
        readonly asBid: {
            readonly candidateId: AccountId32;
            readonly offer: u128;
        } & Struct;
        readonly isVouch: boolean;
        readonly asVouch: {
            readonly candidateId: AccountId32;
            readonly offer: u128;
            readonly vouching: AccountId32;
        } & Struct;
        readonly isAutoUnbid: boolean;
        readonly asAutoUnbid: {
            readonly candidate: AccountId32;
        } & Struct;
        readonly isUnbid: boolean;
        readonly asUnbid: {
            readonly candidate: AccountId32;
        } & Struct;
        readonly isUnvouch: boolean;
        readonly asUnvouch: {
            readonly candidate: AccountId32;
        } & Struct;
        readonly isInducted: boolean;
        readonly asInducted: {
            readonly primary: AccountId32;
            readonly candidates: Vec<AccountId32>;
        } & Struct;
        readonly isSuspendedMemberJudgement: boolean;
        readonly asSuspendedMemberJudgement: {
            readonly who: AccountId32;
            readonly judged: bool;
        } & Struct;
        readonly isCandidateSuspended: boolean;
        readonly asCandidateSuspended: {
            readonly candidate: AccountId32;
        } & Struct;
        readonly isMemberSuspended: boolean;
        readonly asMemberSuspended: {
            readonly member: AccountId32;
        } & Struct;
        readonly isChallenged: boolean;
        readonly asChallenged: {
            readonly member: AccountId32;
        } & Struct;
        readonly isVote: boolean;
        readonly asVote: {
            readonly candidate: AccountId32;
            readonly voter: AccountId32;
            readonly vote: bool;
        } & Struct;
        readonly isDefenderVote: boolean;
        readonly asDefenderVote: {
            readonly voter: AccountId32;
            readonly vote: bool;
        } & Struct;
        readonly isNewMaxMembers: boolean;
        readonly asNewMaxMembers: {
            readonly max: u32;
        } & Struct;
        readonly isUnfounded: boolean;
        readonly asUnfounded: {
            readonly founder: AccountId32;
        } & Struct;
        readonly isDeposit: boolean;
        readonly asDeposit: {
            readonly value: u128;
        } & Struct;
        readonly type: 'Founded' | 'Bid' | 'Vouch' | 'AutoUnbid' | 'Unbid' | 'Unvouch' | 'Inducted' | 'SuspendedMemberJudgement' | 'CandidateSuspended' | 'MemberSuspended' | 'Challenged' | 'Vote' | 'DefenderVote' | 'NewMaxMembers' | 'Unfounded' | 'Deposit';
    }
    /** @name PalletRecoveryEvent (70) */
    interface PalletRecoveryEvent extends Enum {
        readonly isRecoveryCreated: boolean;
        readonly asRecoveryCreated: {
            readonly account: AccountId32;
        } & Struct;
        readonly isRecoveryInitiated: boolean;
        readonly asRecoveryInitiated: {
            readonly lostAccount: AccountId32;
            readonly rescuerAccount: AccountId32;
        } & Struct;
        readonly isRecoveryVouched: boolean;
        readonly asRecoveryVouched: {
            readonly lostAccount: AccountId32;
            readonly rescuerAccount: AccountId32;
            readonly sender: AccountId32;
        } & Struct;
        readonly isRecoveryClosed: boolean;
        readonly asRecoveryClosed: {
            readonly lostAccount: AccountId32;
            readonly rescuerAccount: AccountId32;
        } & Struct;
        readonly isAccountRecovered: boolean;
        readonly asAccountRecovered: {
            readonly lostAccount: AccountId32;
            readonly rescuerAccount: AccountId32;
        } & Struct;
        readonly isRecoveryRemoved: boolean;
        readonly asRecoveryRemoved: {
            readonly lostAccount: AccountId32;
        } & Struct;
        readonly type: 'RecoveryCreated' | 'RecoveryInitiated' | 'RecoveryVouched' | 'RecoveryClosed' | 'AccountRecovered' | 'RecoveryRemoved';
    }
    /** @name PalletVestingEvent (71) */
    interface PalletVestingEvent extends Enum {
        readonly isVestingUpdated: boolean;
        readonly asVestingUpdated: {
            readonly account: AccountId32;
            readonly unvested: u128;
        } & Struct;
        readonly isVestingCompleted: boolean;
        readonly asVestingCompleted: {
            readonly account: AccountId32;
        } & Struct;
        readonly type: 'VestingUpdated' | 'VestingCompleted';
    }
    /** @name PalletSchedulerEvent (72) */
    interface PalletSchedulerEvent extends Enum {
        readonly isScheduled: boolean;
        readonly asScheduled: {
            readonly when: u32;
            readonly index: u32;
        } & Struct;
        readonly isCanceled: boolean;
        readonly asCanceled: {
            readonly when: u32;
            readonly index: u32;
        } & Struct;
        readonly isDispatched: boolean;
        readonly asDispatched: {
            readonly task: ITuple<[u32, u32]>;
            readonly id: Option<Bytes>;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isCallLookupFailed: boolean;
        readonly asCallLookupFailed: {
            readonly task: ITuple<[u32, u32]>;
            readonly id: Option<Bytes>;
            readonly error: FrameSupportScheduleLookupError;
        } & Struct;
        readonly type: 'Scheduled' | 'Canceled' | 'Dispatched' | 'CallLookupFailed';
    }
    /** @name FrameSupportScheduleLookupError (75) */
    interface FrameSupportScheduleLookupError extends Enum {
        readonly isUnknown: boolean;
        readonly isBadFormat: boolean;
        readonly type: 'Unknown' | 'BadFormat';
    }
    /** @name PalletPreimageEvent (76) */
    interface PalletPreimageEvent extends Enum {
        readonly isNoted: boolean;
        readonly asNoted: {
            readonly hash_: H256;
        } & Struct;
        readonly isRequested: boolean;
        readonly asRequested: {
            readonly hash_: H256;
        } & Struct;
        readonly isCleared: boolean;
        readonly asCleared: {
            readonly hash_: H256;
        } & Struct;
        readonly type: 'Noted' | 'Requested' | 'Cleared';
    }
    /** @name PalletProxyEvent (77) */
    interface PalletProxyEvent extends Enum {
        readonly isProxyExecuted: boolean;
        readonly asProxyExecuted: {
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isAnonymousCreated: boolean;
        readonly asAnonymousCreated: {
            readonly anonymous: AccountId32;
            readonly who: AccountId32;
            readonly proxyType: NodeRuntimeProxyType;
            readonly disambiguationIndex: u16;
        } & Struct;
        readonly isAnnounced: boolean;
        readonly asAnnounced: {
            readonly real: AccountId32;
            readonly proxy: AccountId32;
            readonly callHash: H256;
        } & Struct;
        readonly isProxyAdded: boolean;
        readonly asProxyAdded: {
            readonly delegator: AccountId32;
            readonly delegatee: AccountId32;
            readonly proxyType: NodeRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly type: 'ProxyExecuted' | 'AnonymousCreated' | 'Announced' | 'ProxyAdded';
    }
    /** @name NodeRuntimeProxyType (78) */
    interface NodeRuntimeProxyType extends Enum {
        readonly isAny: boolean;
        readonly isNonTransfer: boolean;
        readonly isGovernance: boolean;
        readonly isStaking: boolean;
        readonly type: 'Any' | 'NonTransfer' | 'Governance' | 'Staking';
    }
    /** @name PalletMultisigEvent (80) */
    interface PalletMultisigEvent extends Enum {
        readonly isNewMultisig: boolean;
        readonly asNewMultisig: {
            readonly approving: AccountId32;
            readonly multisig: AccountId32;
            readonly callHash: U8aFixed;
        } & Struct;
        readonly isMultisigApproval: boolean;
        readonly asMultisigApproval: {
            readonly approving: AccountId32;
            readonly timepoint: PalletMultisigTimepoint;
            readonly multisig: AccountId32;
            readonly callHash: U8aFixed;
        } & Struct;
        readonly isMultisigExecuted: boolean;
        readonly asMultisigExecuted: {
            readonly approving: AccountId32;
            readonly timepoint: PalletMultisigTimepoint;
            readonly multisig: AccountId32;
            readonly callHash: U8aFixed;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isMultisigCancelled: boolean;
        readonly asMultisigCancelled: {
            readonly cancelling: AccountId32;
            readonly timepoint: PalletMultisigTimepoint;
            readonly multisig: AccountId32;
            readonly callHash: U8aFixed;
        } & Struct;
        readonly type: 'NewMultisig' | 'MultisigApproval' | 'MultisigExecuted' | 'MultisigCancelled';
    }
    /** @name PalletMultisigTimepoint (81) */
    interface PalletMultisigTimepoint extends Struct {
        readonly height: u32;
        readonly index: u32;
    }
    /** @name PalletBountiesEvent (82) */
    interface PalletBountiesEvent extends Enum {
        readonly isBountyProposed: boolean;
        readonly asBountyProposed: {
            readonly index: u32;
        } & Struct;
        readonly isBountyRejected: boolean;
        readonly asBountyRejected: {
            readonly index: u32;
            readonly bond: u128;
        } & Struct;
        readonly isBountyBecameActive: boolean;
        readonly asBountyBecameActive: {
            readonly index: u32;
        } & Struct;
        readonly isBountyAwarded: boolean;
        readonly asBountyAwarded: {
            readonly index: u32;
            readonly beneficiary: AccountId32;
        } & Struct;
        readonly isBountyClaimed: boolean;
        readonly asBountyClaimed: {
            readonly index: u32;
            readonly payout: u128;
            readonly beneficiary: AccountId32;
        } & Struct;
        readonly isBountyCanceled: boolean;
        readonly asBountyCanceled: {
            readonly index: u32;
        } & Struct;
        readonly isBountyExtended: boolean;
        readonly asBountyExtended: {
            readonly index: u32;
        } & Struct;
        readonly type: 'BountyProposed' | 'BountyRejected' | 'BountyBecameActive' | 'BountyAwarded' | 'BountyClaimed' | 'BountyCanceled' | 'BountyExtended';
    }
    /** @name PalletTipsEvent (83) */
    interface PalletTipsEvent extends Enum {
        readonly isNewTip: boolean;
        readonly asNewTip: {
            readonly tipHash: H256;
        } & Struct;
        readonly isTipClosing: boolean;
        readonly asTipClosing: {
            readonly tipHash: H256;
        } & Struct;
        readonly isTipClosed: boolean;
        readonly asTipClosed: {
            readonly tipHash: H256;
            readonly who: AccountId32;
            readonly payout: u128;
        } & Struct;
        readonly isTipRetracted: boolean;
        readonly asTipRetracted: {
            readonly tipHash: H256;
        } & Struct;
        readonly isTipSlashed: boolean;
        readonly asTipSlashed: {
            readonly tipHash: H256;
            readonly finder: AccountId32;
            readonly deposit: u128;
        } & Struct;
        readonly type: 'NewTip' | 'TipClosing' | 'TipClosed' | 'TipRetracted' | 'TipSlashed';
    }
    /** @name PalletAssetsEvent (84) */
    interface PalletAssetsEvent extends Enum {
        readonly isCreated: boolean;
        readonly asCreated: {
            readonly assetId: u32;
            readonly creator: AccountId32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isIssued: boolean;
        readonly asIssued: {
            readonly assetId: u32;
            readonly owner: AccountId32;
            readonly totalSupply: u128;
        } & Struct;
        readonly isTransferred: boolean;
        readonly asTransferred: {
            readonly assetId: u32;
            readonly from: AccountId32;
            readonly to: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isBurned: boolean;
        readonly asBurned: {
            readonly assetId: u32;
            readonly owner: AccountId32;
            readonly balance: u128;
        } & Struct;
        readonly isTeamChanged: boolean;
        readonly asTeamChanged: {
            readonly assetId: u32;
            readonly issuer: AccountId32;
            readonly admin: AccountId32;
            readonly freezer: AccountId32;
        } & Struct;
        readonly isOwnerChanged: boolean;
        readonly asOwnerChanged: {
            readonly assetId: u32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isFrozen: boolean;
        readonly asFrozen: {
            readonly assetId: u32;
            readonly who: AccountId32;
        } & Struct;
        readonly isThawed: boolean;
        readonly asThawed: {
            readonly assetId: u32;
            readonly who: AccountId32;
        } & Struct;
        readonly isAssetFrozen: boolean;
        readonly asAssetFrozen: {
            readonly assetId: u32;
        } & Struct;
        readonly isAssetThawed: boolean;
        readonly asAssetThawed: {
            readonly assetId: u32;
        } & Struct;
        readonly isDestroyed: boolean;
        readonly asDestroyed: {
            readonly assetId: u32;
        } & Struct;
        readonly isForceCreated: boolean;
        readonly asForceCreated: {
            readonly assetId: u32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isMetadataSet: boolean;
        readonly asMetadataSet: {
            readonly assetId: u32;
            readonly name: Bytes;
            readonly symbol: Bytes;
            readonly decimals: u8;
            readonly isFrozen: bool;
        } & Struct;
        readonly isMetadataCleared: boolean;
        readonly asMetadataCleared: {
            readonly assetId: u32;
        } & Struct;
        readonly isApprovedTransfer: boolean;
        readonly asApprovedTransfer: {
            readonly assetId: u32;
            readonly source: AccountId32;
            readonly delegate: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isApprovalCancelled: boolean;
        readonly asApprovalCancelled: {
            readonly assetId: u32;
            readonly owner: AccountId32;
            readonly delegate: AccountId32;
        } & Struct;
        readonly isTransferredApproved: boolean;
        readonly asTransferredApproved: {
            readonly assetId: u32;
            readonly owner: AccountId32;
            readonly delegate: AccountId32;
            readonly destination: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isAssetStatusChanged: boolean;
        readonly asAssetStatusChanged: {
            readonly assetId: u32;
        } & Struct;
        readonly type: 'Created' | 'Issued' | 'Transferred' | 'Burned' | 'TeamChanged' | 'OwnerChanged' | 'Frozen' | 'Thawed' | 'AssetFrozen' | 'AssetThawed' | 'Destroyed' | 'ForceCreated' | 'MetadataSet' | 'MetadataCleared' | 'ApprovedTransfer' | 'ApprovalCancelled' | 'TransferredApproved' | 'AssetStatusChanged';
    }
    /** @name PalletLotteryEvent (85) */
    interface PalletLotteryEvent extends Enum {
        readonly isLotteryStarted: boolean;
        readonly isCallsUpdated: boolean;
        readonly isWinner: boolean;
        readonly asWinner: {
            readonly winner: AccountId32;
            readonly lotteryBalance: u128;
        } & Struct;
        readonly isTicketBought: boolean;
        readonly asTicketBought: {
            readonly who: AccountId32;
            readonly callIndex: ITuple<[u8, u8]>;
        } & Struct;
        readonly type: 'LotteryStarted' | 'CallsUpdated' | 'Winner' | 'TicketBought';
    }
    /** @name PalletGiltEvent (87) */
    interface PalletGiltEvent extends Enum {
        readonly isBidPlaced: boolean;
        readonly asBidPlaced: {
            readonly who: AccountId32;
            readonly amount: u128;
            readonly duration: u32;
        } & Struct;
        readonly isBidRetracted: boolean;
        readonly asBidRetracted: {
            readonly who: AccountId32;
            readonly amount: u128;
            readonly duration: u32;
        } & Struct;
        readonly isGiltIssued: boolean;
        readonly asGiltIssued: {
            readonly index: u32;
            readonly expiry: u32;
            readonly who: AccountId32;
            readonly amount: u128;
        } & Struct;
        readonly isGiltThawed: boolean;
        readonly asGiltThawed: {
            readonly index: u32;
            readonly who: AccountId32;
            readonly originalAmount: u128;
            readonly additionalAmount: u128;
        } & Struct;
        readonly type: 'BidPlaced' | 'BidRetracted' | 'GiltIssued' | 'GiltThawed';
    }
    /** @name PalletUniquesEvent (88) */
    interface PalletUniquesEvent extends Enum {
        readonly isCreated: boolean;
        readonly asCreated: {
            readonly class: u32;
            readonly creator: AccountId32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isForceCreated: boolean;
        readonly asForceCreated: {
            readonly class: u32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isDestroyed: boolean;
        readonly asDestroyed: {
            readonly class: u32;
        } & Struct;
        readonly isIssued: boolean;
        readonly asIssued: {
            readonly class: u32;
            readonly instance: u32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isTransferred: boolean;
        readonly asTransferred: {
            readonly class: u32;
            readonly instance: u32;
            readonly from: AccountId32;
            readonly to: AccountId32;
        } & Struct;
        readonly isBurned: boolean;
        readonly asBurned: {
            readonly class: u32;
            readonly instance: u32;
            readonly owner: AccountId32;
        } & Struct;
        readonly isFrozen: boolean;
        readonly asFrozen: {
            readonly class: u32;
            readonly instance: u32;
        } & Struct;
        readonly isThawed: boolean;
        readonly asThawed: {
            readonly class: u32;
            readonly instance: u32;
        } & Struct;
        readonly isClassFrozen: boolean;
        readonly asClassFrozen: {
            readonly class: u32;
        } & Struct;
        readonly isClassThawed: boolean;
        readonly asClassThawed: {
            readonly class: u32;
        } & Struct;
        readonly isOwnerChanged: boolean;
        readonly asOwnerChanged: {
            readonly class: u32;
            readonly newOwner: AccountId32;
        } & Struct;
        readonly isTeamChanged: boolean;
        readonly asTeamChanged: {
            readonly class: u32;
            readonly issuer: AccountId32;
            readonly admin: AccountId32;
            readonly freezer: AccountId32;
        } & Struct;
        readonly isApprovedTransfer: boolean;
        readonly asApprovedTransfer: {
            readonly class: u32;
            readonly instance: u32;
            readonly owner: AccountId32;
            readonly delegate: AccountId32;
        } & Struct;
        readonly isApprovalCancelled: boolean;
        readonly asApprovalCancelled: {
            readonly class: u32;
            readonly instance: u32;
            readonly owner: AccountId32;
            readonly delegate: AccountId32;
        } & Struct;
        readonly isAssetStatusChanged: boolean;
        readonly asAssetStatusChanged: {
            readonly class: u32;
        } & Struct;
        readonly isClassMetadataSet: boolean;
        readonly asClassMetadataSet: {
            readonly class: u32;
            readonly data: Bytes;
            readonly isFrozen: bool;
        } & Struct;
        readonly isClassMetadataCleared: boolean;
        readonly asClassMetadataCleared: {
            readonly class: u32;
        } & Struct;
        readonly isMetadataSet: boolean;
        readonly asMetadataSet: {
            readonly class: u32;
            readonly instance: u32;
            readonly data: Bytes;
            readonly isFrozen: bool;
        } & Struct;
        readonly isMetadataCleared: boolean;
        readonly asMetadataCleared: {
            readonly class: u32;
            readonly instance: u32;
        } & Struct;
        readonly isRedeposited: boolean;
        readonly asRedeposited: {
            readonly class: u32;
            readonly successfulInstances: Vec<u32>;
        } & Struct;
        readonly isAttributeSet: boolean;
        readonly asAttributeSet: {
            readonly class: u32;
            readonly maybeInstance: Option<u32>;
            readonly key: Bytes;
            readonly value: Bytes;
        } & Struct;
        readonly isAttributeCleared: boolean;
        readonly asAttributeCleared: {
            readonly class: u32;
            readonly maybeInstance: Option<u32>;
            readonly key: Bytes;
        } & Struct;
        readonly type: 'Created' | 'ForceCreated' | 'Destroyed' | 'Issued' | 'Transferred' | 'Burned' | 'Frozen' | 'Thawed' | 'ClassFrozen' | 'ClassThawed' | 'OwnerChanged' | 'TeamChanged' | 'ApprovedTransfer' | 'ApprovalCancelled' | 'AssetStatusChanged' | 'ClassMetadataSet' | 'ClassMetadataCleared' | 'MetadataSet' | 'MetadataCleared' | 'Redeposited' | 'AttributeSet' | 'AttributeCleared';
    }
    /** @name PalletTransactionStorageEvent (94) */
    interface PalletTransactionStorageEvent extends Enum {
        readonly isStored: boolean;
        readonly asStored: {
            readonly index: u32;
        } & Struct;
        readonly isRenewed: boolean;
        readonly asRenewed: {
            readonly index: u32;
        } & Struct;
        readonly isProofChecked: boolean;
        readonly type: 'Stored' | 'Renewed' | 'ProofChecked';
    }
    /** @name PalletBagsListEvent (95) */
    interface PalletBagsListEvent extends Enum {
        readonly isRebagged: boolean;
        readonly asRebagged: {
            readonly who: AccountId32;
            readonly from: u64;
            readonly to: u64;
        } & Struct;
        readonly type: 'Rebagged';
    }
    /** @name PalletChildBountiesEvent (96) */
    interface PalletChildBountiesEvent extends Enum {
        readonly isAdded: boolean;
        readonly asAdded: {
            readonly index: u32;
            readonly childIndex: u32;
        } & Struct;
        readonly isAwarded: boolean;
        readonly asAwarded: {
            readonly index: u32;
            readonly childIndex: u32;
            readonly beneficiary: AccountId32;
        } & Struct;
        readonly isClaimed: boolean;
        readonly asClaimed: {
            readonly index: u32;
            readonly childIndex: u32;
            readonly payout: u128;
            readonly beneficiary: AccountId32;
        } & Struct;
        readonly isCanceled: boolean;
        readonly asCanceled: {
            readonly index: u32;
            readonly childIndex: u32;
        } & Struct;
        readonly type: 'Added' | 'Awarded' | 'Claimed' | 'Canceled';
    }
    /** @name FrameSystemPhase (97) */
    interface FrameSystemPhase extends Enum {
        readonly isApplyExtrinsic: boolean;
        readonly asApplyExtrinsic: u32;
        readonly isFinalization: boolean;
        readonly isInitialization: boolean;
        readonly type: 'ApplyExtrinsic' | 'Finalization' | 'Initialization';
    }
    /** @name FrameSystemLastRuntimeUpgradeInfo (100) */
    interface FrameSystemLastRuntimeUpgradeInfo extends Struct {
        readonly specVersion: Compact<u32>;
        readonly specName: Text;
    }
    /** @name FrameSystemCall (103) */
    interface FrameSystemCall extends Enum {
        readonly isFillBlock: boolean;
        readonly asFillBlock: {
            readonly ratio: Perbill;
        } & Struct;
        readonly isRemark: boolean;
        readonly asRemark: {
            readonly remark: Bytes;
        } & Struct;
        readonly isSetHeapPages: boolean;
        readonly asSetHeapPages: {
            readonly pages: u64;
        } & Struct;
        readonly isSetCode: boolean;
        readonly asSetCode: {
            readonly code: Bytes;
        } & Struct;
        readonly isSetCodeWithoutChecks: boolean;
        readonly asSetCodeWithoutChecks: {
            readonly code: Bytes;
        } & Struct;
        readonly isSetStorage: boolean;
        readonly asSetStorage: {
            readonly items: Vec<ITuple<[Bytes, Bytes]>>;
        } & Struct;
        readonly isKillStorage: boolean;
        readonly asKillStorage: {
            readonly keys_: Vec<Bytes>;
        } & Struct;
        readonly isKillPrefix: boolean;
        readonly asKillPrefix: {
            readonly prefix: Bytes;
            readonly subkeys: u32;
        } & Struct;
        readonly isRemarkWithEvent: boolean;
        readonly asRemarkWithEvent: {
            readonly remark: Bytes;
        } & Struct;
        readonly type: 'FillBlock' | 'Remark' | 'SetHeapPages' | 'SetCode' | 'SetCodeWithoutChecks' | 'SetStorage' | 'KillStorage' | 'KillPrefix' | 'RemarkWithEvent';
    }
    /** @name FrameSystemLimitsBlockWeights (108) */
    interface FrameSystemLimitsBlockWeights extends Struct {
        readonly baseBlock: u64;
        readonly maxBlock: u64;
        readonly perClass: FrameSupportWeightsPerDispatchClassWeightsPerClass;
    }
    /** @name FrameSupportWeightsPerDispatchClassWeightsPerClass (109) */
    interface FrameSupportWeightsPerDispatchClassWeightsPerClass extends Struct {
        readonly normal: FrameSystemLimitsWeightsPerClass;
        readonly operational: FrameSystemLimitsWeightsPerClass;
        readonly mandatory: FrameSystemLimitsWeightsPerClass;
    }
    /** @name FrameSystemLimitsWeightsPerClass (110) */
    interface FrameSystemLimitsWeightsPerClass extends Struct {
        readonly baseExtrinsic: u64;
        readonly maxExtrinsic: Option<u64>;
        readonly maxTotal: Option<u64>;
        readonly reserved: Option<u64>;
    }
    /** @name FrameSystemLimitsBlockLength (112) */
    interface FrameSystemLimitsBlockLength extends Struct {
        readonly max: FrameSupportWeightsPerDispatchClassU32;
    }
    /** @name FrameSupportWeightsPerDispatchClassU32 (113) */
    interface FrameSupportWeightsPerDispatchClassU32 extends Struct {
        readonly normal: u32;
        readonly operational: u32;
        readonly mandatory: u32;
    }
    /** @name FrameSupportWeightsRuntimeDbWeight (114) */
    interface FrameSupportWeightsRuntimeDbWeight extends Struct {
        readonly read: u64;
        readonly write: u64;
    }
    /** @name SpVersionRuntimeVersion (115) */
    interface SpVersionRuntimeVersion extends Struct {
        readonly specName: Text;
        readonly implName: Text;
        readonly authoringVersion: u32;
        readonly specVersion: u32;
        readonly implVersion: u32;
        readonly apis: Vec<ITuple<[U8aFixed, u32]>>;
        readonly transactionVersion: u32;
        readonly stateVersion: u8;
    }
    /** @name FrameSystemError (120) */
    interface FrameSystemError extends Enum {
        readonly isInvalidSpecName: boolean;
        readonly isSpecVersionNeedsToIncrease: boolean;
        readonly isFailedToExtractRuntimeVersion: boolean;
        readonly isNonDefaultComposite: boolean;
        readonly isNonZeroRefCount: boolean;
        readonly isCallFiltered: boolean;
        readonly type: 'InvalidSpecName' | 'SpecVersionNeedsToIncrease' | 'FailedToExtractRuntimeVersion' | 'NonDefaultComposite' | 'NonZeroRefCount' | 'CallFiltered';
    }
    /** @name PalletUtilityCall (121) */
    interface PalletUtilityCall extends Enum {
        readonly isBatch: boolean;
        readonly asBatch: {
            readonly calls: Vec<Call>;
        } & Struct;
        readonly isAsDerivative: boolean;
        readonly asAsDerivative: {
            readonly index: u16;
            readonly call: Call;
        } & Struct;
        readonly isBatchAll: boolean;
        readonly asBatchAll: {
            readonly calls: Vec<Call>;
        } & Struct;
        readonly isDispatchAs: boolean;
        readonly asDispatchAs: {
            readonly asOrigin: NodeRuntimeOriginCaller;
            readonly call: Call;
        } & Struct;
        readonly type: 'Batch' | 'AsDerivative' | 'BatchAll' | 'DispatchAs';
    }
    /** @name PalletBabeCall (124) */
    interface PalletBabeCall extends Enum {
        readonly isReportEquivocation: boolean;
        readonly asReportEquivocation: {
            readonly equivocationProof: SpConsensusSlotsEquivocationProof;
            readonly keyOwnerProof: SpSessionMembershipProof;
        } & Struct;
        readonly isReportEquivocationUnsigned: boolean;
        readonly asReportEquivocationUnsigned: {
            readonly equivocationProof: SpConsensusSlotsEquivocationProof;
            readonly keyOwnerProof: SpSessionMembershipProof;
        } & Struct;
        readonly isPlanConfigChange: boolean;
        readonly asPlanConfigChange: {
            readonly config: SpConsensusBabeDigestsNextConfigDescriptor;
        } & Struct;
        readonly type: 'ReportEquivocation' | 'ReportEquivocationUnsigned' | 'PlanConfigChange';
    }
    /** @name SpConsensusSlotsEquivocationProof (125) */
    interface SpConsensusSlotsEquivocationProof extends Struct {
        readonly offender: SpConsensusBabeAppPublic;
        readonly slot: u64;
        readonly firstHeader: SpRuntimeHeader;
        readonly secondHeader: SpRuntimeHeader;
    }
    /** @name SpRuntimeHeader (126) */
    interface SpRuntimeHeader extends Struct {
        readonly parentHash: H256;
        readonly number: Compact<u32>;
        readonly stateRoot: H256;
        readonly extrinsicsRoot: H256;
        readonly digest: SpRuntimeDigest;
    }
    /** @name SpRuntimeBlakeTwo256 (127) */
    type SpRuntimeBlakeTwo256 = Null;
    /** @name SpConsensusBabeAppPublic (128) */
    interface SpConsensusBabeAppPublic extends SpCoreSr25519Public {
    }
    /** @name SpSessionMembershipProof (130) */
    interface SpSessionMembershipProof extends Struct {
        readonly session: u32;
        readonly trieNodes: Vec<Bytes>;
        readonly validatorCount: u32;
    }
    /** @name SpConsensusBabeDigestsNextConfigDescriptor (131) */
    interface SpConsensusBabeDigestsNextConfigDescriptor extends Enum {
        readonly isV1: boolean;
        readonly asV1: {
            readonly c: ITuple<[u64, u64]>;
            readonly allowedSlots: SpConsensusBabeAllowedSlots;
        } & Struct;
        readonly type: 'V1';
    }
    /** @name SpConsensusBabeAllowedSlots (133) */
    interface SpConsensusBabeAllowedSlots extends Enum {
        readonly isPrimarySlots: boolean;
        readonly isPrimaryAndSecondaryPlainSlots: boolean;
        readonly isPrimaryAndSecondaryVRFSlots: boolean;
        readonly type: 'PrimarySlots' | 'PrimaryAndSecondaryPlainSlots' | 'PrimaryAndSecondaryVRFSlots';
    }
    /** @name PalletTimestampCall (134) */
    interface PalletTimestampCall extends Enum {
        readonly isSet: boolean;
        readonly asSet: {
            readonly now: Compact<u64>;
        } & Struct;
        readonly type: 'Set';
    }
    /** @name PalletAuthorshipCall (136) */
    interface PalletAuthorshipCall extends Enum {
        readonly isSetUncles: boolean;
        readonly asSetUncles: {
            readonly newUncles: Vec<SpRuntimeHeader>;
        } & Struct;
        readonly type: 'SetUncles';
    }
    /** @name PalletIndicesCall (138) */
    interface PalletIndicesCall extends Enum {
        readonly isClaim: boolean;
        readonly asClaim: {
            readonly index: u32;
        } & Struct;
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly new_: AccountId32;
            readonly index: u32;
        } & Struct;
        readonly isFree: boolean;
        readonly asFree: {
            readonly index: u32;
        } & Struct;
        readonly isForceTransfer: boolean;
        readonly asForceTransfer: {
            readonly new_: AccountId32;
            readonly index: u32;
            readonly freeze: bool;
        } & Struct;
        readonly isFreeze: boolean;
        readonly asFreeze: {
            readonly index: u32;
        } & Struct;
        readonly type: 'Claim' | 'Transfer' | 'Free' | 'ForceTransfer' | 'Freeze';
    }
    /** @name PalletBalancesCall (139) */
    interface PalletBalancesCall extends Enum {
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly dest: MultiAddress;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isSetBalance: boolean;
        readonly asSetBalance: {
            readonly who: MultiAddress;
            readonly newFree: Compact<u128>;
            readonly newReserved: Compact<u128>;
        } & Struct;
        readonly isForceTransfer: boolean;
        readonly asForceTransfer: {
            readonly source: MultiAddress;
            readonly dest: MultiAddress;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isTransferKeepAlive: boolean;
        readonly asTransferKeepAlive: {
            readonly dest: MultiAddress;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isTransferAll: boolean;
        readonly asTransferAll: {
            readonly dest: MultiAddress;
            readonly keepAlive: bool;
        } & Struct;
        readonly isForceUnreserve: boolean;
        readonly asForceUnreserve: {
            readonly who: MultiAddress;
            readonly amount: u128;
        } & Struct;
        readonly type: 'Transfer' | 'SetBalance' | 'ForceTransfer' | 'TransferKeepAlive' | 'TransferAll' | 'ForceUnreserve';
    }
    /** @name PalletElectionProviderMultiPhaseCall (142) */
    interface PalletElectionProviderMultiPhaseCall extends Enum {
        readonly isSubmitUnsigned: boolean;
        readonly asSubmitUnsigned: {
            readonly rawSolution: PalletElectionProviderMultiPhaseRawSolution;
            readonly witness: PalletElectionProviderMultiPhaseSolutionOrSnapshotSize;
        } & Struct;
        readonly isSetMinimumUntrustedScore: boolean;
        readonly asSetMinimumUntrustedScore: {
            readonly maybeNextScore: Option<Vec<u128>>;
        } & Struct;
        readonly isSetEmergencyElectionResult: boolean;
        readonly asSetEmergencyElectionResult: {
            readonly supports: Vec<ITuple<[AccountId32, SpNposElectionsSupport]>>;
        } & Struct;
        readonly isSubmit: boolean;
        readonly asSubmit: {
            readonly rawSolution: PalletElectionProviderMultiPhaseRawSolution;
            readonly numSignedSubmissions: u32;
        } & Struct;
        readonly type: 'SubmitUnsigned' | 'SetMinimumUntrustedScore' | 'SetEmergencyElectionResult' | 'Submit';
    }
    /** @name PalletElectionProviderMultiPhaseRawSolution (143) */
    interface PalletElectionProviderMultiPhaseRawSolution extends Struct {
        readonly solution: NodeRuntimeNposSolution16;
        readonly score: Vec<u128>;
        readonly round: u32;
    }
    /** @name NodeRuntimeNposSolution16 (144) */
    interface NodeRuntimeNposSolution16 extends Struct {
        readonly votes1: Vec<ITuple<[Compact<u32>, Compact<u16>]>>;
        readonly votes2: Vec<ITuple<[Compact<u32>, ITuple<[Compact<u16>, Compact<PerU16>]>, Compact<u16>]>>;
        readonly votes3: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes4: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes5: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes6: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes7: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes8: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes9: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes10: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes11: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes12: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes13: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes14: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes15: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
        readonly votes16: Vec<ITuple<[Compact<u32>, Vec<ITuple<[Compact<u16>, Compact<PerU16>]>>, Compact<u16>]>>;
    }
    /** @name PalletElectionProviderMultiPhaseSolutionOrSnapshotSize (196) */
    interface PalletElectionProviderMultiPhaseSolutionOrSnapshotSize extends Struct {
        readonly voters: Compact<u32>;
        readonly targets: Compact<u32>;
    }
    /** @name SpNposElectionsSupport (200) */
    interface SpNposElectionsSupport extends Struct {
        readonly total: u128;
        readonly voters: Vec<ITuple<[AccountId32, u128]>>;
    }
    /** @name PalletStakingPalletCall (201) */
    interface PalletStakingPalletCall extends Enum {
        readonly isBond: boolean;
        readonly asBond: {
            readonly controller: MultiAddress;
            readonly value: Compact<u128>;
            readonly payee: PalletStakingRewardDestination;
        } & Struct;
        readonly isBondExtra: boolean;
        readonly asBondExtra: {
            readonly maxAdditional: Compact<u128>;
        } & Struct;
        readonly isUnbond: boolean;
        readonly asUnbond: {
            readonly value: Compact<u128>;
        } & Struct;
        readonly isWithdrawUnbonded: boolean;
        readonly asWithdrawUnbonded: {
            readonly numSlashingSpans: u32;
        } & Struct;
        readonly isValidate: boolean;
        readonly asValidate: {
            readonly prefs: PalletStakingValidatorPrefs;
        } & Struct;
        readonly isNominate: boolean;
        readonly asNominate: {
            readonly targets: Vec<MultiAddress>;
        } & Struct;
        readonly isChill: boolean;
        readonly isSetPayee: boolean;
        readonly asSetPayee: {
            readonly payee: PalletStakingRewardDestination;
        } & Struct;
        readonly isSetController: boolean;
        readonly asSetController: {
            readonly controller: MultiAddress;
        } & Struct;
        readonly isSetValidatorCount: boolean;
        readonly asSetValidatorCount: {
            readonly new_: Compact<u32>;
        } & Struct;
        readonly isIncreaseValidatorCount: boolean;
        readonly asIncreaseValidatorCount: {
            readonly additional: Compact<u32>;
        } & Struct;
        readonly isScaleValidatorCount: boolean;
        readonly asScaleValidatorCount: {
            readonly factor: Percent;
        } & Struct;
        readonly isForceNoEras: boolean;
        readonly isForceNewEra: boolean;
        readonly isSetInvulnerables: boolean;
        readonly asSetInvulnerables: {
            readonly invulnerables: Vec<AccountId32>;
        } & Struct;
        readonly isForceUnstake: boolean;
        readonly asForceUnstake: {
            readonly stash: AccountId32;
            readonly numSlashingSpans: u32;
        } & Struct;
        readonly isForceNewEraAlways: boolean;
        readonly isCancelDeferredSlash: boolean;
        readonly asCancelDeferredSlash: {
            readonly era: u32;
            readonly slashIndices: Vec<u32>;
        } & Struct;
        readonly isPayoutStakers: boolean;
        readonly asPayoutStakers: {
            readonly validatorStash: AccountId32;
            readonly era: u32;
        } & Struct;
        readonly isRebond: boolean;
        readonly asRebond: {
            readonly value: Compact<u128>;
        } & Struct;
        readonly isSetHistoryDepth: boolean;
        readonly asSetHistoryDepth: {
            readonly newHistoryDepth: Compact<u32>;
            readonly eraItemsDeleted: Compact<u32>;
        } & Struct;
        readonly isReapStash: boolean;
        readonly asReapStash: {
            readonly stash: AccountId32;
            readonly numSlashingSpans: u32;
        } & Struct;
        readonly isKick: boolean;
        readonly asKick: {
            readonly who: Vec<MultiAddress>;
        } & Struct;
        readonly isSetStakingConfigs: boolean;
        readonly asSetStakingConfigs: {
            readonly minNominatorBond: u128;
            readonly minValidatorBond: u128;
            readonly maxNominatorCount: Option<u32>;
            readonly maxValidatorCount: Option<u32>;
            readonly chillThreshold: Option<Percent>;
            readonly minCommission: Perbill;
        } & Struct;
        readonly isChillOther: boolean;
        readonly asChillOther: {
            readonly controller: AccountId32;
        } & Struct;
        readonly type: 'Bond' | 'BondExtra' | 'Unbond' | 'WithdrawUnbonded' | 'Validate' | 'Nominate' | 'Chill' | 'SetPayee' | 'SetController' | 'SetValidatorCount' | 'IncreaseValidatorCount' | 'ScaleValidatorCount' | 'ForceNoEras' | 'ForceNewEra' | 'SetInvulnerables' | 'ForceUnstake' | 'ForceNewEraAlways' | 'CancelDeferredSlash' | 'PayoutStakers' | 'Rebond' | 'SetHistoryDepth' | 'ReapStash' | 'Kick' | 'SetStakingConfigs' | 'ChillOther';
    }
    /** @name PalletStakingRewardDestination (202) */
    interface PalletStakingRewardDestination extends Enum {
        readonly isStaked: boolean;
        readonly isStash: boolean;
        readonly isController: boolean;
        readonly isAccount: boolean;
        readonly asAccount: AccountId32;
        readonly isNone: boolean;
        readonly type: 'Staked' | 'Stash' | 'Controller' | 'Account' | 'None';
    }
    /** @name PalletStakingValidatorPrefs (203) */
    interface PalletStakingValidatorPrefs extends Struct {
        readonly commission: Compact<Perbill>;
        readonly blocked: bool;
    }
    /** @name PalletSessionCall (208) */
    interface PalletSessionCall extends Enum {
        readonly isSetKeys: boolean;
        readonly asSetKeys: {
            readonly keys_: NodeRuntimeSessionKeys;
            readonly proof: Bytes;
        } & Struct;
        readonly isPurgeKeys: boolean;
        readonly type: 'SetKeys' | 'PurgeKeys';
    }
    /** @name NodeRuntimeSessionKeys (209) */
    interface NodeRuntimeSessionKeys extends Struct {
        readonly grandpa: SpFinalityGrandpaAppPublic;
        readonly babe: SpConsensusBabeAppPublic;
        readonly imOnline: PalletImOnlineSr25519AppSr25519Public;
        readonly authorityDiscovery: SpAuthorityDiscoveryAppPublic;
    }
    /** @name SpAuthorityDiscoveryAppPublic (210) */
    interface SpAuthorityDiscoveryAppPublic extends SpCoreSr25519Public {
    }
    /** @name PalletDemocracyCall (211) */
    interface PalletDemocracyCall extends Enum {
        readonly isPropose: boolean;
        readonly asPropose: {
            readonly proposalHash: H256;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isSecond: boolean;
        readonly asSecond: {
            readonly proposal: Compact<u32>;
            readonly secondsUpperBound: Compact<u32>;
        } & Struct;
        readonly isVote: boolean;
        readonly asVote: {
            readonly refIndex: Compact<u32>;
            readonly vote: PalletDemocracyVoteAccountVote;
        } & Struct;
        readonly isEmergencyCancel: boolean;
        readonly asEmergencyCancel: {
            readonly refIndex: u32;
        } & Struct;
        readonly isExternalPropose: boolean;
        readonly asExternalPropose: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isExternalProposeMajority: boolean;
        readonly asExternalProposeMajority: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isExternalProposeDefault: boolean;
        readonly asExternalProposeDefault: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isFastTrack: boolean;
        readonly asFastTrack: {
            readonly proposalHash: H256;
            readonly votingPeriod: u32;
            readonly delay: u32;
        } & Struct;
        readonly isVetoExternal: boolean;
        readonly asVetoExternal: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isCancelReferendum: boolean;
        readonly asCancelReferendum: {
            readonly refIndex: Compact<u32>;
        } & Struct;
        readonly isCancelQueued: boolean;
        readonly asCancelQueued: {
            readonly which: u32;
        } & Struct;
        readonly isDelegate: boolean;
        readonly asDelegate: {
            readonly to: AccountId32;
            readonly conviction: PalletDemocracyConviction;
            readonly balance: u128;
        } & Struct;
        readonly isUndelegate: boolean;
        readonly isClearPublicProposals: boolean;
        readonly isNotePreimage: boolean;
        readonly asNotePreimage: {
            readonly encodedProposal: Bytes;
        } & Struct;
        readonly isNotePreimageOperational: boolean;
        readonly asNotePreimageOperational: {
            readonly encodedProposal: Bytes;
        } & Struct;
        readonly isNoteImminentPreimage: boolean;
        readonly asNoteImminentPreimage: {
            readonly encodedProposal: Bytes;
        } & Struct;
        readonly isNoteImminentPreimageOperational: boolean;
        readonly asNoteImminentPreimageOperational: {
            readonly encodedProposal: Bytes;
        } & Struct;
        readonly isReapPreimage: boolean;
        readonly asReapPreimage: {
            readonly proposalHash: H256;
            readonly proposalLenUpperBound: Compact<u32>;
        } & Struct;
        readonly isUnlock: boolean;
        readonly asUnlock: {
            readonly target: AccountId32;
        } & Struct;
        readonly isRemoveVote: boolean;
        readonly asRemoveVote: {
            readonly index: u32;
        } & Struct;
        readonly isRemoveOtherVote: boolean;
        readonly asRemoveOtherVote: {
            readonly target: AccountId32;
            readonly index: u32;
        } & Struct;
        readonly isEnactProposal: boolean;
        readonly asEnactProposal: {
            readonly proposalHash: H256;
            readonly index: u32;
        } & Struct;
        readonly isBlacklist: boolean;
        readonly asBlacklist: {
            readonly proposalHash: H256;
            readonly maybeRefIndex: Option<u32>;
        } & Struct;
        readonly isCancelProposal: boolean;
        readonly asCancelProposal: {
            readonly propIndex: Compact<u32>;
        } & Struct;
        readonly type: 'Propose' | 'Second' | 'Vote' | 'EmergencyCancel' | 'ExternalPropose' | 'ExternalProposeMajority' | 'ExternalProposeDefault' | 'FastTrack' | 'VetoExternal' | 'CancelReferendum' | 'CancelQueued' | 'Delegate' | 'Undelegate' | 'ClearPublicProposals' | 'NotePreimage' | 'NotePreimageOperational' | 'NoteImminentPreimage' | 'NoteImminentPreimageOperational' | 'ReapPreimage' | 'Unlock' | 'RemoveVote' | 'RemoveOtherVote' | 'EnactProposal' | 'Blacklist' | 'CancelProposal';
    }
    /** @name PalletDemocracyConviction (212) */
    interface PalletDemocracyConviction extends Enum {
        readonly isNone: boolean;
        readonly isLocked1x: boolean;
        readonly isLocked2x: boolean;
        readonly isLocked3x: boolean;
        readonly isLocked4x: boolean;
        readonly isLocked5x: boolean;
        readonly isLocked6x: boolean;
        readonly type: 'None' | 'Locked1x' | 'Locked2x' | 'Locked3x' | 'Locked4x' | 'Locked5x' | 'Locked6x';
    }
    /** @name PalletCollectiveCall (213) */
    interface PalletCollectiveCall extends Enum {
        readonly isSetMembers: boolean;
        readonly asSetMembers: {
            readonly newMembers: Vec<AccountId32>;
            readonly prime: Option<AccountId32>;
            readonly oldCount: u32;
        } & Struct;
        readonly isExecute: boolean;
        readonly asExecute: {
            readonly proposal: Call;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly isPropose: boolean;
        readonly asPropose: {
            readonly threshold: Compact<u32>;
            readonly proposal: Call;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly isVote: boolean;
        readonly asVote: {
            readonly proposal: H256;
            readonly index: Compact<u32>;
            readonly approve: bool;
        } & Struct;
        readonly isClose: boolean;
        readonly asClose: {
            readonly proposalHash: H256;
            readonly index: Compact<u32>;
            readonly proposalWeightBound: Compact<u64>;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly isDisapproveProposal: boolean;
        readonly asDisapproveProposal: {
            readonly proposalHash: H256;
        } & Struct;
        readonly type: 'SetMembers' | 'Execute' | 'Propose' | 'Vote' | 'Close' | 'DisapproveProposal';
    }
    /** @name PalletElectionsPhragmenCall (215) */
    interface PalletElectionsPhragmenCall extends Enum {
        readonly isVote: boolean;
        readonly asVote: {
            readonly votes: Vec<AccountId32>;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isRemoveVoter: boolean;
        readonly isSubmitCandidacy: boolean;
        readonly asSubmitCandidacy: {
            readonly candidateCount: Compact<u32>;
        } & Struct;
        readonly isRenounceCandidacy: boolean;
        readonly asRenounceCandidacy: {
            readonly renouncing: PalletElectionsPhragmenRenouncing;
        } & Struct;
        readonly isRemoveMember: boolean;
        readonly asRemoveMember: {
            readonly who: MultiAddress;
            readonly hasReplacement: bool;
        } & Struct;
        readonly isCleanDefunctVoters: boolean;
        readonly asCleanDefunctVoters: {
            readonly numVoters: u32;
            readonly numDefunct: u32;
        } & Struct;
        readonly type: 'Vote' | 'RemoveVoter' | 'SubmitCandidacy' | 'RenounceCandidacy' | 'RemoveMember' | 'CleanDefunctVoters';
    }
    /** @name PalletElectionsPhragmenRenouncing (216) */
    interface PalletElectionsPhragmenRenouncing extends Enum {
        readonly isMember: boolean;
        readonly isRunnerUp: boolean;
        readonly isCandidate: boolean;
        readonly asCandidate: Compact<u32>;
        readonly type: 'Member' | 'RunnerUp' | 'Candidate';
    }
    /** @name PalletMembershipCall (217) */
    interface PalletMembershipCall extends Enum {
        readonly isAddMember: boolean;
        readonly asAddMember: {
            readonly who: AccountId32;
        } & Struct;
        readonly isRemoveMember: boolean;
        readonly asRemoveMember: {
            readonly who: AccountId32;
        } & Struct;
        readonly isSwapMember: boolean;
        readonly asSwapMember: {
            readonly remove: AccountId32;
            readonly add: AccountId32;
        } & Struct;
        readonly isResetMembers: boolean;
        readonly asResetMembers: {
            readonly members: Vec<AccountId32>;
        } & Struct;
        readonly isChangeKey: boolean;
        readonly asChangeKey: {
            readonly new_: AccountId32;
        } & Struct;
        readonly isSetPrime: boolean;
        readonly asSetPrime: {
            readonly who: AccountId32;
        } & Struct;
        readonly isClearPrime: boolean;
        readonly type: 'AddMember' | 'RemoveMember' | 'SwapMember' | 'ResetMembers' | 'ChangeKey' | 'SetPrime' | 'ClearPrime';
    }
    /** @name PalletGrandpaCall (218) */
    interface PalletGrandpaCall extends Enum {
        readonly isReportEquivocation: boolean;
        readonly asReportEquivocation: {
            readonly equivocationProof: SpFinalityGrandpaEquivocationProof;
            readonly keyOwnerProof: SpSessionMembershipProof;
        } & Struct;
        readonly isReportEquivocationUnsigned: boolean;
        readonly asReportEquivocationUnsigned: {
            readonly equivocationProof: SpFinalityGrandpaEquivocationProof;
            readonly keyOwnerProof: SpSessionMembershipProof;
        } & Struct;
        readonly isNoteStalled: boolean;
        readonly asNoteStalled: {
            readonly delay: u32;
            readonly bestFinalizedBlockNumber: u32;
        } & Struct;
        readonly type: 'ReportEquivocation' | 'ReportEquivocationUnsigned' | 'NoteStalled';
    }
    /** @name SpFinalityGrandpaEquivocationProof (219) */
    interface SpFinalityGrandpaEquivocationProof extends Struct {
        readonly setId: u64;
        readonly equivocation: SpFinalityGrandpaEquivocation;
    }
    /** @name SpFinalityGrandpaEquivocation (220) */
    interface SpFinalityGrandpaEquivocation extends Enum {
        readonly isPrevote: boolean;
        readonly asPrevote: FinalityGrandpaEquivocationPrevote;
        readonly isPrecommit: boolean;
        readonly asPrecommit: FinalityGrandpaEquivocationPrecommit;
        readonly type: 'Prevote' | 'Precommit';
    }
    /** @name FinalityGrandpaEquivocationPrevote (221) */
    interface FinalityGrandpaEquivocationPrevote extends Struct {
        readonly roundNumber: u64;
        readonly identity: SpFinalityGrandpaAppPublic;
        readonly first: ITuple<[FinalityGrandpaPrevote, SpFinalityGrandpaAppSignature]>;
        readonly second: ITuple<[FinalityGrandpaPrevote, SpFinalityGrandpaAppSignature]>;
    }
    /** @name FinalityGrandpaPrevote (222) */
    interface FinalityGrandpaPrevote extends Struct {
        readonly targetHash: H256;
        readonly targetNumber: u32;
    }
    /** @name SpFinalityGrandpaAppSignature (223) */
    interface SpFinalityGrandpaAppSignature extends SpCoreEd25519Signature {
    }
    /** @name SpCoreEd25519Signature (224) */
    interface SpCoreEd25519Signature extends U8aFixed {
    }
    /** @name FinalityGrandpaEquivocationPrecommit (227) */
    interface FinalityGrandpaEquivocationPrecommit extends Struct {
        readonly roundNumber: u64;
        readonly identity: SpFinalityGrandpaAppPublic;
        readonly first: ITuple<[FinalityGrandpaPrecommit, SpFinalityGrandpaAppSignature]>;
        readonly second: ITuple<[FinalityGrandpaPrecommit, SpFinalityGrandpaAppSignature]>;
    }
    /** @name FinalityGrandpaPrecommit (228) */
    interface FinalityGrandpaPrecommit extends Struct {
        readonly targetHash: H256;
        readonly targetNumber: u32;
    }
    /** @name PalletTreasuryCall (230) */
    interface PalletTreasuryCall extends Enum {
        readonly isProposeSpend: boolean;
        readonly asProposeSpend: {
            readonly value: Compact<u128>;
            readonly beneficiary: MultiAddress;
        } & Struct;
        readonly isRejectProposal: boolean;
        readonly asRejectProposal: {
            readonly proposalId: Compact<u32>;
        } & Struct;
        readonly isApproveProposal: boolean;
        readonly asApproveProposal: {
            readonly proposalId: Compact<u32>;
        } & Struct;
        readonly type: 'ProposeSpend' | 'RejectProposal' | 'ApproveProposal';
    }
    /** @name PalletContractsCall (231) */
    interface PalletContractsCall extends Enum {
        readonly isCall: boolean;
        readonly asCall: {
            readonly dest: MultiAddress;
            readonly value: Compact<u128>;
            readonly gasLimit: Compact<u64>;
            readonly storageDepositLimit: Option<Compact<u128>>;
            readonly data: Bytes;
        } & Struct;
        readonly isInstantiateWithCode: boolean;
        readonly asInstantiateWithCode: {
            readonly value: Compact<u128>;
            readonly gasLimit: Compact<u64>;
            readonly storageDepositLimit: Option<Compact<u128>>;
            readonly code: Bytes;
            readonly data: Bytes;
            readonly salt: Bytes;
        } & Struct;
        readonly isInstantiate: boolean;
        readonly asInstantiate: {
            readonly value: Compact<u128>;
            readonly gasLimit: Compact<u64>;
            readonly storageDepositLimit: Option<Compact<u128>>;
            readonly codeHash: H256;
            readonly data: Bytes;
            readonly salt: Bytes;
        } & Struct;
        readonly isUploadCode: boolean;
        readonly asUploadCode: {
            readonly code: Bytes;
            readonly storageDepositLimit: Option<Compact<u128>>;
        } & Struct;
        readonly isRemoveCode: boolean;
        readonly asRemoveCode: {
            readonly codeHash: H256;
        } & Struct;
        readonly type: 'Call' | 'InstantiateWithCode' | 'Instantiate' | 'UploadCode' | 'RemoveCode';
    }
    /** @name PalletSudoCall (233) */
    interface PalletSudoCall extends Enum {
        readonly isSudo: boolean;
        readonly asSudo: {
            readonly call: Call;
        } & Struct;
        readonly isSudoUncheckedWeight: boolean;
        readonly asSudoUncheckedWeight: {
            readonly call: Call;
            readonly weight: u64;
        } & Struct;
        readonly isSetKey: boolean;
        readonly asSetKey: {
            readonly new_: MultiAddress;
        } & Struct;
        readonly isSudoAs: boolean;
        readonly asSudoAs: {
            readonly who: MultiAddress;
            readonly call: Call;
        } & Struct;
        readonly type: 'Sudo' | 'SudoUncheckedWeight' | 'SetKey' | 'SudoAs';
    }
    /** @name PalletImOnlineCall (234) */
    interface PalletImOnlineCall extends Enum {
        readonly isHeartbeat: boolean;
        readonly asHeartbeat: {
            readonly heartbeat: PalletImOnlineHeartbeat;
            readonly signature: PalletImOnlineSr25519AppSr25519Signature;
        } & Struct;
        readonly type: 'Heartbeat';
    }
    /** @name PalletImOnlineHeartbeat (235) */
    interface PalletImOnlineHeartbeat extends Struct {
        readonly blockNumber: u32;
        readonly networkState: SpCoreOffchainOpaqueNetworkState;
        readonly sessionIndex: u32;
        readonly authorityIndex: u32;
        readonly validatorsLen: u32;
    }
    /** @name SpCoreOffchainOpaqueNetworkState (236) */
    interface SpCoreOffchainOpaqueNetworkState extends Struct {
        readonly peerId: Bytes;
        readonly externalAddresses: Vec<Bytes>;
    }
    /** @name PalletImOnlineSr25519AppSr25519Signature (240) */
    interface PalletImOnlineSr25519AppSr25519Signature extends SpCoreSr25519Signature {
    }
    /** @name SpCoreSr25519Signature (241) */
    interface SpCoreSr25519Signature extends U8aFixed {
    }
    /** @name PalletIdentityCall (242) */
    interface PalletIdentityCall extends Enum {
        readonly isAddRegistrar: boolean;
        readonly asAddRegistrar: {
            readonly account: AccountId32;
        } & Struct;
        readonly isSetIdentity: boolean;
        readonly asSetIdentity: {
            readonly info: PalletIdentityIdentityInfo;
        } & Struct;
        readonly isSetSubs: boolean;
        readonly asSetSubs: {
            readonly subs: Vec<ITuple<[AccountId32, Data]>>;
        } & Struct;
        readonly isClearIdentity: boolean;
        readonly isRequestJudgement: boolean;
        readonly asRequestJudgement: {
            readonly regIndex: Compact<u32>;
            readonly maxFee: Compact<u128>;
        } & Struct;
        readonly isCancelRequest: boolean;
        readonly asCancelRequest: {
            readonly regIndex: u32;
        } & Struct;
        readonly isSetFee: boolean;
        readonly asSetFee: {
            readonly index: Compact<u32>;
            readonly fee: Compact<u128>;
        } & Struct;
        readonly isSetAccountId: boolean;
        readonly asSetAccountId: {
            readonly index: Compact<u32>;
            readonly new_: AccountId32;
        } & Struct;
        readonly isSetFields: boolean;
        readonly asSetFields: {
            readonly index: Compact<u32>;
            readonly fields: PalletIdentityBitFlags;
        } & Struct;
        readonly isProvideJudgement: boolean;
        readonly asProvideJudgement: {
            readonly regIndex: Compact<u32>;
            readonly target: MultiAddress;
            readonly judgement: PalletIdentityJudgement;
        } & Struct;
        readonly isKillIdentity: boolean;
        readonly asKillIdentity: {
            readonly target: MultiAddress;
        } & Struct;
        readonly isAddSub: boolean;
        readonly asAddSub: {
            readonly sub: MultiAddress;
            readonly data: Data;
        } & Struct;
        readonly isRenameSub: boolean;
        readonly asRenameSub: {
            readonly sub: MultiAddress;
            readonly data: Data;
        } & Struct;
        readonly isRemoveSub: boolean;
        readonly asRemoveSub: {
            readonly sub: MultiAddress;
        } & Struct;
        readonly isQuitSub: boolean;
        readonly type: 'AddRegistrar' | 'SetIdentity' | 'SetSubs' | 'ClearIdentity' | 'RequestJudgement' | 'CancelRequest' | 'SetFee' | 'SetAccountId' | 'SetFields' | 'ProvideJudgement' | 'KillIdentity' | 'AddSub' | 'RenameSub' | 'RemoveSub' | 'QuitSub';
    }
    /** @name PalletIdentityIdentityInfo (243) */
    interface PalletIdentityIdentityInfo extends Struct {
        readonly additional: Vec<ITuple<[Data, Data]>>;
        readonly display: Data;
        readonly legal: Data;
        readonly web: Data;
        readonly riot: Data;
        readonly email: Data;
        readonly pgpFingerprint: Option<U8aFixed>;
        readonly image: Data;
        readonly twitter: Data;
    }
    /** @name PalletIdentityBitFlags (279) */
    interface PalletIdentityBitFlags extends Set {
        readonly isDisplay: boolean;
        readonly isLegal: boolean;
        readonly isWeb: boolean;
        readonly isRiot: boolean;
        readonly isEmail: boolean;
        readonly isPgpFingerprint: boolean;
        readonly isImage: boolean;
        readonly isTwitter: boolean;
    }
    /** @name PalletIdentityIdentityField (280) */
    interface PalletIdentityIdentityField extends Enum {
        readonly isDisplay: boolean;
        readonly isLegal: boolean;
        readonly isWeb: boolean;
        readonly isRiot: boolean;
        readonly isEmail: boolean;
        readonly isPgpFingerprint: boolean;
        readonly isImage: boolean;
        readonly isTwitter: boolean;
        readonly type: 'Display' | 'Legal' | 'Web' | 'Riot' | 'Email' | 'PgpFingerprint' | 'Image' | 'Twitter';
    }
    /** @name PalletIdentityJudgement (281) */
    interface PalletIdentityJudgement extends Enum {
        readonly isUnknown: boolean;
        readonly isFeePaid: boolean;
        readonly asFeePaid: u128;
        readonly isReasonable: boolean;
        readonly isKnownGood: boolean;
        readonly isOutOfDate: boolean;
        readonly isLowQuality: boolean;
        readonly isErroneous: boolean;
        readonly type: 'Unknown' | 'FeePaid' | 'Reasonable' | 'KnownGood' | 'OutOfDate' | 'LowQuality' | 'Erroneous';
    }
    /** @name PalletSocietyCall (282) */
    interface PalletSocietyCall extends Enum {
        readonly isBid: boolean;
        readonly asBid: {
            readonly value: u128;
        } & Struct;
        readonly isUnbid: boolean;
        readonly asUnbid: {
            readonly pos: u32;
        } & Struct;
        readonly isVouch: boolean;
        readonly asVouch: {
            readonly who: AccountId32;
            readonly value: u128;
            readonly tip: u128;
        } & Struct;
        readonly isUnvouch: boolean;
        readonly asUnvouch: {
            readonly pos: u32;
        } & Struct;
        readonly isVote: boolean;
        readonly asVote: {
            readonly candidate: MultiAddress;
            readonly approve: bool;
        } & Struct;
        readonly isDefenderVote: boolean;
        readonly asDefenderVote: {
            readonly approve: bool;
        } & Struct;
        readonly isPayout: boolean;
        readonly isFound: boolean;
        readonly asFound: {
            readonly founder: AccountId32;
            readonly maxMembers: u32;
            readonly rules: Bytes;
        } & Struct;
        readonly isUnfound: boolean;
        readonly isJudgeSuspendedMember: boolean;
        readonly asJudgeSuspendedMember: {
            readonly who: AccountId32;
            readonly forgive: bool;
        } & Struct;
        readonly isJudgeSuspendedCandidate: boolean;
        readonly asJudgeSuspendedCandidate: {
            readonly who: AccountId32;
            readonly judgement: PalletSocietyJudgement;
        } & Struct;
        readonly isSetMaxMembers: boolean;
        readonly asSetMaxMembers: {
            readonly max: u32;
        } & Struct;
        readonly type: 'Bid' | 'Unbid' | 'Vouch' | 'Unvouch' | 'Vote' | 'DefenderVote' | 'Payout' | 'Found' | 'Unfound' | 'JudgeSuspendedMember' | 'JudgeSuspendedCandidate' | 'SetMaxMembers';
    }
    /** @name PalletSocietyJudgement (283) */
    interface PalletSocietyJudgement extends Enum {
        readonly isRebid: boolean;
        readonly isReject: boolean;
        readonly isApprove: boolean;
        readonly type: 'Rebid' | 'Reject' | 'Approve';
    }
    /** @name PalletRecoveryCall (284) */
    interface PalletRecoveryCall extends Enum {
        readonly isAsRecovered: boolean;
        readonly asAsRecovered: {
            readonly account: AccountId32;
            readonly call: Call;
        } & Struct;
        readonly isSetRecovered: boolean;
        readonly asSetRecovered: {
            readonly lost: AccountId32;
            readonly rescuer: AccountId32;
        } & Struct;
        readonly isCreateRecovery: boolean;
        readonly asCreateRecovery: {
            readonly friends: Vec<AccountId32>;
            readonly threshold: u16;
            readonly delayPeriod: u32;
        } & Struct;
        readonly isInitiateRecovery: boolean;
        readonly asInitiateRecovery: {
            readonly account: AccountId32;
        } & Struct;
        readonly isVouchRecovery: boolean;
        readonly asVouchRecovery: {
            readonly lost: AccountId32;
            readonly rescuer: AccountId32;
        } & Struct;
        readonly isClaimRecovery: boolean;
        readonly asClaimRecovery: {
            readonly account: AccountId32;
        } & Struct;
        readonly isCloseRecovery: boolean;
        readonly asCloseRecovery: {
            readonly rescuer: AccountId32;
        } & Struct;
        readonly isRemoveRecovery: boolean;
        readonly isCancelRecovered: boolean;
        readonly asCancelRecovered: {
            readonly account: AccountId32;
        } & Struct;
        readonly type: 'AsRecovered' | 'SetRecovered' | 'CreateRecovery' | 'InitiateRecovery' | 'VouchRecovery' | 'ClaimRecovery' | 'CloseRecovery' | 'RemoveRecovery' | 'CancelRecovered';
    }
    /** @name PalletVestingCall (285) */
    interface PalletVestingCall extends Enum {
        readonly isVest: boolean;
        readonly isVestOther: boolean;
        readonly asVestOther: {
            readonly target: MultiAddress;
        } & Struct;
        readonly isVestedTransfer: boolean;
        readonly asVestedTransfer: {
            readonly target: MultiAddress;
            readonly schedule: PalletVestingVestingInfo;
        } & Struct;
        readonly isForceVestedTransfer: boolean;
        readonly asForceVestedTransfer: {
            readonly source: MultiAddress;
            readonly target: MultiAddress;
            readonly schedule: PalletVestingVestingInfo;
        } & Struct;
        readonly isMergeSchedules: boolean;
        readonly asMergeSchedules: {
            readonly schedule1Index: u32;
            readonly schedule2Index: u32;
        } & Struct;
        readonly type: 'Vest' | 'VestOther' | 'VestedTransfer' | 'ForceVestedTransfer' | 'MergeSchedules';
    }
    /** @name PalletVestingVestingInfo (286) */
    interface PalletVestingVestingInfo extends Struct {
        readonly locked: u128;
        readonly perBlock: u128;
        readonly startingBlock: u32;
    }
    /** @name PalletSchedulerCall (287) */
    interface PalletSchedulerCall extends Enum {
        readonly isSchedule: boolean;
        readonly asSchedule: {
            readonly when: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: FrameSupportScheduleMaybeHashed;
        } & Struct;
        readonly isCancel: boolean;
        readonly asCancel: {
            readonly when: u32;
            readonly index: u32;
        } & Struct;
        readonly isScheduleNamed: boolean;
        readonly asScheduleNamed: {
            readonly id: Bytes;
            readonly when: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: FrameSupportScheduleMaybeHashed;
        } & Struct;
        readonly isCancelNamed: boolean;
        readonly asCancelNamed: {
            readonly id: Bytes;
        } & Struct;
        readonly isScheduleAfter: boolean;
        readonly asScheduleAfter: {
            readonly after: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: FrameSupportScheduleMaybeHashed;
        } & Struct;
        readonly isScheduleNamedAfter: boolean;
        readonly asScheduleNamedAfter: {
            readonly id: Bytes;
            readonly after: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: FrameSupportScheduleMaybeHashed;
        } & Struct;
        readonly type: 'Schedule' | 'Cancel' | 'ScheduleNamed' | 'CancelNamed' | 'ScheduleAfter' | 'ScheduleNamedAfter';
    }
    /** @name FrameSupportScheduleMaybeHashed (289) */
    interface FrameSupportScheduleMaybeHashed extends Enum {
        readonly isValue: boolean;
        readonly asValue: Call;
        readonly isHash: boolean;
        readonly asHash: H256;
        readonly type: 'Value' | 'Hash';
    }
    /** @name PalletPreimageCall (290) */
    interface PalletPreimageCall extends Enum {
        readonly isNotePreimage: boolean;
        readonly asNotePreimage: {
            readonly bytes: Bytes;
        } & Struct;
        readonly isUnnotePreimage: boolean;
        readonly asUnnotePreimage: {
            readonly hash_: H256;
        } & Struct;
        readonly isRequestPreimage: boolean;
        readonly asRequestPreimage: {
            readonly hash_: H256;
        } & Struct;
        readonly isUnrequestPreimage: boolean;
        readonly asUnrequestPreimage: {
            readonly hash_: H256;
        } & Struct;
        readonly type: 'NotePreimage' | 'UnnotePreimage' | 'RequestPreimage' | 'UnrequestPreimage';
    }
    /** @name PalletProxyCall (291) */
    interface PalletProxyCall extends Enum {
        readonly isProxy: boolean;
        readonly asProxy: {
            readonly real: AccountId32;
            readonly forceProxyType: Option<NodeRuntimeProxyType>;
            readonly call: Call;
        } & Struct;
        readonly isAddProxy: boolean;
        readonly asAddProxy: {
            readonly delegate: AccountId32;
            readonly proxyType: NodeRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly isRemoveProxy: boolean;
        readonly asRemoveProxy: {
            readonly delegate: AccountId32;
            readonly proxyType: NodeRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly isRemoveProxies: boolean;
        readonly isAnonymous: boolean;
        readonly asAnonymous: {
            readonly proxyType: NodeRuntimeProxyType;
            readonly delay: u32;
            readonly index: u16;
        } & Struct;
        readonly isKillAnonymous: boolean;
        readonly asKillAnonymous: {
            readonly spawner: AccountId32;
            readonly proxyType: NodeRuntimeProxyType;
            readonly index: u16;
            readonly height: Compact<u32>;
            readonly extIndex: Compact<u32>;
        } & Struct;
        readonly isAnnounce: boolean;
        readonly asAnnounce: {
            readonly real: AccountId32;
            readonly callHash: H256;
        } & Struct;
        readonly isRemoveAnnouncement: boolean;
        readonly asRemoveAnnouncement: {
            readonly real: AccountId32;
            readonly callHash: H256;
        } & Struct;
        readonly isRejectAnnouncement: boolean;
        readonly asRejectAnnouncement: {
            readonly delegate: AccountId32;
            readonly callHash: H256;
        } & Struct;
        readonly isProxyAnnounced: boolean;
        readonly asProxyAnnounced: {
            readonly delegate: AccountId32;
            readonly real: AccountId32;
            readonly forceProxyType: Option<NodeRuntimeProxyType>;
            readonly call: Call;
        } & Struct;
        readonly type: 'Proxy' | 'AddProxy' | 'RemoveProxy' | 'RemoveProxies' | 'Anonymous' | 'KillAnonymous' | 'Announce' | 'RemoveAnnouncement' | 'RejectAnnouncement' | 'ProxyAnnounced';
    }
    /** @name PalletMultisigCall (293) */
    interface PalletMultisigCall extends Enum {
        readonly isAsMultiThreshold1: boolean;
        readonly asAsMultiThreshold1: {
            readonly otherSignatories: Vec<AccountId32>;
            readonly call: Call;
        } & Struct;
        readonly isAsMulti: boolean;
        readonly asAsMulti: {
            readonly threshold: u16;
            readonly otherSignatories: Vec<AccountId32>;
            readonly maybeTimepoint: Option<PalletMultisigTimepoint>;
            readonly call: WrapperKeepOpaque<Call>;
            readonly storeCall: bool;
            readonly maxWeight: u64;
        } & Struct;
        readonly isApproveAsMulti: boolean;
        readonly asApproveAsMulti: {
            readonly threshold: u16;
            readonly otherSignatories: Vec<AccountId32>;
            readonly maybeTimepoint: Option<PalletMultisigTimepoint>;
            readonly callHash: U8aFixed;
            readonly maxWeight: u64;
        } & Struct;
        readonly isCancelAsMulti: boolean;
        readonly asCancelAsMulti: {
            readonly threshold: u16;
            readonly otherSignatories: Vec<AccountId32>;
            readonly timepoint: PalletMultisigTimepoint;
            readonly callHash: U8aFixed;
        } & Struct;
        readonly type: 'AsMultiThreshold1' | 'AsMulti' | 'ApproveAsMulti' | 'CancelAsMulti';
    }
    /** @name PalletBountiesCall (296) */
    interface PalletBountiesCall extends Enum {
        readonly isProposeBounty: boolean;
        readonly asProposeBounty: {
            readonly value: Compact<u128>;
            readonly description: Bytes;
        } & Struct;
        readonly isApproveBounty: boolean;
        readonly asApproveBounty: {
            readonly bountyId: Compact<u32>;
        } & Struct;
        readonly isProposeCurator: boolean;
        readonly asProposeCurator: {
            readonly bountyId: Compact<u32>;
            readonly curator: MultiAddress;
            readonly fee: Compact<u128>;
        } & Struct;
        readonly isUnassignCurator: boolean;
        readonly asUnassignCurator: {
            readonly bountyId: Compact<u32>;
        } & Struct;
        readonly isAcceptCurator: boolean;
        readonly asAcceptCurator: {
            readonly bountyId: Compact<u32>;
        } & Struct;
        readonly isAwardBounty: boolean;
        readonly asAwardBounty: {
            readonly bountyId: Compact<u32>;
            readonly beneficiary: MultiAddress;
        } & Struct;
        readonly isClaimBounty: boolean;
        readonly asClaimBounty: {
            readonly bountyId: Compact<u32>;
        } & Struct;
        readonly isCloseBounty: boolean;
        readonly asCloseBounty: {
            readonly bountyId: Compact<u32>;
        } & Struct;
        readonly isExtendBountyExpiry: boolean;
        readonly asExtendBountyExpiry: {
            readonly bountyId: Compact<u32>;
            readonly remark: Bytes;
        } & Struct;
        readonly type: 'ProposeBounty' | 'ApproveBounty' | 'ProposeCurator' | 'UnassignCurator' | 'AcceptCurator' | 'AwardBounty' | 'ClaimBounty' | 'CloseBounty' | 'ExtendBountyExpiry';
    }
    /** @name PalletTipsCall (297) */
    interface PalletTipsCall extends Enum {
        readonly isReportAwesome: boolean;
        readonly asReportAwesome: {
            readonly reason: Bytes;
            readonly who: AccountId32;
        } & Struct;
        readonly isRetractTip: boolean;
        readonly asRetractTip: {
            readonly hash_: H256;
        } & Struct;
        readonly isTipNew: boolean;
        readonly asTipNew: {
            readonly reason: Bytes;
            readonly who: AccountId32;
            readonly tipValue: Compact<u128>;
        } & Struct;
        readonly isTip: boolean;
        readonly asTip: {
            readonly hash_: H256;
            readonly tipValue: Compact<u128>;
        } & Struct;
        readonly isCloseTip: boolean;
        readonly asCloseTip: {
            readonly hash_: H256;
        } & Struct;
        readonly isSlashTip: boolean;
        readonly asSlashTip: {
            readonly hash_: H256;
        } & Struct;
        readonly type: 'ReportAwesome' | 'RetractTip' | 'TipNew' | 'Tip' | 'CloseTip' | 'SlashTip';
    }
    /** @name PalletAssetsCall (298) */
    interface PalletAssetsCall extends Enum {
        readonly isCreate: boolean;
        readonly asCreate: {
            readonly id: Compact<u32>;
            readonly admin: MultiAddress;
            readonly minBalance: u128;
        } & Struct;
        readonly isForceCreate: boolean;
        readonly asForceCreate: {
            readonly id: Compact<u32>;
            readonly owner: MultiAddress;
            readonly isSufficient: bool;
            readonly minBalance: Compact<u128>;
        } & Struct;
        readonly isDestroy: boolean;
        readonly asDestroy: {
            readonly id: Compact<u32>;
            readonly witness: PalletAssetsDestroyWitness;
        } & Struct;
        readonly isMint: boolean;
        readonly asMint: {
            readonly id: Compact<u32>;
            readonly beneficiary: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isBurn: boolean;
        readonly asBurn: {
            readonly id: Compact<u32>;
            readonly who: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly id: Compact<u32>;
            readonly target: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isTransferKeepAlive: boolean;
        readonly asTransferKeepAlive: {
            readonly id: Compact<u32>;
            readonly target: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isForceTransfer: boolean;
        readonly asForceTransfer: {
            readonly id: Compact<u32>;
            readonly source: MultiAddress;
            readonly dest: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isFreeze: boolean;
        readonly asFreeze: {
            readonly id: Compact<u32>;
            readonly who: MultiAddress;
        } & Struct;
        readonly isThaw: boolean;
        readonly asThaw: {
            readonly id: Compact<u32>;
            readonly who: MultiAddress;
        } & Struct;
        readonly isFreezeAsset: boolean;
        readonly asFreezeAsset: {
            readonly id: Compact<u32>;
        } & Struct;
        readonly isThawAsset: boolean;
        readonly asThawAsset: {
            readonly id: Compact<u32>;
        } & Struct;
        readonly isTransferOwnership: boolean;
        readonly asTransferOwnership: {
            readonly id: Compact<u32>;
            readonly owner: MultiAddress;
        } & Struct;
        readonly isSetTeam: boolean;
        readonly asSetTeam: {
            readonly id: Compact<u32>;
            readonly issuer: MultiAddress;
            readonly admin: MultiAddress;
            readonly freezer: MultiAddress;
        } & Struct;
        readonly isSetMetadata: boolean;
        readonly asSetMetadata: {
            readonly id: Compact<u32>;
            readonly name: Bytes;
            readonly symbol: Bytes;
            readonly decimals: u8;
        } & Struct;
        readonly isClearMetadata: boolean;
        readonly asClearMetadata: {
            readonly id: Compact<u32>;
        } & Struct;
        readonly isForceSetMetadata: boolean;
        readonly asForceSetMetadata: {
            readonly id: Compact<u32>;
            readonly name: Bytes;
            readonly symbol: Bytes;
            readonly decimals: u8;
            readonly isFrozen: bool;
        } & Struct;
        readonly isForceClearMetadata: boolean;
        readonly asForceClearMetadata: {
            readonly id: Compact<u32>;
        } & Struct;
        readonly isForceAssetStatus: boolean;
        readonly asForceAssetStatus: {
            readonly id: Compact<u32>;
            readonly owner: MultiAddress;
            readonly issuer: MultiAddress;
            readonly admin: MultiAddress;
            readonly freezer: MultiAddress;
            readonly minBalance: Compact<u128>;
            readonly isSufficient: bool;
            readonly isFrozen: bool;
        } & Struct;
        readonly isApproveTransfer: boolean;
        readonly asApproveTransfer: {
            readonly id: Compact<u32>;
            readonly delegate: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isCancelApproval: boolean;
        readonly asCancelApproval: {
            readonly id: Compact<u32>;
            readonly delegate: MultiAddress;
        } & Struct;
        readonly isForceCancelApproval: boolean;
        readonly asForceCancelApproval: {
            readonly id: Compact<u32>;
            readonly owner: MultiAddress;
            readonly delegate: MultiAddress;
        } & Struct;
        readonly isTransferApproved: boolean;
        readonly asTransferApproved: {
            readonly id: Compact<u32>;
            readonly owner: MultiAddress;
            readonly destination: MultiAddress;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isTouch: boolean;
        readonly asTouch: {
            readonly id: Compact<u32>;
        } & Struct;
        readonly isRefund: boolean;
        readonly asRefund: {
            readonly id: Compact<u32>;
            readonly allowBurn: bool;
        } & Struct;
        readonly type: 'Create' | 'ForceCreate' | 'Destroy' | 'Mint' | 'Burn' | 'Transfer' | 'TransferKeepAlive' | 'ForceTransfer' | 'Freeze' | 'Thaw' | 'FreezeAsset' | 'ThawAsset' | 'TransferOwnership' | 'SetTeam' | 'SetMetadata' | 'ClearMetadata' | 'ForceSetMetadata' | 'ForceClearMetadata' | 'ForceAssetStatus' | 'ApproveTransfer' | 'CancelApproval' | 'ForceCancelApproval' | 'TransferApproved' | 'Touch' | 'Refund';
    }
    /** @name PalletAssetsDestroyWitness (299) */
    interface PalletAssetsDestroyWitness extends Struct {
        readonly accounts: Compact<u32>;
        readonly sufficients: Compact<u32>;
        readonly approvals: Compact<u32>;
    }
    /** @name PalletLotteryCall (300) */
    interface PalletLotteryCall extends Enum {
        readonly isBuyTicket: boolean;
        readonly asBuyTicket: {
            readonly call: Call;
        } & Struct;
        readonly isSetCalls: boolean;
        readonly asSetCalls: {
            readonly calls: Vec<Call>;
        } & Struct;
        readonly isStartLottery: boolean;
        readonly asStartLottery: {
            readonly price: u128;
            readonly length: u32;
            readonly delay: u32;
            readonly repeat: bool;
        } & Struct;
        readonly isStopRepeat: boolean;
        readonly type: 'BuyTicket' | 'SetCalls' | 'StartLottery' | 'StopRepeat';
    }
    /** @name PalletGiltCall (301) */
    interface PalletGiltCall extends Enum {
        readonly isPlaceBid: boolean;
        readonly asPlaceBid: {
            readonly amount: Compact<u128>;
            readonly duration: u32;
        } & Struct;
        readonly isRetractBid: boolean;
        readonly asRetractBid: {
            readonly amount: Compact<u128>;
            readonly duration: u32;
        } & Struct;
        readonly isSetTarget: boolean;
        readonly asSetTarget: {
            readonly target: Compact<Perquintill>;
        } & Struct;
        readonly isThaw: boolean;
        readonly asThaw: {
            readonly index: Compact<u32>;
        } & Struct;
        readonly type: 'PlaceBid' | 'RetractBid' | 'SetTarget' | 'Thaw';
    }
    /** @name PalletUniquesCall (304) */
    interface PalletUniquesCall extends Enum {
        readonly isCreate: boolean;
        readonly asCreate: {
            readonly class: Compact<u32>;
            readonly admin: MultiAddress;
        } & Struct;
        readonly isForceCreate: boolean;
        readonly asForceCreate: {
            readonly class: Compact<u32>;
            readonly owner: MultiAddress;
            readonly freeHolding: bool;
        } & Struct;
        readonly isDestroy: boolean;
        readonly asDestroy: {
            readonly class: Compact<u32>;
            readonly witness: PalletUniquesDestroyWitness;
        } & Struct;
        readonly isMint: boolean;
        readonly asMint: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
            readonly owner: MultiAddress;
        } & Struct;
        readonly isBurn: boolean;
        readonly asBurn: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
            readonly checkOwner: Option<MultiAddress>;
        } & Struct;
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
            readonly dest: MultiAddress;
        } & Struct;
        readonly isRedeposit: boolean;
        readonly asRedeposit: {
            readonly class: Compact<u32>;
            readonly instances: Vec<u32>;
        } & Struct;
        readonly isFreeze: boolean;
        readonly asFreeze: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
        } & Struct;
        readonly isThaw: boolean;
        readonly asThaw: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
        } & Struct;
        readonly isFreezeClass: boolean;
        readonly asFreezeClass: {
            readonly class: Compact<u32>;
        } & Struct;
        readonly isThawClass: boolean;
        readonly asThawClass: {
            readonly class: Compact<u32>;
        } & Struct;
        readonly isTransferOwnership: boolean;
        readonly asTransferOwnership: {
            readonly class: Compact<u32>;
            readonly owner: MultiAddress;
        } & Struct;
        readonly isSetTeam: boolean;
        readonly asSetTeam: {
            readonly class: Compact<u32>;
            readonly issuer: MultiAddress;
            readonly admin: MultiAddress;
            readonly freezer: MultiAddress;
        } & Struct;
        readonly isApproveTransfer: boolean;
        readonly asApproveTransfer: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
            readonly delegate: MultiAddress;
        } & Struct;
        readonly isCancelApproval: boolean;
        readonly asCancelApproval: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
            readonly maybeCheckDelegate: Option<MultiAddress>;
        } & Struct;
        readonly isForceAssetStatus: boolean;
        readonly asForceAssetStatus: {
            readonly class: Compact<u32>;
            readonly owner: MultiAddress;
            readonly issuer: MultiAddress;
            readonly admin: MultiAddress;
            readonly freezer: MultiAddress;
            readonly freeHolding: bool;
            readonly isFrozen: bool;
        } & Struct;
        readonly isSetAttribute: boolean;
        readonly asSetAttribute: {
            readonly class: Compact<u32>;
            readonly maybeInstance: Option<u32>;
            readonly key: Bytes;
            readonly value: Bytes;
        } & Struct;
        readonly isClearAttribute: boolean;
        readonly asClearAttribute: {
            readonly class: Compact<u32>;
            readonly maybeInstance: Option<u32>;
            readonly key: Bytes;
        } & Struct;
        readonly isSetMetadata: boolean;
        readonly asSetMetadata: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
            readonly data: Bytes;
            readonly isFrozen: bool;
        } & Struct;
        readonly isClearMetadata: boolean;
        readonly asClearMetadata: {
            readonly class: Compact<u32>;
            readonly instance: Compact<u32>;
        } & Struct;
        readonly isSetClassMetadata: boolean;
        readonly asSetClassMetadata: {
            readonly class: Compact<u32>;
            readonly data: Bytes;
            readonly isFrozen: bool;
        } & Struct;
        readonly isClearClassMetadata: boolean;
        readonly asClearClassMetadata: {
            readonly class: Compact<u32>;
        } & Struct;
        readonly type: 'Create' | 'ForceCreate' | 'Destroy' | 'Mint' | 'Burn' | 'Transfer' | 'Redeposit' | 'Freeze' | 'Thaw' | 'FreezeClass' | 'ThawClass' | 'TransferOwnership' | 'SetTeam' | 'ApproveTransfer' | 'CancelApproval' | 'ForceAssetStatus' | 'SetAttribute' | 'ClearAttribute' | 'SetMetadata' | 'ClearMetadata' | 'SetClassMetadata' | 'ClearClassMetadata';
    }
    /** @name PalletUniquesDestroyWitness (305) */
    interface PalletUniquesDestroyWitness extends Struct {
        readonly instances: Compact<u32>;
        readonly instanceMetadatas: Compact<u32>;
        readonly attributes: Compact<u32>;
    }
    /** @name PalletTransactionStorageCall (307) */
    interface PalletTransactionStorageCall extends Enum {
        readonly isStore: boolean;
        readonly asStore: {
            readonly data: Bytes;
        } & Struct;
        readonly isRenew: boolean;
        readonly asRenew: {
            readonly block: u32;
            readonly index: u32;
        } & Struct;
        readonly isCheckProof: boolean;
        readonly asCheckProof: {
            readonly proof: SpTransactionStorageProofTransactionStorageProof;
        } & Struct;
        readonly type: 'Store' | 'Renew' | 'CheckProof';
    }
    /** @name SpTransactionStorageProofTransactionStorageProof (308) */
    interface SpTransactionStorageProofTransactionStorageProof extends Struct {
        readonly chunk: Bytes;
        readonly proof: Vec<Bytes>;
    }
    /** @name PalletBagsListCall (309) */
    interface PalletBagsListCall extends Enum {
        readonly isRebag: boolean;
        readonly asRebag: {
            readonly dislocated: AccountId32;
        } & Struct;
        readonly isPutInFrontOf: boolean;
        readonly asPutInFrontOf: {
            readonly lighter: AccountId32;
        } & Struct;
        readonly type: 'Rebag' | 'PutInFrontOf';
    }
    /** @name PalletChildBountiesCall (310) */
    interface PalletChildBountiesCall extends Enum {
        readonly isAddChildBounty: boolean;
        readonly asAddChildBounty: {
            readonly parentBountyId: Compact<u32>;
            readonly value: Compact<u128>;
            readonly description: Bytes;
        } & Struct;
        readonly isProposeCurator: boolean;
        readonly asProposeCurator: {
            readonly parentBountyId: Compact<u32>;
            readonly childBountyId: Compact<u32>;
            readonly curator: MultiAddress;
            readonly fee: Compact<u128>;
        } & Struct;
        readonly isAcceptCurator: boolean;
        readonly asAcceptCurator: {
            readonly parentBountyId: Compact<u32>;
            readonly childBountyId: Compact<u32>;
        } & Struct;
        readonly isUnassignCurator: boolean;
        readonly asUnassignCurator: {
            readonly parentBountyId: Compact<u32>;
            readonly childBountyId: Compact<u32>;
        } & Struct;
        readonly isAwardChildBounty: boolean;
        readonly asAwardChildBounty: {
            readonly parentBountyId: Compact<u32>;
            readonly childBountyId: Compact<u32>;
            readonly beneficiary: MultiAddress;
        } & Struct;
        readonly isClaimChildBounty: boolean;
        readonly asClaimChildBounty: {
            readonly parentBountyId: Compact<u32>;
            readonly childBountyId: Compact<u32>;
        } & Struct;
        readonly isCloseChildBounty: boolean;
        readonly asCloseChildBounty: {
            readonly parentBountyId: Compact<u32>;
            readonly childBountyId: Compact<u32>;
        } & Struct;
        readonly type: 'AddChildBounty' | 'ProposeCurator' | 'AcceptCurator' | 'UnassignCurator' | 'AwardChildBounty' | 'ClaimChildBounty' | 'CloseChildBounty';
    }
    /** @name NodeRuntimeOriginCaller (311) */
    interface NodeRuntimeOriginCaller extends Enum {
        readonly isSystem: boolean;
        readonly asSystem: FrameSystemRawOrigin;
        readonly isVoid: boolean;
        readonly isCouncil: boolean;
        readonly asCouncil: PalletCollectiveRawOrigin;
        readonly isTechnicalCommittee: boolean;
        readonly asTechnicalCommittee: PalletCollectiveRawOrigin;
        readonly type: 'System' | 'Void' | 'Council' | 'TechnicalCommittee';
    }
    /** @name FrameSystemRawOrigin (312) */
    interface FrameSystemRawOrigin extends Enum {
        readonly isRoot: boolean;
        readonly isSigned: boolean;
        readonly asSigned: AccountId32;
        readonly isNone: boolean;
        readonly type: 'Root' | 'Signed' | 'None';
    }
    /** @name PalletCollectiveRawOrigin (313) */
    interface PalletCollectiveRawOrigin extends Enum {
        readonly isMembers: boolean;
        readonly asMembers: ITuple<[u32, u32]>;
        readonly isMember: boolean;
        readonly asMember: AccountId32;
        readonly isPhantom: boolean;
        readonly type: 'Members' | 'Member' | 'Phantom';
    }
    /** @name SpCoreVoid (315) */
    type SpCoreVoid = Null;
    /** @name PalletUtilityError (316) */
    interface PalletUtilityError extends Enum {
        readonly isTooManyCalls: boolean;
        readonly type: 'TooManyCalls';
    }
    /** @name SpConsensusBabeBabeEpochConfiguration (323) */
    interface SpConsensusBabeBabeEpochConfiguration extends Struct {
        readonly c: ITuple<[u64, u64]>;
        readonly allowedSlots: SpConsensusBabeAllowedSlots;
    }
    /** @name PalletBabeError (324) */
    interface PalletBabeError extends Enum {
        readonly isInvalidEquivocationProof: boolean;
        readonly isInvalidKeyOwnershipProof: boolean;
        readonly isDuplicateOffenceReport: boolean;
        readonly type: 'InvalidEquivocationProof' | 'InvalidKeyOwnershipProof' | 'DuplicateOffenceReport';
    }
    /** @name PalletAuthorshipUncleEntryItem (326) */
    interface PalletAuthorshipUncleEntryItem extends Enum {
        readonly isInclusionHeight: boolean;
        readonly asInclusionHeight: u32;
        readonly isUncle: boolean;
        readonly asUncle: ITuple<[H256, Option<AccountId32>]>;
        readonly type: 'InclusionHeight' | 'Uncle';
    }
    /** @name PalletAuthorshipError (327) */
    interface PalletAuthorshipError extends Enum {
        readonly isInvalidUncleParent: boolean;
        readonly isUnclesAlreadySet: boolean;
        readonly isTooManyUncles: boolean;
        readonly isGenesisUncle: boolean;
        readonly isTooHighUncle: boolean;
        readonly isUncleAlreadyIncluded: boolean;
        readonly isOldUncle: boolean;
        readonly type: 'InvalidUncleParent' | 'UnclesAlreadySet' | 'TooManyUncles' | 'GenesisUncle' | 'TooHighUncle' | 'UncleAlreadyIncluded' | 'OldUncle';
    }
    /** @name PalletIndicesError (329) */
    interface PalletIndicesError extends Enum {
        readonly isNotAssigned: boolean;
        readonly isNotOwner: boolean;
        readonly isInUse: boolean;
        readonly isNotTransfer: boolean;
        readonly isPermanent: boolean;
        readonly type: 'NotAssigned' | 'NotOwner' | 'InUse' | 'NotTransfer' | 'Permanent';
    }
    /** @name PalletBalancesBalanceLock (331) */
    interface PalletBalancesBalanceLock extends Struct {
        readonly id: U8aFixed;
        readonly amount: u128;
        readonly reasons: PalletBalancesReasons;
    }
    /** @name PalletBalancesReasons (332) */
    interface PalletBalancesReasons extends Enum {
        readonly isFee: boolean;
        readonly isMisc: boolean;
        readonly isAll: boolean;
        readonly type: 'Fee' | 'Misc' | 'All';
    }
    /** @name PalletBalancesReserveData (335) */
    interface PalletBalancesReserveData extends Struct {
        readonly id: U8aFixed;
        readonly amount: u128;
    }
    /** @name PalletBalancesReleases (337) */
    interface PalletBalancesReleases extends Enum {
        readonly isV100: boolean;
        readonly isV200: boolean;
        readonly type: 'V100' | 'V200';
    }
    /** @name PalletBalancesError (338) */
    interface PalletBalancesError extends Enum {
        readonly isVestingBalance: boolean;
        readonly isLiquidityRestrictions: boolean;
        readonly isInsufficientBalance: boolean;
        readonly isExistentialDeposit: boolean;
        readonly isKeepAlive: boolean;
        readonly isExistingVestingSchedule: boolean;
        readonly isDeadAccount: boolean;
        readonly isTooManyReserves: boolean;
        readonly type: 'VestingBalance' | 'LiquidityRestrictions' | 'InsufficientBalance' | 'ExistentialDeposit' | 'KeepAlive' | 'ExistingVestingSchedule' | 'DeadAccount' | 'TooManyReserves';
    }
    /** @name PalletTransactionPaymentReleases (340) */
    interface PalletTransactionPaymentReleases extends Enum {
        readonly isV1Ancient: boolean;
        readonly isV2: boolean;
        readonly type: 'V1Ancient' | 'V2';
    }
    /** @name FrameSupportWeightsWeightToFeeCoefficient (342) */
    interface FrameSupportWeightsWeightToFeeCoefficient extends Struct {
        readonly coeffInteger: u128;
        readonly coeffFrac: Perbill;
        readonly negative: bool;
        readonly degree: u8;
    }
    /** @name PalletElectionProviderMultiPhasePhase (343) */
    interface PalletElectionProviderMultiPhasePhase extends Enum {
        readonly isOff: boolean;
        readonly isSigned: boolean;
        readonly isUnsigned: boolean;
        readonly asUnsigned: ITuple<[bool, u32]>;
        readonly isEmergency: boolean;
        readonly type: 'Off' | 'Signed' | 'Unsigned' | 'Emergency';
    }
    /** @name PalletElectionProviderMultiPhaseReadySolution (345) */
    interface PalletElectionProviderMultiPhaseReadySolution extends Struct {
        readonly supports: Vec<ITuple<[AccountId32, SpNposElectionsSupport]>>;
        readonly score: Vec<u128>;
        readonly compute: PalletElectionProviderMultiPhaseElectionCompute;
    }
    /** @name PalletElectionProviderMultiPhaseRoundSnapshot (346) */
    interface PalletElectionProviderMultiPhaseRoundSnapshot extends Struct {
        readonly voters: Vec<ITuple<[AccountId32, u64, Vec<AccountId32>]>>;
        readonly targets: Vec<AccountId32>;
    }
    /** @name PalletElectionProviderMultiPhaseSignedSignedSubmission (353) */
    interface PalletElectionProviderMultiPhaseSignedSignedSubmission extends Struct {
        readonly who: AccountId32;
        readonly deposit: u128;
        readonly rawSolution: PalletElectionProviderMultiPhaseRawSolution;
        readonly reward: u128;
    }
    /** @name PalletElectionProviderMultiPhaseError (354) */
    interface PalletElectionProviderMultiPhaseError extends Enum {
        readonly isPreDispatchEarlySubmission: boolean;
        readonly isPreDispatchWrongWinnerCount: boolean;
        readonly isPreDispatchWeakSubmission: boolean;
        readonly isSignedQueueFull: boolean;
        readonly isSignedCannotPayDeposit: boolean;
        readonly isSignedInvalidWitness: boolean;
        readonly isSignedTooMuchWeight: boolean;
        readonly isOcwCallWrongEra: boolean;
        readonly isMissingSnapshotMetadata: boolean;
        readonly isInvalidSubmissionIndex: boolean;
        readonly isCallNotAllowed: boolean;
        readonly type: 'PreDispatchEarlySubmission' | 'PreDispatchWrongWinnerCount' | 'PreDispatchWeakSubmission' | 'SignedQueueFull' | 'SignedCannotPayDeposit' | 'SignedInvalidWitness' | 'SignedTooMuchWeight' | 'OcwCallWrongEra' | 'MissingSnapshotMetadata' | 'InvalidSubmissionIndex' | 'CallNotAllowed';
    }
    /** @name PalletStakingStakingLedger (355) */
    interface PalletStakingStakingLedger extends Struct {
        readonly stash: AccountId32;
        readonly total: Compact<u128>;
        readonly active: Compact<u128>;
        readonly unlocking: Vec<PalletStakingUnlockChunk>;
        readonly claimedRewards: Vec<u32>;
    }
    /** @name PalletStakingUnlockChunk (357) */
    interface PalletStakingUnlockChunk extends Struct {
        readonly value: Compact<u128>;
        readonly era: Compact<u32>;
    }
    /** @name PalletStakingNominations (358) */
    interface PalletStakingNominations extends Struct {
        readonly targets: Vec<AccountId32>;
        readonly submittedIn: u32;
        readonly suppressed: bool;
    }
    /** @name PalletStakingActiveEraInfo (359) */
    interface PalletStakingActiveEraInfo extends Struct {
        readonly index: u32;
        readonly start: Option<u64>;
    }
    /** @name PalletStakingEraRewardPoints (361) */
    interface PalletStakingEraRewardPoints extends Struct {
        readonly total: u32;
        readonly individual: BTreeMap<AccountId32, u32>;
    }
    /** @name PalletStakingForcing (365) */
    interface PalletStakingForcing extends Enum {
        readonly isNotForcing: boolean;
        readonly isForceNew: boolean;
        readonly isForceNone: boolean;
        readonly isForceAlways: boolean;
        readonly type: 'NotForcing' | 'ForceNew' | 'ForceNone' | 'ForceAlways';
    }
    /** @name PalletStakingUnappliedSlash (367) */
    interface PalletStakingUnappliedSlash extends Struct {
        readonly validator: AccountId32;
        readonly own: u128;
        readonly others: Vec<ITuple<[AccountId32, u128]>>;
        readonly reporters: Vec<AccountId32>;
        readonly payout: u128;
    }
    /** @name PalletStakingSlashingSlashingSpans (369) */
    interface PalletStakingSlashingSlashingSpans extends Struct {
        readonly spanIndex: u32;
        readonly lastStart: u32;
        readonly lastNonzeroSlash: u32;
        readonly prior: Vec<u32>;
    }
    /** @name PalletStakingSlashingSpanRecord (370) */
    interface PalletStakingSlashingSpanRecord extends Struct {
        readonly slashed: u128;
        readonly paidOut: u128;
    }
    /** @name PalletStakingReleases (373) */
    interface PalletStakingReleases extends Enum {
        readonly isV100Ancient: boolean;
        readonly isV200: boolean;
        readonly isV300: boolean;
        readonly isV400: boolean;
        readonly isV500: boolean;
        readonly isV600: boolean;
        readonly isV700: boolean;
        readonly isV800: boolean;
        readonly type: 'V100Ancient' | 'V200' | 'V300' | 'V400' | 'V500' | 'V600' | 'V700' | 'V800';
    }
    /** @name PalletStakingPalletError (374) */
    interface PalletStakingPalletError extends Enum {
        readonly isNotController: boolean;
        readonly isNotStash: boolean;
        readonly isAlreadyBonded: boolean;
        readonly isAlreadyPaired: boolean;
        readonly isEmptyTargets: boolean;
        readonly isDuplicateIndex: boolean;
        readonly isInvalidSlashIndex: boolean;
        readonly isInsufficientBond: boolean;
        readonly isNoMoreChunks: boolean;
        readonly isNoUnlockChunk: boolean;
        readonly isFundedTarget: boolean;
        readonly isInvalidEraToReward: boolean;
        readonly isInvalidNumberOfNominations: boolean;
        readonly isNotSortedAndUnique: boolean;
        readonly isAlreadyClaimed: boolean;
        readonly isIncorrectHistoryDepth: boolean;
        readonly isIncorrectSlashingSpans: boolean;
        readonly isBadState: boolean;
        readonly isTooManyTargets: boolean;
        readonly isBadTarget: boolean;
        readonly isCannotChillOther: boolean;
        readonly isTooManyNominators: boolean;
        readonly isTooManyValidators: boolean;
        readonly isCommissionTooLow: boolean;
        readonly type: 'NotController' | 'NotStash' | 'AlreadyBonded' | 'AlreadyPaired' | 'EmptyTargets' | 'DuplicateIndex' | 'InvalidSlashIndex' | 'InsufficientBond' | 'NoMoreChunks' | 'NoUnlockChunk' | 'FundedTarget' | 'InvalidEraToReward' | 'InvalidNumberOfNominations' | 'NotSortedAndUnique' | 'AlreadyClaimed' | 'IncorrectHistoryDepth' | 'IncorrectSlashingSpans' | 'BadState' | 'TooManyTargets' | 'BadTarget' | 'CannotChillOther' | 'TooManyNominators' | 'TooManyValidators' | 'CommissionTooLow';
    }
    /** @name SpCoreCryptoKeyTypeId (378) */
    interface SpCoreCryptoKeyTypeId extends U8aFixed {
    }
    /** @name PalletSessionError (379) */
    interface PalletSessionError extends Enum {
        readonly isInvalidProof: boolean;
        readonly isNoAssociatedValidatorId: boolean;
        readonly isDuplicatedKey: boolean;
        readonly isNoKeys: boolean;
        readonly isNoAccount: boolean;
        readonly type: 'InvalidProof' | 'NoAssociatedValidatorId' | 'DuplicatedKey' | 'NoKeys' | 'NoAccount';
    }
    /** @name PalletDemocracyPreimageStatus (383) */
    interface PalletDemocracyPreimageStatus extends Enum {
        readonly isMissing: boolean;
        readonly asMissing: u32;
        readonly isAvailable: boolean;
        readonly asAvailable: {
            readonly data: Bytes;
            readonly provider: AccountId32;
            readonly deposit: u128;
            readonly since: u32;
            readonly expiry: Option<u32>;
        } & Struct;
        readonly type: 'Missing' | 'Available';
    }
    /** @name PalletDemocracyReferendumInfo (384) */
    interface PalletDemocracyReferendumInfo extends Enum {
        readonly isOngoing: boolean;
        readonly asOngoing: PalletDemocracyReferendumStatus;
        readonly isFinished: boolean;
        readonly asFinished: {
            readonly approved: bool;
            readonly end: u32;
        } & Struct;
        readonly type: 'Ongoing' | 'Finished';
    }
    /** @name PalletDemocracyReferendumStatus (385) */
    interface PalletDemocracyReferendumStatus extends Struct {
        readonly end: u32;
        readonly proposalHash: H256;
        readonly threshold: PalletDemocracyVoteThreshold;
        readonly delay: u32;
        readonly tally: PalletDemocracyTally;
    }
    /** @name PalletDemocracyTally (386) */
    interface PalletDemocracyTally extends Struct {
        readonly ayes: u128;
        readonly nays: u128;
        readonly turnout: u128;
    }
    /** @name PalletDemocracyVoteVoting (387) */
    interface PalletDemocracyVoteVoting extends Enum {
        readonly isDirect: boolean;
        readonly asDirect: {
            readonly votes: Vec<ITuple<[u32, PalletDemocracyVoteAccountVote]>>;
            readonly delegations: PalletDemocracyDelegations;
            readonly prior: PalletDemocracyVotePriorLock;
        } & Struct;
        readonly isDelegating: boolean;
        readonly asDelegating: {
            readonly balance: u128;
            readonly target: AccountId32;
            readonly conviction: PalletDemocracyConviction;
            readonly delegations: PalletDemocracyDelegations;
            readonly prior: PalletDemocracyVotePriorLock;
        } & Struct;
        readonly type: 'Direct' | 'Delegating';
    }
    /** @name PalletDemocracyDelegations (390) */
    interface PalletDemocracyDelegations extends Struct {
        readonly votes: u128;
        readonly capital: u128;
    }
    /** @name PalletDemocracyVotePriorLock (391) */
    interface PalletDemocracyVotePriorLock extends ITuple<[u32, u128]> {
    }
    /** @name PalletDemocracyReleases (394) */
    interface PalletDemocracyReleases extends Enum {
        readonly isV1: boolean;
        readonly type: 'V1';
    }
    /** @name PalletDemocracyError (395) */
    interface PalletDemocracyError extends Enum {
        readonly isValueLow: boolean;
        readonly isProposalMissing: boolean;
        readonly isAlreadyCanceled: boolean;
        readonly isDuplicateProposal: boolean;
        readonly isProposalBlacklisted: boolean;
        readonly isNotSimpleMajority: boolean;
        readonly isInvalidHash: boolean;
        readonly isNoProposal: boolean;
        readonly isAlreadyVetoed: boolean;
        readonly isDuplicatePreimage: boolean;
        readonly isNotImminent: boolean;
        readonly isTooEarly: boolean;
        readonly isImminent: boolean;
        readonly isPreimageMissing: boolean;
        readonly isReferendumInvalid: boolean;
        readonly isPreimageInvalid: boolean;
        readonly isNoneWaiting: boolean;
        readonly isNotVoter: boolean;
        readonly isNoPermission: boolean;
        readonly isAlreadyDelegating: boolean;
        readonly isInsufficientFunds: boolean;
        readonly isNotDelegating: boolean;
        readonly isVotesExist: boolean;
        readonly isInstantNotAllowed: boolean;
        readonly isNonsense: boolean;
        readonly isWrongUpperBound: boolean;
        readonly isMaxVotesReached: boolean;
        readonly isTooManyProposals: boolean;
        readonly type: 'ValueLow' | 'ProposalMissing' | 'AlreadyCanceled' | 'DuplicateProposal' | 'ProposalBlacklisted' | 'NotSimpleMajority' | 'InvalidHash' | 'NoProposal' | 'AlreadyVetoed' | 'DuplicatePreimage' | 'NotImminent' | 'TooEarly' | 'Imminent' | 'PreimageMissing' | 'ReferendumInvalid' | 'PreimageInvalid' | 'NoneWaiting' | 'NotVoter' | 'NoPermission' | 'AlreadyDelegating' | 'InsufficientFunds' | 'NotDelegating' | 'VotesExist' | 'InstantNotAllowed' | 'Nonsense' | 'WrongUpperBound' | 'MaxVotesReached' | 'TooManyProposals';
    }
    /** @name PalletCollectiveVotes (397) */
    interface PalletCollectiveVotes extends Struct {
        readonly index: u32;
        readonly threshold: u32;
        readonly ayes: Vec<AccountId32>;
        readonly nays: Vec<AccountId32>;
        readonly end: u32;
    }
    /** @name PalletCollectiveError (398) */
    interface PalletCollectiveError extends Enum {
        readonly isNotMember: boolean;
        readonly isDuplicateProposal: boolean;
        readonly isProposalMissing: boolean;
        readonly isWrongIndex: boolean;
        readonly isDuplicateVote: boolean;
        readonly isAlreadyInitialized: boolean;
        readonly isTooEarly: boolean;
        readonly isTooManyProposals: boolean;
        readonly isWrongProposalWeight: boolean;
        readonly isWrongProposalLength: boolean;
        readonly type: 'NotMember' | 'DuplicateProposal' | 'ProposalMissing' | 'WrongIndex' | 'DuplicateVote' | 'AlreadyInitialized' | 'TooEarly' | 'TooManyProposals' | 'WrongProposalWeight' | 'WrongProposalLength';
    }
    /** @name PalletElectionsPhragmenSeatHolder (402) */
    interface PalletElectionsPhragmenSeatHolder extends Struct {
        readonly who: AccountId32;
        readonly stake: u128;
        readonly deposit: u128;
    }
    /** @name PalletElectionsPhragmenVoter (403) */
    interface PalletElectionsPhragmenVoter extends Struct {
        readonly votes: Vec<AccountId32>;
        readonly stake: u128;
        readonly deposit: u128;
    }
    /** @name PalletElectionsPhragmenError (404) */
    interface PalletElectionsPhragmenError extends Enum {
        readonly isUnableToVote: boolean;
        readonly isNoVotes: boolean;
        readonly isTooManyVotes: boolean;
        readonly isMaximumVotesExceeded: boolean;
        readonly isLowBalance: boolean;
        readonly isUnableToPayBond: boolean;
        readonly isMustBeVoter: boolean;
        readonly isReportSelf: boolean;
        readonly isDuplicatedCandidate: boolean;
        readonly isMemberSubmit: boolean;
        readonly isRunnerUpSubmit: boolean;
        readonly isInsufficientCandidateFunds: boolean;
        readonly isNotMember: boolean;
        readonly isInvalidWitnessData: boolean;
        readonly isInvalidVoteCount: boolean;
        readonly isInvalidRenouncing: boolean;
        readonly isInvalidReplacement: boolean;
        readonly type: 'UnableToVote' | 'NoVotes' | 'TooManyVotes' | 'MaximumVotesExceeded' | 'LowBalance' | 'UnableToPayBond' | 'MustBeVoter' | 'ReportSelf' | 'DuplicatedCandidate' | 'MemberSubmit' | 'RunnerUpSubmit' | 'InsufficientCandidateFunds' | 'NotMember' | 'InvalidWitnessData' | 'InvalidVoteCount' | 'InvalidRenouncing' | 'InvalidReplacement';
    }
    /** @name PalletMembershipError (405) */
    interface PalletMembershipError extends Enum {
        readonly isAlreadyMember: boolean;
        readonly isNotMember: boolean;
        readonly type: 'AlreadyMember' | 'NotMember';
    }
    /** @name PalletGrandpaStoredState (406) */
    interface PalletGrandpaStoredState extends Enum {
        readonly isLive: boolean;
        readonly isPendingPause: boolean;
        readonly asPendingPause: {
            readonly scheduledAt: u32;
            readonly delay: u32;
        } & Struct;
        readonly isPaused: boolean;
        readonly isPendingResume: boolean;
        readonly asPendingResume: {
            readonly scheduledAt: u32;
            readonly delay: u32;
        } & Struct;
        readonly type: 'Live' | 'PendingPause' | 'Paused' | 'PendingResume';
    }
    /** @name PalletGrandpaStoredPendingChange (407) */
    interface PalletGrandpaStoredPendingChange extends Struct {
        readonly scheduledAt: u32;
        readonly delay: u32;
        readonly nextAuthorities: Vec<ITuple<[SpFinalityGrandpaAppPublic, u64]>>;
        readonly forced: Option<u32>;
    }
    /** @name PalletGrandpaError (409) */
    interface PalletGrandpaError extends Enum {
        readonly isPauseFailed: boolean;
        readonly isResumeFailed: boolean;
        readonly isChangePending: boolean;
        readonly isTooSoon: boolean;
        readonly isInvalidKeyOwnershipProof: boolean;
        readonly isInvalidEquivocationProof: boolean;
        readonly isDuplicateOffenceReport: boolean;
        readonly type: 'PauseFailed' | 'ResumeFailed' | 'ChangePending' | 'TooSoon' | 'InvalidKeyOwnershipProof' | 'InvalidEquivocationProof' | 'DuplicateOffenceReport';
    }
    /** @name PalletTreasuryProposal (410) */
    interface PalletTreasuryProposal extends Struct {
        readonly proposer: AccountId32;
        readonly value: u128;
        readonly beneficiary: AccountId32;
        readonly bond: u128;
    }
    /** @name FrameSupportPalletId (413) */
    interface FrameSupportPalletId extends U8aFixed {
    }
    /** @name PalletTreasuryError (414) */
    interface PalletTreasuryError extends Enum {
        readonly isInsufficientProposersBalance: boolean;
        readonly isInvalidIndex: boolean;
        readonly isTooManyApprovals: boolean;
        readonly type: 'InsufficientProposersBalance' | 'InvalidIndex' | 'TooManyApprovals';
    }
    /** @name PalletContractsWasmPrefabWasmModule (415) */
    interface PalletContractsWasmPrefabWasmModule extends Struct {
        readonly instructionWeightsVersion: Compact<u32>;
        readonly initial: Compact<u32>;
        readonly maximum: Compact<u32>;
        readonly code: Bytes;
    }
    /** @name PalletContractsWasmOwnerInfo (416) */
    interface PalletContractsWasmOwnerInfo extends Struct {
        readonly owner: AccountId32;
        readonly deposit: Compact<u128>;
        readonly refcount: Compact<u64>;
    }
    /** @name PalletContractsStorageRawContractInfo (417) */
    interface PalletContractsStorageRawContractInfo extends Struct {
        readonly trieId: Bytes;
        readonly codeHash: H256;
        readonly storageDeposit: u128;
    }
    /** @name PalletContractsStorageDeletedContract (419) */
    interface PalletContractsStorageDeletedContract extends Struct {
        readonly trieId: Bytes;
    }
    /** @name PalletContractsSchedule (420) */
    interface PalletContractsSchedule extends Struct {
        readonly limits: PalletContractsScheduleLimits;
        readonly instructionWeights: PalletContractsScheduleInstructionWeights;
        readonly hostFnWeights: PalletContractsScheduleHostFnWeights;
    }
    /** @name PalletContractsScheduleLimits (421) */
    interface PalletContractsScheduleLimits extends Struct {
        readonly eventTopics: u32;
        readonly stackHeight: u32;
        readonly globals: u32;
        readonly parameters: u32;
        readonly memoryPages: u32;
        readonly tableSize: u32;
        readonly brTableSize: u32;
        readonly subjectLen: u32;
        readonly callDepth: u32;
        readonly payloadLen: u32;
        readonly codeLen: u32;
    }
    /** @name PalletContractsScheduleInstructionWeights (422) */
    interface PalletContractsScheduleInstructionWeights extends Struct {
        readonly version: u32;
        readonly i64const: u32;
        readonly i64load: u32;
        readonly i64store: u32;
        readonly select: u32;
        readonly r_if: u32;
        readonly br: u32;
        readonly brIf: u32;
        readonly brTable: u32;
        readonly brTablePerEntry: u32;
        readonly call: u32;
        readonly callIndirect: u32;
        readonly callIndirectPerParam: u32;
        readonly localGet: u32;
        readonly localSet: u32;
        readonly localTee: u32;
        readonly globalGet: u32;
        readonly globalSet: u32;
        readonly memoryCurrent: u32;
        readonly memoryGrow: u32;
        readonly i64clz: u32;
        readonly i64ctz: u32;
        readonly i64popcnt: u32;
        readonly i64eqz: u32;
        readonly i64extendsi32: u32;
        readonly i64extendui32: u32;
        readonly i32wrapi64: u32;
        readonly i64eq: u32;
        readonly i64ne: u32;
        readonly i64lts: u32;
        readonly i64ltu: u32;
        readonly i64gts: u32;
        readonly i64gtu: u32;
        readonly i64les: u32;
        readonly i64leu: u32;
        readonly i64ges: u32;
        readonly i64geu: u32;
        readonly i64add: u32;
        readonly i64sub: u32;
        readonly i64mul: u32;
        readonly i64divs: u32;
        readonly i64divu: u32;
        readonly i64rems: u32;
        readonly i64remu: u32;
        readonly i64and: u32;
        readonly i64or: u32;
        readonly i64xor: u32;
        readonly i64shl: u32;
        readonly i64shrs: u32;
        readonly i64shru: u32;
        readonly i64rotl: u32;
        readonly i64rotr: u32;
    }
    /** @name PalletContractsScheduleHostFnWeights (423) */
    interface PalletContractsScheduleHostFnWeights extends Struct {
        readonly caller: u64;
        readonly address: u64;
        readonly gasLeft: u64;
        readonly balance: u64;
        readonly valueTransferred: u64;
        readonly minimumBalance: u64;
        readonly blockNumber: u64;
        readonly now: u64;
        readonly weightToFee: u64;
        readonly gas: u64;
        readonly input: u64;
        readonly inputPerByte: u64;
        readonly r_return: u64;
        readonly returnPerByte: u64;
        readonly terminate: u64;
        readonly random: u64;
        readonly depositEvent: u64;
        readonly depositEventPerTopic: u64;
        readonly depositEventPerByte: u64;
        readonly debugMessage: u64;
        readonly setStorage: u64;
        readonly setStoragePerByte: u64;
        readonly clearStorage: u64;
        readonly containsStorage: u64;
        readonly getStorage: u64;
        readonly getStoragePerByte: u64;
        readonly takeStorage: u64;
        readonly takeStoragePerByte: u64;
        readonly transfer: u64;
        readonly call: u64;
        readonly callTransferSurcharge: u64;
        readonly callPerInputByte: u64;
        readonly callPerOutputByte: u64;
        readonly instantiate: u64;
        readonly instantiatePerInputByte: u64;
        readonly instantiatePerOutputByte: u64;
        readonly instantiatePerSaltByte: u64;
        readonly hashSha2256: u64;
        readonly hashSha2256PerByte: u64;
        readonly hashKeccak256: u64;
        readonly hashKeccak256PerByte: u64;
        readonly hashBlake2256: u64;
        readonly hashBlake2256PerByte: u64;
        readonly hashBlake2128: u64;
        readonly hashBlake2128PerByte: u64;
        readonly ecdsaRecover: u64;
    }
    /** @name PalletContractsError (424) */
    interface PalletContractsError extends Enum {
        readonly isInvalidScheduleVersion: boolean;
        readonly isOutOfGas: boolean;
        readonly isOutputBufferTooSmall: boolean;
        readonly isTransferFailed: boolean;
        readonly isMaxCallDepthReached: boolean;
        readonly isContractNotFound: boolean;
        readonly isCodeTooLarge: boolean;
        readonly isCodeNotFound: boolean;
        readonly isOutOfBounds: boolean;
        readonly isDecodingFailed: boolean;
        readonly isContractTrapped: boolean;
        readonly isValueTooLarge: boolean;
        readonly isTerminatedWhileReentrant: boolean;
        readonly isInputForwarded: boolean;
        readonly isRandomSubjectTooLong: boolean;
        readonly isTooManyTopics: boolean;
        readonly isDuplicateTopics: boolean;
        readonly isNoChainExtension: boolean;
        readonly isDeletionQueueFull: boolean;
        readonly isDuplicateContract: boolean;
        readonly isTerminatedInConstructor: boolean;
        readonly isDebugMessageInvalidUTF8: boolean;
        readonly isReentranceDenied: boolean;
        readonly isStorageDepositNotEnoughFunds: boolean;
        readonly isStorageDepositLimitExhausted: boolean;
        readonly isCodeInUse: boolean;
        readonly isContractReverted: boolean;
        readonly isCodeRejected: boolean;
        readonly type: 'InvalidScheduleVersion' | 'OutOfGas' | 'OutputBufferTooSmall' | 'TransferFailed' | 'MaxCallDepthReached' | 'ContractNotFound' | 'CodeTooLarge' | 'CodeNotFound' | 'OutOfBounds' | 'DecodingFailed' | 'ContractTrapped' | 'ValueTooLarge' | 'TerminatedWhileReentrant' | 'InputForwarded' | 'RandomSubjectTooLong' | 'TooManyTopics' | 'DuplicateTopics' | 'NoChainExtension' | 'DeletionQueueFull' | 'DuplicateContract' | 'TerminatedInConstructor' | 'DebugMessageInvalidUTF8' | 'ReentranceDenied' | 'StorageDepositNotEnoughFunds' | 'StorageDepositLimitExhausted' | 'CodeInUse' | 'ContractReverted' | 'CodeRejected';
    }
    /** @name PalletSudoError (425) */
    interface PalletSudoError extends Enum {
        readonly isRequireSudo: boolean;
        readonly type: 'RequireSudo';
    }
    /** @name PalletImOnlineBoundedOpaqueNetworkState (429) */
    interface PalletImOnlineBoundedOpaqueNetworkState extends Struct {
        readonly peerId: Bytes;
        readonly externalAddresses: Vec<Bytes>;
    }
    /** @name PalletImOnlineError (433) */
    interface PalletImOnlineError extends Enum {
        readonly isInvalidKey: boolean;
        readonly isDuplicatedHeartbeat: boolean;
        readonly type: 'InvalidKey' | 'DuplicatedHeartbeat';
    }
    /** @name SpStakingOffenceOffenceDetails (436) */
    interface SpStakingOffenceOffenceDetails extends Struct {
        readonly offender: ITuple<[AccountId32, PalletStakingExposure]>;
        readonly reporters: Vec<AccountId32>;
    }
    /** @name PalletIdentityRegistration (438) */
    interface PalletIdentityRegistration extends Struct {
        readonly judgements: Vec<ITuple<[u32, PalletIdentityJudgement]>>;
        readonly deposit: u128;
        readonly info: PalletIdentityIdentityInfo;
    }
    /** @name PalletIdentityRegistrarInfo (446) */
    interface PalletIdentityRegistrarInfo extends Struct {
        readonly account: AccountId32;
        readonly fee: u128;
        readonly fields: PalletIdentityBitFlags;
    }
    /** @name PalletIdentityError (448) */
    interface PalletIdentityError extends Enum {
        readonly isTooManySubAccounts: boolean;
        readonly isNotFound: boolean;
        readonly isNotNamed: boolean;
        readonly isEmptyIndex: boolean;
        readonly isFeeChanged: boolean;
        readonly isNoIdentity: boolean;
        readonly isStickyJudgement: boolean;
        readonly isJudgementGiven: boolean;
        readonly isInvalidJudgement: boolean;
        readonly isInvalidIndex: boolean;
        readonly isInvalidTarget: boolean;
        readonly isTooManyFields: boolean;
        readonly isTooManyRegistrars: boolean;
        readonly isAlreadyClaimed: boolean;
        readonly isNotSub: boolean;
        readonly isNotOwned: boolean;
        readonly type: 'TooManySubAccounts' | 'NotFound' | 'NotNamed' | 'EmptyIndex' | 'FeeChanged' | 'NoIdentity' | 'StickyJudgement' | 'JudgementGiven' | 'InvalidJudgement' | 'InvalidIndex' | 'InvalidTarget' | 'TooManyFields' | 'TooManyRegistrars' | 'AlreadyClaimed' | 'NotSub' | 'NotOwned';
    }
    /** @name PalletSocietyBid (450) */
    interface PalletSocietyBid extends Struct {
        readonly who: AccountId32;
        readonly kind: PalletSocietyBidKind;
        readonly value: u128;
    }
    /** @name PalletSocietyBidKind (451) */
    interface PalletSocietyBidKind extends Enum {
        readonly isDeposit: boolean;
        readonly asDeposit: u128;
        readonly isVouch: boolean;
        readonly asVouch: ITuple<[AccountId32, u128]>;
        readonly type: 'Deposit' | 'Vouch';
    }
    /** @name PalletSocietyVouchingStatus (453) */
    interface PalletSocietyVouchingStatus extends Enum {
        readonly isVouching: boolean;
        readonly isBanned: boolean;
        readonly type: 'Vouching' | 'Banned';
    }
    /** @name PalletSocietyVote (457) */
    interface PalletSocietyVote extends Enum {
        readonly isSkeptic: boolean;
        readonly isReject: boolean;
        readonly isApprove: boolean;
        readonly type: 'Skeptic' | 'Reject' | 'Approve';
    }
    /** @name PalletSocietyError (458) */
    interface PalletSocietyError extends Enum {
        readonly isBadPosition: boolean;
        readonly isNotMember: boolean;
        readonly isAlreadyMember: boolean;
        readonly isSuspended: boolean;
        readonly isNotSuspended: boolean;
        readonly isNoPayout: boolean;
        readonly isAlreadyFounded: boolean;
        readonly isInsufficientPot: boolean;
        readonly isAlreadyVouching: boolean;
        readonly isNotVouching: boolean;
        readonly isHead: boolean;
        readonly isFounder: boolean;
        readonly isAlreadyBid: boolean;
        readonly isAlreadyCandidate: boolean;
        readonly isNotCandidate: boolean;
        readonly isMaxMembers: boolean;
        readonly isNotFounder: boolean;
        readonly isNotHead: boolean;
        readonly type: 'BadPosition' | 'NotMember' | 'AlreadyMember' | 'Suspended' | 'NotSuspended' | 'NoPayout' | 'AlreadyFounded' | 'InsufficientPot' | 'AlreadyVouching' | 'NotVouching' | 'Head' | 'Founder' | 'AlreadyBid' | 'AlreadyCandidate' | 'NotCandidate' | 'MaxMembers' | 'NotFounder' | 'NotHead';
    }
    /** @name PalletRecoveryRecoveryConfig (459) */
    interface PalletRecoveryRecoveryConfig extends Struct {
        readonly delayPeriod: u32;
        readonly deposit: u128;
        readonly friends: Vec<AccountId32>;
        readonly threshold: u16;
    }
    /** @name PalletRecoveryActiveRecovery (460) */
    interface PalletRecoveryActiveRecovery extends Struct {
        readonly created: u32;
        readonly deposit: u128;
        readonly friends: Vec<AccountId32>;
    }
    /** @name PalletRecoveryError (461) */
    interface PalletRecoveryError extends Enum {
        readonly isNotAllowed: boolean;
        readonly isZeroThreshold: boolean;
        readonly isNotEnoughFriends: boolean;
        readonly isMaxFriends: boolean;
        readonly isNotSorted: boolean;
        readonly isNotRecoverable: boolean;
        readonly isAlreadyRecoverable: boolean;
        readonly isAlreadyStarted: boolean;
        readonly isNotStarted: boolean;
        readonly isNotFriend: boolean;
        readonly isDelayPeriod: boolean;
        readonly isAlreadyVouched: boolean;
        readonly isThreshold: boolean;
        readonly isStillActive: boolean;
        readonly isAlreadyProxy: boolean;
        readonly isBadState: boolean;
        readonly type: 'NotAllowed' | 'ZeroThreshold' | 'NotEnoughFriends' | 'MaxFriends' | 'NotSorted' | 'NotRecoverable' | 'AlreadyRecoverable' | 'AlreadyStarted' | 'NotStarted' | 'NotFriend' | 'DelayPeriod' | 'AlreadyVouched' | 'Threshold' | 'StillActive' | 'AlreadyProxy' | 'BadState';
    }
    /** @name PalletVestingReleases (464) */
    interface PalletVestingReleases extends Enum {
        readonly isV0: boolean;
        readonly isV1: boolean;
        readonly type: 'V0' | 'V1';
    }
    /** @name PalletVestingError (465) */
    interface PalletVestingError extends Enum {
        readonly isNotVesting: boolean;
        readonly isAtMaxVestingSchedules: boolean;
        readonly isAmountLow: boolean;
        readonly isScheduleIndexOutOfBounds: boolean;
        readonly isInvalidScheduleParams: boolean;
        readonly type: 'NotVesting' | 'AtMaxVestingSchedules' | 'AmountLow' | 'ScheduleIndexOutOfBounds' | 'InvalidScheduleParams';
    }
    /** @name PalletSchedulerScheduledV3 (468) */
    interface PalletSchedulerScheduledV3 extends Struct {
        readonly maybeId: Option<Bytes>;
        readonly priority: u8;
        readonly call: FrameSupportScheduleMaybeHashed;
        readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
        readonly origin: NodeRuntimeOriginCaller;
    }
    /** @name PalletSchedulerReleases (469) */
    interface PalletSchedulerReleases extends Enum {
        readonly isV1: boolean;
        readonly isV2: boolean;
        readonly isV3: boolean;
        readonly type: 'V1' | 'V2' | 'V3';
    }
    /** @name PalletSchedulerError (470) */
    interface PalletSchedulerError extends Enum {
        readonly isFailedToSchedule: boolean;
        readonly isNotFound: boolean;
        readonly isTargetBlockNumberInPast: boolean;
        readonly isRescheduleNoChange: boolean;
        readonly type: 'FailedToSchedule' | 'NotFound' | 'TargetBlockNumberInPast' | 'RescheduleNoChange';
    }
    /** @name PalletPreimageRequestStatus (471) */
    interface PalletPreimageRequestStatus extends Enum {
        readonly isUnrequested: boolean;
        readonly asUnrequested: Option<ITuple<[AccountId32, u128]>>;
        readonly isRequested: boolean;
        readonly asRequested: u32;
        readonly type: 'Unrequested' | 'Requested';
    }
    /** @name PalletPreimageError (474) */
    interface PalletPreimageError extends Enum {
        readonly isTooLarge: boolean;
        readonly isAlreadyNoted: boolean;
        readonly isNotAuthorized: boolean;
        readonly isNotNoted: boolean;
        readonly isRequested: boolean;
        readonly isNotRequested: boolean;
        readonly type: 'TooLarge' | 'AlreadyNoted' | 'NotAuthorized' | 'NotNoted' | 'Requested' | 'NotRequested';
    }
    /** @name PalletProxyProxyDefinition (477) */
    interface PalletProxyProxyDefinition extends Struct {
        readonly delegate: AccountId32;
        readonly proxyType: NodeRuntimeProxyType;
        readonly delay: u32;
    }
    /** @name PalletProxyAnnouncement (481) */
    interface PalletProxyAnnouncement extends Struct {
        readonly real: AccountId32;
        readonly callHash: H256;
        readonly height: u32;
    }
    /** @name PalletProxyError (483) */
    interface PalletProxyError extends Enum {
        readonly isTooMany: boolean;
        readonly isNotFound: boolean;
        readonly isNotProxy: boolean;
        readonly isUnproxyable: boolean;
        readonly isDuplicate: boolean;
        readonly isNoPermission: boolean;
        readonly isUnannounced: boolean;
        readonly isNoSelfProxy: boolean;
        readonly type: 'TooMany' | 'NotFound' | 'NotProxy' | 'Unproxyable' | 'Duplicate' | 'NoPermission' | 'Unannounced' | 'NoSelfProxy';
    }
    /** @name PalletMultisigMultisig (485) */
    interface PalletMultisigMultisig extends Struct {
        readonly when: PalletMultisigTimepoint;
        readonly deposit: u128;
        readonly depositor: AccountId32;
        readonly approvals: Vec<AccountId32>;
    }
    /** @name PalletMultisigError (487) */
    interface PalletMultisigError extends Enum {
        readonly isMinimumThreshold: boolean;
        readonly isAlreadyApproved: boolean;
        readonly isNoApprovalsNeeded: boolean;
        readonly isTooFewSignatories: boolean;
        readonly isTooManySignatories: boolean;
        readonly isSignatoriesOutOfOrder: boolean;
        readonly isSenderInSignatories: boolean;
        readonly isNotFound: boolean;
        readonly isNotOwner: boolean;
        readonly isNoTimepoint: boolean;
        readonly isWrongTimepoint: boolean;
        readonly isUnexpectedTimepoint: boolean;
        readonly isMaxWeightTooLow: boolean;
        readonly isAlreadyStored: boolean;
        readonly type: 'MinimumThreshold' | 'AlreadyApproved' | 'NoApprovalsNeeded' | 'TooFewSignatories' | 'TooManySignatories' | 'SignatoriesOutOfOrder' | 'SenderInSignatories' | 'NotFound' | 'NotOwner' | 'NoTimepoint' | 'WrongTimepoint' | 'UnexpectedTimepoint' | 'MaxWeightTooLow' | 'AlreadyStored';
    }
    /** @name PalletBountiesBounty (488) */
    interface PalletBountiesBounty extends Struct {
        readonly proposer: AccountId32;
        readonly value: u128;
        readonly fee: u128;
        readonly curatorDeposit: u128;
        readonly bond: u128;
        readonly status: PalletBountiesBountyStatus;
    }
    /** @name PalletBountiesBountyStatus (489) */
    interface PalletBountiesBountyStatus extends Enum {
        readonly isProposed: boolean;
        readonly isApproved: boolean;
        readonly isFunded: boolean;
        readonly isCuratorProposed: boolean;
        readonly asCuratorProposed: {
            readonly curator: AccountId32;
        } & Struct;
        readonly isActive: boolean;
        readonly asActive: {
            readonly curator: AccountId32;
            readonly updateDue: u32;
        } & Struct;
        readonly isPendingPayout: boolean;
        readonly asPendingPayout: {
            readonly curator: AccountId32;
            readonly beneficiary: AccountId32;
            readonly unlockAt: u32;
        } & Struct;
        readonly type: 'Proposed' | 'Approved' | 'Funded' | 'CuratorProposed' | 'Active' | 'PendingPayout';
    }
    /** @name PalletBountiesError (490) */
    interface PalletBountiesError extends Enum {
        readonly isInsufficientProposersBalance: boolean;
        readonly isInvalidIndex: boolean;
        readonly isReasonTooBig: boolean;
        readonly isUnexpectedStatus: boolean;
        readonly isRequireCurator: boolean;
        readonly isInvalidValue: boolean;
        readonly isInvalidFee: boolean;
        readonly isPendingPayout: boolean;
        readonly isPremature: boolean;
        readonly isHasActiveChildBounty: boolean;
        readonly type: 'InsufficientProposersBalance' | 'InvalidIndex' | 'ReasonTooBig' | 'UnexpectedStatus' | 'RequireCurator' | 'InvalidValue' | 'InvalidFee' | 'PendingPayout' | 'Premature' | 'HasActiveChildBounty';
    }
    /** @name PalletTipsOpenTip (491) */
    interface PalletTipsOpenTip extends Struct {
        readonly reason: H256;
        readonly who: AccountId32;
        readonly finder: AccountId32;
        readonly deposit: u128;
        readonly closes: Option<u32>;
        readonly tips: Vec<ITuple<[AccountId32, u128]>>;
        readonly findersFee: bool;
    }
    /** @name PalletTipsError (492) */
    interface PalletTipsError extends Enum {
        readonly isReasonTooBig: boolean;
        readonly isAlreadyKnown: boolean;
        readonly isUnknownTip: boolean;
        readonly isNotFinder: boolean;
        readonly isStillOpen: boolean;
        readonly isPremature: boolean;
        readonly type: 'ReasonTooBig' | 'AlreadyKnown' | 'UnknownTip' | 'NotFinder' | 'StillOpen' | 'Premature';
    }
    /** @name PalletAssetsAssetDetails (493) */
    interface PalletAssetsAssetDetails extends Struct {
        readonly owner: AccountId32;
        readonly issuer: AccountId32;
        readonly admin: AccountId32;
        readonly freezer: AccountId32;
        readonly supply: u128;
        readonly deposit: u128;
        readonly minBalance: u128;
        readonly isSufficient: bool;
        readonly accounts: u32;
        readonly sufficients: u32;
        readonly approvals: u32;
        readonly isFrozen: bool;
    }
    /** @name PalletAssetsAssetAccount (494) */
    interface PalletAssetsAssetAccount extends Struct {
        readonly balance: u128;
        readonly isFrozen: bool;
        readonly reason: PalletAssetsExistenceReason;
        readonly extra: Null;
    }
    /** @name PalletAssetsExistenceReason (495) */
    interface PalletAssetsExistenceReason extends Enum {
        readonly isConsumer: boolean;
        readonly isSufficient: boolean;
        readonly isDepositHeld: boolean;
        readonly asDepositHeld: u128;
        readonly isDepositRefunded: boolean;
        readonly type: 'Consumer' | 'Sufficient' | 'DepositHeld' | 'DepositRefunded';
    }
    /** @name PalletAssetsApproval (497) */
    interface PalletAssetsApproval extends Struct {
        readonly amount: u128;
        readonly deposit: u128;
    }
    /** @name PalletAssetsAssetMetadata (498) */
    interface PalletAssetsAssetMetadata extends Struct {
        readonly deposit: u128;
        readonly name: Bytes;
        readonly symbol: Bytes;
        readonly decimals: u8;
        readonly isFrozen: bool;
    }
    /** @name PalletAssetsError (499) */
    interface PalletAssetsError extends Enum {
        readonly isBalanceLow: boolean;
        readonly isNoAccount: boolean;
        readonly isNoPermission: boolean;
        readonly isUnknown: boolean;
        readonly isFrozen: boolean;
        readonly isInUse: boolean;
        readonly isBadWitness: boolean;
        readonly isMinBalanceZero: boolean;
        readonly isNoProvider: boolean;
        readonly isBadMetadata: boolean;
        readonly isUnapproved: boolean;
        readonly isWouldDie: boolean;
        readonly isAlreadyExists: boolean;
        readonly isNoDeposit: boolean;
        readonly isWouldBurn: boolean;
        readonly type: 'BalanceLow' | 'NoAccount' | 'NoPermission' | 'Unknown' | 'Frozen' | 'InUse' | 'BadWitness' | 'MinBalanceZero' | 'NoProvider' | 'BadMetadata' | 'Unapproved' | 'WouldDie' | 'AlreadyExists' | 'NoDeposit' | 'WouldBurn';
    }
    /** @name PalletLotteryLotteryConfig (500) */
    interface PalletLotteryLotteryConfig extends Struct {
        readonly price: u128;
        readonly start: u32;
        readonly length: u32;
        readonly delay: u32;
        readonly repeat: bool;
    }
    /** @name PalletLotteryError (504) */
    interface PalletLotteryError extends Enum {
        readonly isNotConfigured: boolean;
        readonly isInProgress: boolean;
        readonly isAlreadyEnded: boolean;
        readonly isInvalidCall: boolean;
        readonly isAlreadyParticipating: boolean;
        readonly isTooManyCalls: boolean;
        readonly isEncodingFailed: boolean;
        readonly type: 'NotConfigured' | 'InProgress' | 'AlreadyEnded' | 'InvalidCall' | 'AlreadyParticipating' | 'TooManyCalls' | 'EncodingFailed';
    }
    /** @name PalletGiltGiltBid (506) */
    interface PalletGiltGiltBid extends Struct {
        readonly amount: u128;
        readonly who: AccountId32;
    }
    /** @name PalletGiltActiveGiltsTotal (507) */
    interface PalletGiltActiveGiltsTotal extends Struct {
        readonly frozen: u128;
        readonly proportion: Perquintill;
        readonly index: u32;
        readonly target: Perquintill;
    }
    /** @name PalletGiltActiveGilt (508) */
    interface PalletGiltActiveGilt extends Struct {
        readonly proportion: Perquintill;
        readonly amount: u128;
        readonly who: AccountId32;
        readonly expiry: u32;
    }
    /** @name PalletGiltError (509) */
    interface PalletGiltError extends Enum {
        readonly isDurationTooSmall: boolean;
        readonly isDurationTooBig: boolean;
        readonly isAmountTooSmall: boolean;
        readonly isBidTooLow: boolean;
        readonly isUnknown: boolean;
        readonly isNotOwner: boolean;
        readonly isNotExpired: boolean;
        readonly isNotFound: boolean;
        readonly type: 'DurationTooSmall' | 'DurationTooBig' | 'AmountTooSmall' | 'BidTooLow' | 'Unknown' | 'NotOwner' | 'NotExpired' | 'NotFound';
    }
    /** @name PalletUniquesClassDetails (510) */
    interface PalletUniquesClassDetails extends Struct {
        readonly owner: AccountId32;
        readonly issuer: AccountId32;
        readonly admin: AccountId32;
        readonly freezer: AccountId32;
        readonly totalDeposit: u128;
        readonly freeHolding: bool;
        readonly instances: u32;
        readonly instanceMetadatas: u32;
        readonly attributes: u32;
        readonly isFrozen: bool;
    }
    /** @name PalletUniquesInstanceDetails (512) */
    interface PalletUniquesInstanceDetails extends Struct {
        readonly owner: AccountId32;
        readonly approved: Option<AccountId32>;
        readonly isFrozen: bool;
        readonly deposit: u128;
    }
    /** @name PalletUniquesClassMetadata (513) */
    interface PalletUniquesClassMetadata extends Struct {
        readonly deposit: u128;
        readonly data: Bytes;
        readonly isFrozen: bool;
    }
    /** @name PalletUniquesInstanceMetadata (514) */
    interface PalletUniquesInstanceMetadata extends Struct {
        readonly deposit: u128;
        readonly data: Bytes;
        readonly isFrozen: bool;
    }
    /** @name PalletUniquesError (517) */
    interface PalletUniquesError extends Enum {
        readonly isNoPermission: boolean;
        readonly isUnknown: boolean;
        readonly isAlreadyExists: boolean;
        readonly isWrongOwner: boolean;
        readonly isBadWitness: boolean;
        readonly isInUse: boolean;
        readonly isFrozen: boolean;
        readonly isWrongDelegate: boolean;
        readonly isNoDelegate: boolean;
        readonly isUnapproved: boolean;
        readonly type: 'NoPermission' | 'Unknown' | 'AlreadyExists' | 'WrongOwner' | 'BadWitness' | 'InUse' | 'Frozen' | 'WrongDelegate' | 'NoDelegate' | 'Unapproved';
    }
    /** @name PalletTransactionStorageTransactionInfo (519) */
    interface PalletTransactionStorageTransactionInfo extends Struct {
        readonly chunkRoot: H256;
        readonly contentHash: H256;
        readonly size_: u32;
        readonly blockChunks: u32;
    }
    /** @name PalletTransactionStorageError (520) */
    interface PalletTransactionStorageError extends Enum {
        readonly isInsufficientFunds: boolean;
        readonly isNotConfigured: boolean;
        readonly isRenewedNotFound: boolean;
        readonly isEmptyTransaction: boolean;
        readonly isUnexpectedProof: boolean;
        readonly isInvalidProof: boolean;
        readonly isMissingProof: boolean;
        readonly isMissingStateData: boolean;
        readonly isDoubleCheck: boolean;
        readonly isProofNotChecked: boolean;
        readonly isTransactionTooLarge: boolean;
        readonly isTooManyTransactions: boolean;
        readonly isBadContext: boolean;
        readonly type: 'InsufficientFunds' | 'NotConfigured' | 'RenewedNotFound' | 'EmptyTransaction' | 'UnexpectedProof' | 'InvalidProof' | 'MissingProof' | 'MissingStateData' | 'DoubleCheck' | 'ProofNotChecked' | 'TransactionTooLarge' | 'TooManyTransactions' | 'BadContext';
    }
    /** @name PalletBagsListListNode (521) */
    interface PalletBagsListListNode extends Struct {
        readonly id: AccountId32;
        readonly prev: Option<AccountId32>;
        readonly next: Option<AccountId32>;
        readonly bagUpper: u64;
    }
    /** @name PalletBagsListListBag (522) */
    interface PalletBagsListListBag extends Struct {
        readonly head: Option<AccountId32>;
        readonly tail: Option<AccountId32>;
    }
    /** @name PalletBagsListError (524) */
    interface PalletBagsListError extends Enum {
        readonly isNotInSameBag: boolean;
        readonly isIdNotFound: boolean;
        readonly isNotHeavier: boolean;
        readonly type: 'NotInSameBag' | 'IdNotFound' | 'NotHeavier';
    }
    /** @name PalletChildBountiesChildBounty (525) */
    interface PalletChildBountiesChildBounty extends Struct {
        readonly parentBounty: u32;
        readonly value: u128;
        readonly fee: u128;
        readonly curatorDeposit: u128;
        readonly status: PalletChildBountiesChildBountyStatus;
    }
    /** @name PalletChildBountiesChildBountyStatus (526) */
    interface PalletChildBountiesChildBountyStatus extends Enum {
        readonly isAdded: boolean;
        readonly isCuratorProposed: boolean;
        readonly asCuratorProposed: {
            readonly curator: AccountId32;
        } & Struct;
        readonly isActive: boolean;
        readonly asActive: {
            readonly curator: AccountId32;
        } & Struct;
        readonly isPendingPayout: boolean;
        readonly asPendingPayout: {
            readonly curator: AccountId32;
            readonly beneficiary: AccountId32;
            readonly unlockAt: u32;
        } & Struct;
        readonly type: 'Added' | 'CuratorProposed' | 'Active' | 'PendingPayout';
    }
    /** @name PalletChildBountiesError (528) */
    interface PalletChildBountiesError extends Enum {
        readonly isParentBountyNotActive: boolean;
        readonly isInsufficientBountyBalance: boolean;
        readonly isTooManyChildBounties: boolean;
        readonly type: 'ParentBountyNotActive' | 'InsufficientBountyBalance' | 'TooManyChildBounties';
    }
    /** @name SpRuntimeMultiSignature (530) */
    interface SpRuntimeMultiSignature extends Enum {
        readonly isEd25519: boolean;
        readonly asEd25519: SpCoreEd25519Signature;
        readonly isSr25519: boolean;
        readonly asSr25519: SpCoreSr25519Signature;
        readonly isEcdsa: boolean;
        readonly asEcdsa: SpCoreEcdsaSignature;
        readonly type: 'Ed25519' | 'Sr25519' | 'Ecdsa';
    }
    /** @name SpCoreEcdsaSignature (531) */
    interface SpCoreEcdsaSignature extends U8aFixed {
    }
    /** @name FrameSystemExtensionsCheckNonZeroSender (534) */
    type FrameSystemExtensionsCheckNonZeroSender = Null;
    /** @name FrameSystemExtensionsCheckSpecVersion (535) */
    type FrameSystemExtensionsCheckSpecVersion = Null;
    /** @name FrameSystemExtensionsCheckTxVersion (536) */
    type FrameSystemExtensionsCheckTxVersion = Null;
    /** @name FrameSystemExtensionsCheckGenesis (537) */
    type FrameSystemExtensionsCheckGenesis = Null;
    /** @name FrameSystemExtensionsCheckNonce (540) */
    interface FrameSystemExtensionsCheckNonce extends Compact<u32> {
    }
    /** @name FrameSystemExtensionsCheckWeight (541) */
    type FrameSystemExtensionsCheckWeight = Null;
    /** @name PalletAssetTxPaymentChargeAssetTxPayment (542) */
    interface PalletAssetTxPaymentChargeAssetTxPayment extends Struct {
        readonly tip: Compact<u128>;
        readonly assetId: Option<u32>;
    }
    /** @name NodeRuntimeRuntime (543) */
    type NodeRuntimeRuntime = Null;
}
