"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports._eraPrefs = _eraPrefs;
exports.erasPrefs = exports.eraPrefs = exports._erasPrefs = void 0;

var _rxjs = require("rxjs");

var _index = require("../util/index.cjs");

var _cache = require("./cache.cjs");

var _util = require("./util.cjs");

// Copyright 2017-2022 @polkadot/api-derive authors & contributors
// SPDX-License-Identifier: Apache-2.0
const CACHE_KEY = 'eraPrefs';

function mapPrefs(era, all) {
  const validators = {};
  all.forEach(_ref => {
    let [key, prefs] = _ref;
    validators[key.args[1].toString()] = prefs;
  });
  return {
    era,
    validators
  };
}

function _eraPrefs(instanceId, api) {
  return (0, _index.memo)(instanceId, (era, withActive) => {
    const [cacheKey, cached] = (0, _cache.getEraCache)(CACHE_KEY, era, withActive);
    return cached ? (0, _rxjs.of)(cached) : api.query.staking.erasValidatorPrefs.entries(era).pipe((0, _rxjs.map)(r => (0, _cache.setEraCache)(cacheKey, withActive, mapPrefs(era, r))));
  });
}

const eraPrefs = (0, _util.singleEra)('_eraPrefs');
exports.eraPrefs = eraPrefs;

const _erasPrefs = (0, _util.combineEras)('_eraPrefs');

exports._erasPrefs = _erasPrefs;
const erasPrefs = (0, _util.erasHistoricApply)('_erasPrefs');
exports.erasPrefs = erasPrefs;