// Copyright 2017-2022 @polkadot/typegen authors & contributors
// SPDX-License-Identifier: Apache-2.0
import Handlebars from 'handlebars';
import * as defaultDefs from '@polkadot/types/interfaces/definitions';
import lookupDefinitions from '@polkadot/types-augment/lookup/definitions';
import { stringCamelCase } from '@polkadot/util';
import { compareName, createImports, formatType, initMeta, readTemplate, setImports, writeFile } from "../util/index.js";
const generateForMetaTemplate = Handlebars.compile(readTemplate('events'));
/** @internal */

function generateForMeta(meta, dest, extraTypes, isStrict, customLookupDefinitions) {
  writeFile(dest, () => {
    const allTypes = {
      '@polkadot/types-augment': {
        lookup: { ...lookupDefinitions,
          ...customLookupDefinitions
        }
      },
      '@polkadot/types/interfaces': defaultDefs,
      ...extraTypes
    };
    const imports = createImports(allTypes);
    const allDefs = Object.entries(allTypes).reduce((defs, [path, obj]) => {
      return Object.entries(obj).reduce((defs, [key, value]) => ({ ...defs,
        [`${path}/${key}`]: value
      }), defs);
    }, {});
    const {
      lookup,
      pallets,
      registry
    } = meta.asLatest;
    const modules = pallets.filter(({
      events
    }) => events.isSome).map(({
      events,
      name
    }) => ({
      items: lookup.getSiType(events.unwrap().type).def.asVariant.variants.map(({
        docs,
        fields,
        name
      }) => {
        const args = fields.map(({
          type
        }) => lookup.getTypeDef(type)).map(typeDef => typeDef.lookupName || formatType(registry, allDefs, typeDef, imports));
        setImports(allDefs, imports, args);
        return {
          docs,
          name: name.toString(),
          type: args.join(', ')
        };
      }).sort(compareName),
      name: stringCamelCase(name)
    })).sort(compareName);
    return generateForMetaTemplate({
      headerType: 'chain',
      imports,
      isStrict,
      modules,
      types: [...Object.keys(imports.localTypes).sort().map(packagePath => ({
        file: packagePath.replace('@polkadot/types-augment', '@polkadot/types'),
        types: Object.keys(imports.localTypes[packagePath])
      })), {
        file: '@polkadot/api-base/types',
        types: ['ApiTypes']
      }]
    });
  });
} // Call `generateForMeta()` with current static metadata

/** @internal */


export function generateDefaultEvents(dest, data, extraTypes = {}, isStrict = false, customLookupDefinitions) {
  const {
    metadata
  } = initMeta(data, extraTypes);
  return generateForMeta(metadata, dest, extraTypes, isStrict, customLookupDefinitions);
}