// Copyright 2017-2022 @polkadot/types authors & contributors
// SPDX-License-Identifier: Apache-2.0
import { getTypeDef, TypeDefInfo } from '@polkadot/types-create';

function extractSubSingle({
  lookupName,
  type
}) {
  return extractTypes([lookupName || type]);
}

function extractSubArray(types) {
  return extractTypes(types.map(({
    lookupName,
    type
  }) => lookupName || type));
}
/** @internal */


export function extractTypes(types) {
  return types.map(type => {
    const decoded = getTypeDef(type);

    switch (decoded.info) {
      case TypeDefInfo.Plain:
        return decoded.lookupName || decoded.type;

      case TypeDefInfo.BTreeSet:
      case TypeDefInfo.Compact:
      case TypeDefInfo.Option:
      case TypeDefInfo.Vec:
      case TypeDefInfo.VecFixed:
      case TypeDefInfo.WrapperKeepOpaque:
      case TypeDefInfo.WrapperOpaque:
        return extractSubSingle(decoded.sub);

      case TypeDefInfo.BTreeMap:
      case TypeDefInfo.Enum:
      case TypeDefInfo.HashMap:
      case TypeDefInfo.Result:
      case TypeDefInfo.Set:
      case TypeDefInfo.Struct:
      case TypeDefInfo.Tuple:
        return extractSubArray(decoded.sub);

      default:
        throw new Error(`Unhandled: Unable to create and validate type from ${type} (info=${TypeDefInfo[decoded.info]})`);
    }
  });
}